@@ -5,17 +5,13 @@ OC.L10N.register(
     "Open" : "Ldi",
     "Local" : "Adigan",
     "Email address" : "Tansa imayl",
+    "Circle" : "Tawinest",
     "Moderator" : "Amaẓrag",
     "Admin" : "Anedbal",
     "Owner" : "Bab",
-    "Open »%s«" : "Ldi »%s«",
-    "Open %s" : "Ldi %s",
-    "Loading…" : "Asali...",
-    "No files in here" : "Ulac ifuyla da",
     "No entries found in this folder" : "Ulac inekcumen i yettwafen deg ukaram-a",
     "Name" : "Nom",
     "Size" : "Teɣzi",
-    "Modified" : "Yettwabeddel",
-    "Circle" : "Tawinest"
+    "Modified" : "Yettwabeddel"
 },
 "nplurals=2; plural=(n != 1);");
