@@ -2,9 +2,18 @@ OC.L10N.register(
     "circles",
     {
     "Teams" : "Tímy",
+    "You created the team {circle}" : "Vytvorili ste tím {circle}",
+    "{author} created the team {circle}" : "{author} vytvoril tím {circle}",
     "You deleted {circle}" : "Vymazali ste {circle}",
     "{author} deleted {circle}" : "{author} zmazal {circle}",
+    "You made {member} join {circle}" : "Užívateľa {member} ste pripojili k {circle}",
+    "{author} made {member} join {circle}" : "{author} pripojil užívateľa {member} k {circle}",
+    "You added team {member} as member to {circle}" : "Pridali ste tím {member} ako člena k {circle}",
+    "{author} added team {member} as member to {circle}" : "{author} pridal/a tím {member} ako člena do {circle}",
+    "You made {member} leave {circle}" : "Užívateľa {member} ste odpojili od {circle}",
+    "{author} made {member} leave {circle}" : "{author} odpojil užívateľa {member} od {circle}",
     "You removed {member} from {circle}" : "Odstranili ste {member} z {circle}",
+    "{author} removed {member} from {circle}" : "{author} odstránil/a {member} z {circle}",
     "You joined {circle}" : "Pripojili ste sa ku kruhu {circle}",
     "{member} joined {circle}" : "{member} sa pripojil o kruhu {circle}",
     "You accepted the invitation to join {circle}" : "Prijali ste pozvanie k pripojeniu k {circle}",
@@ -22,6 +31,7 @@ OC.L10N.register(
     "You declined the invitation to join {circle}" : "Odmietli ste pozvánku pre pripojenie ku kruhu {circle}",
     "{member} declined an invitation to join {circle}" : "Používateľ {member} odmietol pozvánku pre pripojenie sa ku kruhu {circle}",
     "You cancelled your request to join {circle}" : "Zrušili ste vašu požiadavku o pripojenie k {circle}",
+    "{member} cancelled a request to join {circle}" : "{member} zrušil žiadosť o pripojeni k {circle}",
     "You have been removed from {circle} by {author}" : "{author} vás odstránil(a) z {circle}",
     "{member} has been removed from {circle} by {author}" : "{author} odstránil(a) {member} z {circle}",
     "You removed {external} from {circle}" : "Odstránili ste {external} z {circle}",
@@ -42,13 +52,16 @@ OC.L10N.register(
     "{member} sent a request to join {circle}" : "{member} odoslal(a) požiadavku na pripojenie k {circle}",
     "You are the new owner of {circle}" : "Ste novým vlastníkom {circle}",
     "{member} is the new owner of {circle}" : "{member} je novým vlastníkom {circle}",
-    "Shared to Circles" : "Zdieľané v kruhoch",
+    "On events happening in a <strong>team</strong> of which you are a member" : "Pri udalostiach odohrávajúcich sa v <strong>tíme</strong>, ktorého ste členom/členkou",
+    "Any important event in a <strong>team</strong> you are moderating" : "Dôležité udalosti v <strong>tíme</strong>, ktorý moderujete",
+    "On global events happening in any <strong>team</strong>" : "Pri globálnych udalostiach, ktoré sa odohrávajú v ktoromkoľvek <strong>tíme</strong>",
     "Single" : "Slobodný",
     "Personal" : "Osobný",
     "System" : "Systém",
     "Visible" : "Viditeľné",
     "Open" : "Otvoriť",
     "Invite" : "Pozvať",
+    "Join request" : "Žiadosť o pripojenie",
     "Friends" : "Priatelia",
     "Password protected" : "Chránené heslom",
     "No Owner" : "Žiadny vlastník",
@@ -56,6 +69,7 @@ OC.L10N.register(
     "Backend" : "Backend",
     "Local" : "Lokálny",
     "Root" : "Koreň",
+    "Team invite" : "Pozvánka do tímu",
     "Federated" : "Združený",
     "Mount point" : "Prípojný bod",
     "Nextcloud Account" : "Účet Nextcloud",
@@ -86,79 +100,57 @@ OC.L10N.register(
     "%s shared multiple files with \"%s\"." : "%s zdieľa viacero súborov s \"%s\".",
     "%s shared multiple files with you." : "%s s vami zdieľa súbory.",
     "Boot up" : "Štart",
+    "Nextcloud Initialization" : "Inicializácia Nextcloudu",
+    "Circles App Initialization" : "Inicializácia Aplikácie Kruhy",
     "Fresh installation status" : "Stav čistej inštalácie",
     "Building Local Database" : "Vytváram Lokálnu Databázu",
     "Testing Basic Circle Creation" : "Testujem základné pridávanie Kruhov",
     "Adding local users and moderators" : "Pridávam lokálnych užívateľov a moderátorov",
+    "Show all teams" : "Zobraziť všetky tímy",
+    "Create a new team" : "Vytvoriť nový tím",
     "Files" : "Súbory",
     "This feature is not available for personal circles" : "Táto funkcia nie je k dispozícii pre osobné kruhy",
+    "The team is not federated" : "Tím nie je združený",
+    "You cannot join this team" : "Nemôžete sa pripojiť k tomuto tímu",
     "This member is not a moderator" : "Tento člen nie je moderátor",
     "Insufficient privileges" : "Nedostatočné oprávnenia",
     "This member does not exist" : "Tento používateľ neexistuje",
+    "This member is the owner of the team" : "Tento člen je vlastníkom tímu",
     "Level cannot be changed for this type of member" : "Pre tento typ člena, úroveň nemôže byť zmenená.",
     "You are already a member of this circle" : "Už ste členom tohto kruhu",
-    "You have been blocked from this circle" : "Boli ste zablokovaný z tohto kruhu",
+    "You have been blocked from this circle" : "V tomto kruhu ste boli zablokovaný",
     "The account is already a member of this circle" : "Tento užívateľ už je členom kruhu",
     "The account has already been invited into this circle" : "Užívateľ už bol pozvaný do tohto kruhu",
-    "You are now a member of the Circle \"%2$s\"" : "Teraz ste členom kruhu \"%2$s\"",
-    "You have been invited by %1$s into the Circle \"%2$s\"" : "Do kruhu \"%2$s\" vás pozval(a) %1$s",
-    "%1$s sent a request to be a member of the Circle \"%2$s\"" : "Požiadavku, stať sa členom kruhu \"%2$s\", zaslal(a) %1$s",
+    "%s (Team owned by %s)" : "%s (Tím vlastnený %s)",
+    "You are now a member of the Team \"%2$s\"" : "Teraz ste členom tímu „%2$s“",
+    "You have been invited by %1$s into the Team \"%2$s\"" : "Boli ste pozvaní používateľom %1$sdo tímu „%2$s“",
+    "%1$s sent a request to be a member of the Team \"%2$s\"" : "%1$s poslal žiadosť o členstvo v tíme „%2$s“",
     "Accept" : "Prijať",
     "Refuse" : "Odmietnuť",
-    "Leave the circle" : "Opustiť kruh",
+    "Leave the team" : "Opustiť tím",
     "%s" : "%s",
+    "Personal team" : "Osobný tím",
     "%s owned by %s" : "%s vlastnené %s",
+    "You have no permission to create a new team" : "Nemáte oprávnenia pre vytváranie nového tímu",
     "%s shared a file with \"%s\"." : "%s zozdieľal súbor s \"%s\".",
     "%s shared a file with you." : "%s vám nazdieľal súbor.",
     "%1$s shared some content with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s s vami zdieľa nejaký obsah. Už ste mali dostať e-mail so samostatným odkazom na prístup k nemu.\n",
     "%1$s shared some content with you. You should have already received a separate email with a link to access it." : "%1$s s vami zdieľa nejaký obsah. Už ste mali dostať e-mail s odkazom na prístup k ním.",
     "Password to access content shared with you by %1$s" : "Heslo pre prístup k obsahu, ktorý s vami zdieľa %1$s",
     "Password to access content" : "Heslo pre prístup k obsahu",
+    "This item is already shared with this team" : "Táto položka je už zdieľaná s týmto tímom",
     "Bring cloud-users closer together." : "Zblížte používateľov cloudu.",
+    "Teams allows people to create their own groups of people/colleagues/friends.\nThose groups of people can then be used by any other app for sharing purpose." : "Tímy umožňujú vašim užívateľom vytvárať ich vlastné skupiny užívateľov/kolegov/priateľov.\nTieto skupiny užívateľov môžu byť potom používané akoukoľvek inou aplikáciou pre potreby zdieľania.",
     "No files in here" : "Nie sú tu žiadne súbory",
     "No entries found in this folder" : "V tomto priečinku sa nič nenašlo",
     "Name" : "Názov",
     "Size" : "Veľkosť",
     "Modified" : "Upravené",
-    "Circles" : "Kruhy",
-    "Circles' files" : "Súbory kruhu",
-    "Select circles to filter by" : "Vyberte kruhy, ktoré chcete filtrovať",
-    "No circles found" : "Nenašli sa žiadne kruhy",
-    "Please select circles to filter by" : "Vyberte kruhy, ktoré chcete filtrovať",
-    "No files found for the selected circles" : "Pre vybrané kruhy neboli nájdené žiadne súbory",
-    "You created the circle {circle}" : "Vytvorili ste kruh {circle}",
-    "{author} created the circle {circle}" : "{author} vytvoril kruh {circle}",
-    "On events happening in a <strong>Circle</strong> of which you are a member" : "Pri udalostiach odohrávajúcich sa v <strong>okrhu</strong>, ktorého ste členom/členkou",
-    "Any important event in a <strong>Circle</strong> you are moderating" : "Dôležité udalosti v <strong>kruhu</strong>, ktorý moderujete",
-    "On global events happening in any <strong>Circle</strong>" : "Pri globálnych udalostiach, ktoré sa odohrávajú v ktoromkoľvek <strong>kruhu</strong>",
-    "Join Request" : "Žiadosť o pripojenie",
-    "Password Protected" : "Chránené heslom",
-    "Circle Invite" : "Pozvať do kruhu",
-    "Email Address" : "E-mailová adresa",
-    "Circle not found" : "Kruh sa nenašiel",
-    "Circle not found " : "Kruh nebol nájdený ",
-    "This account is already a member of the circle" : "Tento užívateľ už je členom kruhu",
-    "Federated link not found" : "Združené prepojenie sa nenašlo",
-    "The circle is not federated" : "Kruh nie je združený",
-    "You cannot join this circle" : "Nemôžete sa pripojiť k tomuto kruhu",
-    "This member is the owner of the circle" : "Tento člen je vlastník kruhu",
-    "%s (Circle owned by %s)" : "%s (Kruh vlastnený %s)",
-    "Personal Circle" : "Osobný kruh",
-    "You need a specify a type of circle" : "Musíte špecifikovať typ kruhu",
-    "A circle with that name exists" : "Kruh s týmto názvom existuje",
-    "This member is not the owner of the circle" : "Tento člen nie je vlastník kruhu",
-    "This member is not an admin of the circle" : "Tento člen nie je správcom kruhu",
-    "Group contains too many members" : "Skupina obsahuje priveľa členov",
-    "This group does not exist" : "Táto skupina neexistuje",
-    "This group is already linked to the circle" : "Táto skupina je už s kruhom prepojená",
-    "You cannot edit level in a personal circle" : "Úroveň osobného kruhu sa nedá upraviť",
-    "Group cannot be set as owner of a circle" : "Skupina nemôže byť nastavená ako vlastník kruhu",
-    "now" : "teraz",
-    "This account does not exist" : "Tento účet neexistuje",
-    "Email format is not valid" : "Nesprávny formát e-mailu",
-    "This contact is not available" : "Tento kontakt je nedostupný",
-    "You have no permission to create a new circle" : "Nemáte oprávnenia pre vytváranie nových kruhov",
-    "This item is already shared with this circle" : "Táto položka je už zdieľaná s týmto kruhom",
-    "Circles allows people to create their own groups of people/colleagues/friends.\nThose groups of people (or \"circles\") can then be used by any other app for sharing purpose." : "Kruhy umožňujú vašim užívateľom vytvárať ich vlastné skupiny užívateľov/kolegov/priateľov.\nTieto skupiny užívateľov (alebo \"kruhov\") môžu buť potom používané akoukoľvek inou aplikáciou pre potreby zdieľania."
+    "Teams' files" : "Súbory tímov",
+    "Select team to filter by" : "Vybrať tím pre filtrovanie",
+    "No teams found" : "Žiadne tímy sa nenašli",
+    "Please select teams to filter by" : "Prosím, vyberte tímy pre filtrovanie",
+    "No files found for the selected teams" : "Pre vybrané tímy neboli nájdené žiadne súbory",
+    "Shared to Circles" : "Zdieľané v kruhoch"
 },
 "nplurals=4; plural=(n % 1 == 0 && n == 1 ? 0 : n % 1 == 0 && n >= 2 && n <= 4 ? 1 : n % 1 != 0 ? 2: 3);");
