@@ -69,6 +69,7 @@ class CirclesManager {
 	/** @var CirclesQueryHelper */
 	private $circlesQueryHelper;
 
+	private bool $forceSync = false;
 
 	/**
 	 * CirclesManager constructor.
@@ -86,7 +87,7 @@ class CirclesManager {
 		MemberService $memberService,
 		MembershipService $membershipService,
 		ConfigService $configService,
-		CirclesQueryHelper $circlesQueryHelper
+		CirclesQueryHelper $circlesQueryHelper,
 	) {
 		$this->federatedUserService = $federatedUserService;
 		$this->circleService = $circleService;
@@ -152,7 +153,8 @@ class CirclesManager {
 	 * @throws InvalidIdException
 	 * @throws FederatedUserException
 	 */
-	public function startSession(?FederatedUser $federatedUser = null): void {
+	public function startSession(?FederatedUser $federatedUser = null, bool $forceSync = false): void {
+		$this->forceSync = $forceSync;
 		if (is_null($federatedUser)) {
 			$this->federatedUserService->initCurrentUser();
 		} else {
@@ -163,7 +165,8 @@ class CirclesManager {
 	/**
 	 *
 	 */
-	public function startSuperSession(): void {
+	public function startSuperSession(bool $forceSync = false): void {
+		$this->forceSync = $forceSync;
 		$this->federatedUserService->unsetCurrentUser();
 		$this->federatedUserService->bypassCurrentUserCondition(true);
 	}
@@ -212,7 +215,7 @@ class CirclesManager {
 	public function startOccSession(
 		string $userId,
 		int $userType = Member::TYPE_SINGLE,
-		string $circleId = ''
+		string $circleId = '',
 	): void {
 		$this->federatedUserService->commandLineInitiator($userId, $userType, $circleId);
 	}
@@ -224,6 +227,7 @@ class CirclesManager {
 	public function stopSession(): void {
 		$this->federatedUserService->unsetCurrentUser();
 		$this->federatedUserService->bypassCurrentUserCondition(false);
+		$this->forceSync = false;
 	}
 
 
@@ -272,7 +276,7 @@ class CirclesManager {
 		string $name,
 		?FederatedUser $owner = null,
 		bool $personal = false,
-		bool $local = false
+		bool $local = false,
 	): Circle {
 		$outcome = $this->circleService->create($name, $owner, $personal, $local);
 		$circle = new Circle();
@@ -298,7 +302,7 @@ class CirclesManager {
 	 * @throws UnknownRemoteException
 	 */
 	public function destroyCircle(string $singleId): void {
-		$this->circleService->destroy($singleId);
+		$this->circleService->destroy($singleId, $this->forceSync);
 	}
 
 
@@ -320,7 +324,7 @@ class CirclesManager {
 		if (is_null($probe)) {
 			$probe = new CircleProbe();
 			$probe->filterHiddenCircles()
-				  ->filterBackendCircles();
+				->filterBackendCircles();
 		}
 
 		return $this->circleService->getCircles($probe, !$refreshCache);
@@ -426,7 +430,7 @@ class CirclesManager {
 	 * @throws UnknownRemoteException
 	 */
 	public function addMember(string $circleId, FederatedUser $federatedUser): Member {
-		$outcome = $this->memberService->addMember($circleId, $federatedUser);
+		$outcome = $this->memberService->addMember($circleId, $federatedUser, $this->forceSync);
 		$member = new Member();
 		$member->import($outcome);
 
@@ -475,7 +479,7 @@ class CirclesManager {
 	 * @throws UnknownRemoteException
 	 */
 	public function removeMember(string $memberId): void {
-		$this->memberService->removeMember($memberId);
+		$this->memberService->removeMember($memberId, $this->forceSync);
 	}
 
 
@@ -521,7 +525,7 @@ class CirclesManager {
 		if (is_null($circleProbe)) {
 			$circleProbe = new CircleProbe();
 			$circleProbe->filterHiddenCircles()
-						->filterBackendCircles();
+				->filterBackendCircles();
 		}
 
 		return $this->circleService->probeCircles($circleProbe, $dataProbe);
