@@ -4,35 +4,13 @@ declare(strict_types=1);
 
 
 /**
- * Circles - Bring cloud-users closer together.
- *
- * This file is licensed under the Affero General Public License version 3 or
- * later. See the COPYING file.
- *
- * @author Maxence Lange <maxence@artificial-owl.com>
- * @copyright 2021
- * @license GNU AGPL version 3 or any later version
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Affero General Public License as
- * published by the Free Software Foundation, either version 3 of the
- * License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Affero General Public License for more details.
- *
- * You should have received a copy of the GNU Affero General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
+ * SPDX-FileCopyrightText: 2021 Nextcloud GmbH and Nextcloud contributors
+ * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
 
 namespace OCA\Circles\Db;
 
-use ArtificialOwl\MySmallPhpTools\Db\Nextcloud\nc22\NC22ExtendedQueryBuilder;
-use ArtificialOwl\MySmallPhpTools\Traits\TArrayTools;
 use Doctrine\DBAL\Query\QueryBuilder;
 use OC;
 use OCA\Circles\Exceptions\RequestBuilderException;
@@ -44,6 +22,8 @@ use OCA\Circles\Model\FederatedUser;
 use OCA\Circles\Model\Member;
 use OCA\Circles\Model\Probes\CircleProbe;
 use OCA\Circles\Service\ConfigService;
+use OCA\Circles\Tools\Db\ExtendedQueryBuilder;
+use OCA\Circles\Tools\Traits\TArrayTools;
 use OCP\DB\QueryBuilder\ICompositeExpression;
 use OCP\DB\QueryBuilder\IQueryBuilder;
 
@@ -52,34 +32,33 @@ use OCP\DB\QueryBuilder\IQueryBuilder;
  *
  * @package OCA\Circles\Db
  */
-class CoreQueryBuilder extends NC22ExtendedQueryBuilder {
+class CoreQueryBuilder extends ExtendedQueryBuilder {
 	use TArrayTools;
 
 
-	public const SINGLE = 'single';
-	public const CIRCLE = 'circle';
-	public const MEMBER = 'member';
-	public const MEMBER_COUNT = 'membercount';
-	public const OWNER = 'owner';
-	public const FEDERATED_EVENT = 'federatedevent';
-	public const REMOTE = 'remote';
-	public const BASED_ON = 'basedon';
-	public const INITIATOR = 'initiator';
-	public const DIRECT_INITIATOR = 'initiatordirect';
-	public const MEMBERSHIPS = 'memberships';
-	public const CONFIG = 'config';
-	public const UPSTREAM_MEMBERSHIPS = 'upstreammemberships';
-	public const INHERITANCE_FROM = 'inheritancefrom';
-	public const INHERITED_BY = 'inheritedby';
-	public const INVITED_BY = 'invitedby';
-	public const MOUNT = 'mount';
-	public const MOUNTPOINT = 'mountpoint';
-	public const SHARE = 'share';
-	public const FILE_CACHE = 'filecache';
-	public const STORAGES = 'storages';
-	public const TOKEN = 'token';
-	public const OPTIONS = 'options';
-	public const HELPER = 'circleshelper';
+	public const SINGLE = 'a';
+	public const CIRCLE = 'b';
+	public const MEMBER = 'c';
+	public const OWNER = 'd';
+	public const FEDERATED_EVENT = 'e';
+	public const REMOTE = 'f';
+	public const BASED_ON = 'g';
+	public const INITIATOR = 'h';
+	public const DIRECT_INITIATOR = 'i';
+	public const MEMBERSHIPS = 'j';
+	public const CONFIG = 'k';
+	public const UPSTREAM_MEMBERSHIPS = 'l';
+	public const INHERITANCE_FROM = 'm';
+	public const INHERITED_BY = 'n';
+	public const INVITED_BY = 'o';
+	public const MOUNT = 'p';
+	public const MOUNTPOINT = 'q';
+	public const SHARE = 'r';
+	public const FILE_CACHE = 's';
+	public const STORAGES = 't';
+	public const TOKEN = 'u';
+	public const OPTIONS = 'v';
+	public const HELPER = 'w';
 
 
 	public static $SQL_PATH = [
@@ -90,7 +69,6 @@ class CoreQueryBuilder extends NC22ExtendedQueryBuilder {
 			self::OPTIONS => [
 			],
 			self::MEMBER,
-			self::MEMBER_COUNT,
 			self::OWNER => [
 				self::BASED_ON
 			],
@@ -236,10 +214,8 @@ class CoreQueryBuilder extends NC22ExtendedQueryBuilder {
 	/** @var ConfigService */
 	private $configService;
 
-
-	/** @var array */
-	private $options = [];
-
+	private array $options = [];
+	private array $sqlPath = [];
 
 	/**
 	 * CoreQueryBuilder constructor.
@@ -267,7 +243,7 @@ class CoreQueryBuilder extends NC22ExtendedQueryBuilder {
 	 * @param string $id
 	 */
 	public function limitToCircleId(string $id): void {
-		$this->limitToDBField('circle_id', $id, true);
+		$this->limit('circle_id', $id, '', true);
 	}
 
 	/**
@@ -295,14 +271,14 @@ class CoreQueryBuilder extends NC22ExtendedQueryBuilder {
 	 * @param int $config
 	 */
 	public function limitToConfig(int $config): void {
-		$this->limitToDBFieldInt('config', $config);
+		$this->limitInt('config', $config);
 	}
 
 	/**
 	 * @param int $source
 	 */
 	public function limitToSource(int $source): void {
-		$this->limitToDBFieldInt('source', $source);
+		$this->limitInt('source', $source);
 	}
 
 	/**
@@ -317,8 +293,8 @@ class CoreQueryBuilder extends NC22ExtendedQueryBuilder {
 	/**
 	 * @param string $singleId
 	 */
-	public function limitToSingleId(string $singleId): void {
-		$this->limitToDBField('single_id', $singleId, true);
+	public function limitToSingleId(string $singleId, string $alias = ''): void {
+		$this->limit('single_id', $singleId, $alias, true);
 	}
 
 
@@ -326,7 +302,7 @@ class CoreQueryBuilder extends NC22ExtendedQueryBuilder {
 	 * @param string $itemId
 	 */
 	public function limitToItemId(string $itemId): void {
-		$this->limitToDBField('item_id', $itemId, true);
+		$this->limit('item_id', $itemId, '', true);
 	}
 
 
@@ -334,7 +310,7 @@ class CoreQueryBuilder extends NC22ExtendedQueryBuilder {
 	 * @param string $host
 	 */
 	public function limitToInstance(string $host): void {
-		$this->limitToDBField('instance', $host, false);
+		$this->limit('instance', $host, '', false);
 	}
 
 
@@ -342,7 +318,7 @@ class CoreQueryBuilder extends NC22ExtendedQueryBuilder {
 	 * @param int $userType
 	 */
 	public function limitToUserType(int $userType): void {
-		$this->limitToDBFieldInt('user_type', $userType);
+		$this->limitInt('user_type', $userType);
 	}
 
 
@@ -350,7 +326,7 @@ class CoreQueryBuilder extends NC22ExtendedQueryBuilder {
 	 * @param int $shareType
 	 */
 	public function limitToShareType(int $shareType): void {
-		$this->limitToDBFieldInt('share_type', $shareType);
+		$this->limitInt('share_type', $shareType);
 	}
 
 
@@ -358,7 +334,7 @@ class CoreQueryBuilder extends NC22ExtendedQueryBuilder {
 	 * @param string $shareWith
 	 */
 	public function limitToShareWith(string $shareWith): void {
-		$this->limitToDBField('share_with', $shareWith);
+		$this->limit('share_with', $shareWith, '', true);
 	}
 
 
@@ -366,14 +342,14 @@ class CoreQueryBuilder extends NC22ExtendedQueryBuilder {
 	 * @param int $nodeId
 	 */
 	public function limitToFileSource(int $nodeId): void {
-		$this->limitToDBFieldInt('file_source', $nodeId);
+		$this->limitInt('file_source', $nodeId);
 	}
 
 	/**
 	 * @param array $files
 	 */
 	public function limitToFileSourceArray(array $files): void {
-		$this->limitToDBFieldInArray('file_source', $files);
+		$this->limitInArray('file_source', $files, type: IQueryBuilder::PARAM_INT_ARRAY);
 	}
 
 
@@ -381,21 +357,39 @@ class CoreQueryBuilder extends NC22ExtendedQueryBuilder {
 	 * @param int $shareId
 	 */
 	public function limitToShareParent(int $shareId): void {
-		$this->limitToDBFieldInt('parent', $shareId);
+		$this->limitInt('parent', $shareId);
 	}
 
 
 	/**
+	 * filter result on details (ie. displayName, Description, ...)
+	 *
 	 * @param Circle $circle
 	 */
-	public function filterCircle(Circle $circle): void {
+	public function filterCircleDetails(Circle $circle): void {
 		if ($this->getType() !== QueryBuilder::SELECT) {
 			return;
 		}
 
+		$expr = $this->expr();
+		$orX = $expr->orX();
 		if ($circle->getDisplayName() !== '') {
-			$this->searchInDBField('display_name', '%' . $circle->getDisplayName() . '%');
+			$andX = $expr->andX();
+			foreach (explode(' ', $circle->getDisplayName()) as $word) {
+				$andX->add(
+					$expr->iLike(
+						$this->getDefaultSelectAlias() . '.' . 'display_name',
+						$this->createNamedParameter('%' . $word . '%')
+					)
+				);
+			}
+			$orX->add($andX);
 		}
+
+		if ($orX->count() > 0) {
+			$this->andWhere($orX);
+		}
+
 		if ($circle->getSource() > 0) {
 			$this->limitInt('source', $circle->getSource());
 		}
@@ -414,10 +408,10 @@ class CoreQueryBuilder extends NC22ExtendedQueryBuilder {
 		try {
 			$aliasRemoteInstance = $this->generateAlias($alias, self::REMOTE);
 			$this->generateRemoteInstanceSelectAlias($aliasRemoteInstance)
-				 ->leftJoin(
-					 $alias, CoreRequestBuilder::TABLE_REMOTE, $aliasRemoteInstance,
-					 $expr->eq($alias . '.instance', $aliasRemoteInstance . '.instance')
-				 );
+				->leftJoin(
+					$alias, CoreRequestBuilder::TABLE_REMOTE, $aliasRemoteInstance,
+					$expr->eq($alias . '.instance', $aliasRemoteInstance . '.instance')
+				);
 		} catch (RequestBuilderException $e) {
 		}
 	}
@@ -435,7 +429,7 @@ class CoreQueryBuilder extends NC22ExtendedQueryBuilder {
 		string $alias,
 		RemoteInstance $remoteInstance,
 		bool $filterSensitiveData = true,
-		string $aliasCircle = ''
+		string $aliasCircle = '',
 	): void {
 		if ($aliasCircle === '') {
 			$aliasCircle = $alias;
@@ -458,7 +452,7 @@ class CoreQueryBuilder extends NC22ExtendedQueryBuilder {
 	 */
 	public function leftJoinRemoteInstanceIncomingRequest(
 		string $alias,
-		RemoteInstance $remoteInstance
+		RemoteInstance $remoteInstance,
 	): void {
 		if ($this->getType() !== QueryBuilder::SELECT) {
 			return;
@@ -483,7 +477,7 @@ class CoreQueryBuilder extends NC22ExtendedQueryBuilder {
 	 * @throws RequestBuilderException
 	 */
 	private function leftJoinMemberFromInstance(
-		string $alias, RemoteInstance $remoteInstance, string $aliasCircle
+		string $alias, RemoteInstance $remoteInstance, string $aliasCircle,
 	) {
 		if ($this->getType() !== QueryBuilder::SELECT) {
 			return;
@@ -519,7 +513,7 @@ class CoreQueryBuilder extends NC22ExtendedQueryBuilder {
 	private function leftJoinMemberFromRemoteCircle(
 		string $alias,
 		RemoteInstance $remoteInstance,
-		string $aliasCircle
+		string $aliasCircle,
 	) {
 		if ($this->getType() !== QueryBuilder::SELECT) {
 			return;
@@ -648,6 +642,36 @@ class CoreQueryBuilder extends NC22ExtendedQueryBuilder {
 	}
 
 
+	/**
+	 * @param string $alias
+	 * @param string $aliasCircle
+	 * @param FederatedUser $federatedUser
+	 *
+	 * @throws RequestBuilderException
+	 */
+	public function limitToFederatedUserMemberships(
+		string $alias,
+		string $aliasCircle,
+		FederatedUser $federatedUser,
+	): void {
+		$aliasMembership = $this->generateAlias($alias, self::MEMBERSHIPS);
+
+		$this->leftJoin(
+			$aliasCircle,
+			'circles_membership',
+			$aliasMembership,
+			$this->expr()->eq($aliasCircle . '.unique_id', $aliasMembership . '.circle_id')
+		);
+
+		$this->andWhere(
+			$this->expr()->eq(
+				$aliasMembership . '.single_id',
+				$this->createNamedParameter($federatedUser->getSingleId())
+			)
+		);
+	}
+
+
 	/**
 	 * @param string $aliasMember
 	 * @param Member $member
@@ -678,9 +702,7 @@ class CoreQueryBuilder extends NC22ExtendedQueryBuilder {
 			);
 		}
 
-		$andX->add(
-			$expr->eq($aliasMember . '.instance', $this->createNamedParameter($this->getInstance($member)))
-		);
+		$this->limitToInstance($this->getInstance($member));
 
 		if ($member->getLevel() > 0) {
 			$andX->add(
@@ -695,32 +717,6 @@ class CoreQueryBuilder extends NC22ExtendedQueryBuilder {
 	}
 
 
-	/**
-	 * @param string $alias
-	 */
-	public function countMembers(string $alias): void {
-		if ($this->getType() !== QueryBuilder::SELECT) {
-			return;
-		}
-
-		try {
-			$aliasMemberCount = $this->generateAlias($alias, self::MEMBER_COUNT, $options);
-		} catch (RequestBuilderException $e) {
-			return;
-		}
-
-		$expr = $this->expr();
-		$this->selectAlias(
-			$this->createFunction('COUNT(`' . $aliasMemberCount . '`.`member_id`)'),
-			(($alias !== $this->getDefaultSelectAlias()) ? $alias . '_' : '') . 'population'
-		);
-		$this->leftJoin(
-			$alias, CoreRequestBuilder::TABLE_MEMBER, $aliasMemberCount,
-			$expr->eq($alias . '.unique_id', $aliasMemberCount . '.circle_id')
-		);
-	}
-
-
 	/**
 	 * @param string $alias
 	 * @param IFederatedUser|null $initiator
@@ -733,7 +729,7 @@ class CoreQueryBuilder extends NC22ExtendedQueryBuilder {
 		string $alias,
 		?IFederatedUser $initiator = null,
 		string $field = 'circle_id',
-		string $helperAlias = ''
+		string $helperAlias = '',
 	): void {
 		if ($this->getType() !== QueryBuilder::SELECT) {
 			return;
@@ -781,10 +777,10 @@ class CoreQueryBuilder extends NC22ExtendedQueryBuilder {
 
 		$expr = $this->expr();
 		$this->generateCircleSelectAlias($aliasInvitedBy)
-			 ->leftJoin(
-				 $aliasMember, CoreRequestBuilder::TABLE_CIRCLE, $aliasInvitedBy,
-				 $expr->eq($aliasMember . '.invited_by', $aliasInvitedBy . '.unique_id')
-			 );
+			->leftJoin(
+				$aliasMember, CoreRequestBuilder::TABLE_CIRCLE, $aliasInvitedBy,
+				$expr->eq($aliasMember . '.invited_by', $aliasInvitedBy . '.unique_id')
+			);
 
 		$this->leftJoinOwner($aliasInvitedBy);
 	}
@@ -798,7 +794,7 @@ class CoreQueryBuilder extends NC22ExtendedQueryBuilder {
 	 */
 	public function leftJoinBasedOn(
 		string $aliasMember,
-		?IFederatedUser $initiator = null
+		?IFederatedUser $initiator = null,
 	): void {
 		if ($this->getType() !== QueryBuilder::SELECT) {
 			return;
@@ -812,10 +808,10 @@ class CoreQueryBuilder extends NC22ExtendedQueryBuilder {
 
 		$expr = $this->expr();
 		$this->generateCircleSelectAlias($aliasBasedOn)
-			 ->leftJoin(
-				 $aliasMember, CoreRequestBuilder::TABLE_CIRCLE, $aliasBasedOn,
-				 $expr->eq($aliasBasedOn . '.unique_id', $aliasMember . '.single_id')
-			 );
+			->leftJoin(
+				$aliasMember, CoreRequestBuilder::TABLE_CIRCLE, $aliasBasedOn,
+				$expr->eq($aliasBasedOn . '.unique_id', $aliasMember . '.single_id')
+			);
 
 		if (!is_null($initiator)) {
 			$this->leftJoinInitiator($aliasBasedOn, $initiator);
@@ -844,21 +840,56 @@ class CoreQueryBuilder extends NC22ExtendedQueryBuilder {
 
 		$expr = $this->expr();
 		$this->generateMemberSelectAlias($aliasMember)
-			 ->leftJoin(
-				 $alias, CoreRequestBuilder::TABLE_MEMBER, $aliasMember,
-				 $expr->andX(
-					 $expr->eq($aliasMember . '.circle_id', $alias . '.' . $field),
-					 $expr->eq(
-						 $aliasMember . '.level',
-						 $this->createNamedParameter(Member::LEVEL_OWNER, self::PARAM_INT)
-					 )
-				 )
-			 );
+			->leftJoin(
+				$alias, CoreRequestBuilder::TABLE_MEMBER, $aliasMember,
+				$expr->andX(
+					$expr->eq($aliasMember . '.circle_id', $alias . '.' . $field),
+					$expr->eq(
+						$aliasMember . '.level',
+						$this->createNamedParameter(Member::LEVEL_OWNER, self::PARAM_INT)
+					)
+				)
+			);
 
 		$this->leftJoinBasedOn($aliasMember);
 	}
 
 
+	/**
+	 * @param CircleProbe $probe
+	 * @param string $alias
+	 * @param string $field
+	 */
+	public function innerJoinMembership(
+		CircleProbe $probe,
+		string $alias,
+		string $field = 'unique_id',
+	): void {
+		if ($this->getType() !== QueryBuilder::SELECT) {
+			return;
+		}
+
+		try {
+			$aliasMembership = $this->generateAlias($alias, self::MEMBERSHIPS);
+		} catch (RequestBuilderException $e) {
+			return;
+		}
+
+		$expr = $this->expr();
+
+		$on = $expr->andX($expr->eq($aliasMembership . '.circle_id', $alias . '.' . $field));
+
+		// limit on membership level if requested
+		$minLevel = $probe->getMinimumLevel();
+		if ($minLevel > Member::LEVEL_MEMBER) {
+			$on->add($this->exprGt('level', $minLevel, true, $aliasMembership));
+		}
+
+		$this->generateMembershipSelectAlias($aliasMembership)
+			->innerJoin($alias, CoreRequestBuilder::TABLE_MEMBERSHIP, $aliasMembership, $on);
+	}
+
+
 	/**
 	 * @param string $alias
 	 * @param string $fieldCircleId
@@ -869,7 +900,7 @@ class CoreQueryBuilder extends NC22ExtendedQueryBuilder {
 	public function leftJoinMember(
 		string $alias,
 		string $fieldCircleId = 'circle_id',
-		string $fieldSingleId = 'single_id'
+		string $fieldSingleId = 'single_id',
 	): void {
 		if ($this->getType() !== QueryBuilder::SELECT) {
 			return;
@@ -884,17 +915,14 @@ class CoreQueryBuilder extends NC22ExtendedQueryBuilder {
 
 		$expr = $this->expr();
 		$this->generateMemberSelectAlias($aliasMember)
-			 ->leftJoin(
-				 $alias, CoreRequestBuilder::TABLE_MEMBER, $aliasMember,
-				 $expr->andX(
-					 $expr->eq($aliasMember . '.circle_id', $alias . '.' . $fieldCircleId),
-					 $expr->eq($aliasMember . '.single_id', $alias . '.' . $fieldSingleId),
-					 $expr->gte(
-						 $aliasMember . '.level',
-						 $this->createNamedParameter(Member::LEVEL_MEMBER, self::PARAM_INT)
-					 )
-				 )
-			 );
+			->leftJoin(
+				$alias, CoreRequestBuilder::TABLE_MEMBER, $aliasMember,
+				$expr->andX(
+					$expr->eq($aliasMember . '.circle_id', $alias . '.' . $fieldCircleId),
+					$expr->eq($aliasMember . '.single_id', $alias . '.' . $fieldSingleId),
+					$this->exprGt('level', Member::LEVEL_MEMBER, true, $aliasMember)
+				)
+			);
 
 		$this->leftJoinRemoteInstance($aliasMember);
 		$this->leftJoinBasedOn($aliasMember);
@@ -914,7 +942,7 @@ class CoreQueryBuilder extends NC22ExtendedQueryBuilder {
 	public function leftJoinInheritedMembers(
 		string $alias,
 		string $field = '',
-		string $aliasInheritedBy = ''
+		string $aliasInheritedBy = '',
 	): void {
 		$expr = $this->expr();
 
@@ -926,21 +954,21 @@ class CoreQueryBuilder extends NC22ExtendedQueryBuilder {
 			$expr->eq($aliasMembership . '.circle_id', $alias . '.' . $field)
 		);
 
-//		if (!$this->getBool('getData', $options, false)) {
-//			return;
-//		}
+		//		if (!$this->getBool('getData', $options, false)) {
+		//			return;
+		//		}
 
 		if ($aliasInheritedBy === '') {
 			$aliasInheritedBy = $this->generateAlias($alias, self::INHERITED_BY);
 		}
 		$this->generateMemberSelectAlias($aliasInheritedBy)
-			 ->leftJoin(
-				 $alias, CoreRequestBuilder::TABLE_MEMBER, $aliasInheritedBy,
-				 $expr->andX(
-					 $expr->eq($aliasMembership . '.inheritance_last', $aliasInheritedBy . '.circle_id'),
-					 $expr->eq($aliasMembership . '.single_id', $aliasInheritedBy . '.single_id')
-				 )
-			 );
+			->leftJoin(
+				$alias, CoreRequestBuilder::TABLE_MEMBER, $aliasInheritedBy,
+				$expr->andX(
+					$expr->eq($aliasMembership . '.inheritance_last', $aliasInheritedBy . '.circle_id'),
+					$expr->eq($aliasMembership . '.single_id', $aliasInheritedBy . '.single_id')
+				)
+			);
 
 		$this->leftJoinBasedOn($aliasInheritedBy);
 	}
@@ -1024,13 +1052,13 @@ class CoreQueryBuilder extends NC22ExtendedQueryBuilder {
 
 		$aliasInheritanceFrom = $this->generateAlias($alias, self::INHERITANCE_FROM);
 		$this->generateMemberSelectAlias($aliasInheritanceFrom)
-			 ->leftJoin(
-				 $aliasMembership, CoreRequestBuilder::TABLE_MEMBER, $aliasInheritanceFrom,
-				 $expr->andX(
-					 $expr->eq($aliasMembership . '.circle_id', $aliasInheritanceFrom . '.circle_id'),
-					 $expr->eq($aliasMembership . '.inheritance_first', $aliasInheritanceFrom . '.single_id')
-				 )
-			 );
+			->leftJoin(
+				$aliasMembership, CoreRequestBuilder::TABLE_MEMBER, $aliasInheritanceFrom,
+				$expr->andX(
+					$expr->eq($aliasMembership . '.circle_id', $aliasInheritanceFrom . '.circle_id'),
+					$expr->eq($aliasMembership . '.inheritance_first', $aliasInheritanceFrom . '.single_id')
+				)
+			);
 	}
 
 
@@ -1088,7 +1116,7 @@ class CoreQueryBuilder extends NC22ExtendedQueryBuilder {
 		string $alias,
 		IFederatedUser $user,
 		string $field = '',
-		string $helperAlias = ''
+		string $helperAlias = '',
 	): ICompositeExpression {
 		$this->leftJoinInitiator($alias, $user, $field, $helperAlias);
 		$where = $this->limitInitiatorVisibility($alias);
@@ -1138,7 +1166,7 @@ class CoreQueryBuilder extends NC22ExtendedQueryBuilder {
 		string $alias,
 		IFederatedUser $initiator,
 		string $field = '',
-		string $helperAlias = ''
+		string $helperAlias = '',
 	): void {
 		if ($this->getType() !== QueryBuilder::SELECT) {
 			return;
@@ -1204,15 +1232,15 @@ class CoreQueryBuilder extends NC22ExtendedQueryBuilder {
 			try {
 				$aliasDirectInitiator = $this->generateAlias($alias, self::DIRECT_INITIATOR, $options);
 				$this->generateMemberSelectAlias($aliasDirectInitiator)
-					 ->leftJoin(
-						 $helperAlias,
-						 CoreRequestBuilder::TABLE_MEMBER,
-						 $aliasDirectInitiator,
-						 $expr->andX(
-							 $this->exprLimit('single_id', $initiator->getSingleId(), $aliasDirectInitiator),
-							 $expr->eq($aliasDirectInitiator . '.circle_id', $helperAlias . '.' . $field)
-						 )
-					 );
+					->leftJoin(
+						$helperAlias,
+						CoreRequestBuilder::TABLE_MEMBER,
+						$aliasDirectInitiator,
+						$expr->andX(
+							$this->exprLimit('single_id', $initiator->getSingleId(), $aliasDirectInitiator),
+							$expr->eq($aliasDirectInitiator . '.circle_id', $helperAlias . '.' . $field)
+						)
+					);
 			} catch (RequestBuilderException $e) {
 				// meaning that this path does not require DIRECT_INITIATOR; can be safely ignored
 			}
@@ -1250,13 +1278,43 @@ class CoreQueryBuilder extends NC22ExtendedQueryBuilder {
 			}
 			$aliasInheritedByMembership = $this->generateAlias($aliasInheritedBy, self::MEMBERSHIPS);
 			$this->generateMemberSelectAlias($aliasInitiator, $default)
-				 ->generateMemberSelectAlias($aliasInheritedBy)
-				 ->generateMembershipSelectAlias($aliasMembership, $aliasInheritedByMembership);
+				->generateMemberSelectAlias($aliasInheritedBy)
+				->generateMembershipSelectAlias($aliasMembership, $aliasInheritedByMembership);
 		} catch (RequestBuilderException $e) {
 		}
 	}
 
 
+	public function completeProbeWithInitiator(
+		string $alias,
+		string $field = 'single_id',
+		string $helperAlias = '',
+	): void {
+		if ($this->getType() !== QueryBuilder::SELECT) {
+			return;
+		}
+
+		try {
+			$aliasInitiator = $this->generateAlias($alias, self::INITIATOR);
+		} catch (RequestBuilderException $e) {
+			return;
+		}
+
+		$helperAlias = ($helperAlias === '') ? $alias : $helperAlias;
+
+		$expr = $this->expr();
+		$this->generateMemberSelectAlias($aliasInitiator)
+			->leftJoin(
+				$alias, CoreRequestBuilder::TABLE_MEMBER, $aliasInitiator,
+				$expr->andX(
+					$expr->eq($aliasInitiator . '.circle_id', $alias . '.unique_id'),
+					$expr->eq($aliasInitiator . '.' . $field, $helperAlias . '.inheritance_first'),
+				)
+			);
+		//
+		//		$this->leftJoinBasedOn($aliasInitiator);
+	}
+
 	/**
 	 * @param string $alias
 	 *
@@ -1268,8 +1326,10 @@ class CoreQueryBuilder extends NC22ExtendedQueryBuilder {
 		$aliasMembershipCircle = $this->generateAlias($aliasMembership, self::CONFIG, $options);
 		$levelCheck = [$aliasMembership];
 
+		$directMember = '';
 		if ($this->getBool('initiatorDirectMember', $options, false)) {
-			array_push($levelCheck, $this->generateAlias($alias, self::DIRECT_INITIATOR, $options));
+			$directMember = $this->generateAlias($alias, self::DIRECT_INITIATOR, $options);
+			array_push($levelCheck, $directMember);
 		}
 
 		$expr = $this->expr();
@@ -1299,7 +1359,7 @@ class CoreQueryBuilder extends NC22ExtendedQueryBuilder {
 				$orXLevelCheck->add(
 					$this->expr()->gte(
 						$alias . '.level',
-						$this->createNamedParameter($minimumLevel)
+						$this->createNamedParameter($minimumLevel, self::PARAM_INT)
 					)
 				);
 			},
@@ -1317,6 +1377,13 @@ class CoreQueryBuilder extends NC22ExtendedQueryBuilder {
 		}
 		$orX->add($andXMember);
 
+		if ($directMember !== '' && $this->getBool('allowRequestingMembership', $options, false)) {
+			$orX->add($expr->orX(
+				$this->exprLimit('status', Member::STATUS_REQUEST, $directMember),
+				$this->exprLimit('status', Member::STATUS_INVITED, $directMember)
+			));
+		}
+
 		if ($minimumLevel === 0 && $alias === self::CIRCLE) {
 			$orX->add($this->exprLimitBitwise('config', Circle::CFG_VISIBLE, $alias));
 		}
@@ -1328,6 +1395,10 @@ class CoreQueryBuilder extends NC22ExtendedQueryBuilder {
 			$orX->add($andXNonVisible);
 		}
 
+		if ($this->getBool('visitingSingleCircles', $options, false)) {
+			$orX->add($this->exprLimitBitwise('config', Circle::CFG_SINGLE, $alias));
+		}
+
 		// if Member can be Visitor, we only filter access to Personal Circles
 		if ($this->getBool('viewableThroughKeyhole', $options, false)) {
 			$andOpen = $expr->andX();
@@ -1342,22 +1413,6 @@ class CoreQueryBuilder extends NC22ExtendedQueryBuilder {
 		$this->andWhere($orX);
 
 		return $orX;
-//		$orTypes = $this->generateLimit($qb, $circleUniqueId, $userId, $type, $name, $forceAll);
-//		if (sizeof($orTypes) === 0) {
-//			throw new ConfigNoCircleAvailableException(
-//				$this->l10n->t(
-//					'You cannot use the Circles Application until your administrator has allowed at least one type of circles'
-//				)
-//			);
-//		}
-
-//		$orXTypes = $this->expr()
-//						 ->orX();
-//		foreach ($orTypes as $orType) {
-//			$orXTypes->add($orType);
-//		}
-//
-//		$qb->andWhere($orXTypes);
 	}
 
 
@@ -1427,20 +1482,20 @@ class CoreQueryBuilder extends NC22ExtendedQueryBuilder {
 			$aliasFileCache,
 			[]
 		)
-			 ->generateSelectAlias(
-				 CoreRequestBuilder::$outsideTables[CoreRequestBuilder::TABLE_STORAGES],
-				 $aliasStorages,
-				 $aliasStorages,
-				 []
-			 )
-			 ->leftJoin(
-				 $aliasShare, CoreRequestBuilder::TABLE_FILE_CACHE, $aliasFileCache,
-				 $expr->eq($aliasShare . '.file_source', $aliasFileCache . '.fileid')
-			 )
-			 ->leftJoin(
-				 $aliasFileCache, CoreRequestBuilder::TABLE_STORAGES, $aliasStorages,
-				 $expr->eq($aliasFileCache . '.storage', $aliasStorages . '.numeric_id')
-			 );
+			->generateSelectAlias(
+				CoreRequestBuilder::$outsideTables[CoreRequestBuilder::TABLE_STORAGES],
+				$aliasStorages,
+				$aliasStorages,
+				[]
+			)
+			->leftJoin(
+				$aliasShare, CoreRequestBuilder::TABLE_FILE_CACHE, $aliasFileCache,
+				$expr->eq($aliasShare . '.file_source', $aliasFileCache . '.fileid')
+			)
+			->leftJoin(
+				$aliasFileCache, CoreRequestBuilder::TABLE_STORAGES, $aliasStorages,
+				$expr->eq($aliasFileCache . '.storage', $aliasStorages . '.numeric_id')
+			);
 	}
 
 
@@ -1473,7 +1528,7 @@ class CoreQueryBuilder extends NC22ExtendedQueryBuilder {
 			[]
 		);
 
-//		$this->selectAlias($aliasShareParent . '.permissions', 'parent_perms');
+		//		$this->selectAlias($aliasShareParent . '.permissions', 'parent_perms');
 	}
 
 
@@ -1482,16 +1537,24 @@ class CoreQueryBuilder extends NC22ExtendedQueryBuilder {
 	 * @param FederatedUser $federatedUser
 	 * @param bool $reshares
 	 */
-	public function limitToShareOwner(string $alias, FederatedUser $federatedUser, bool $reshares): void {
+	public function limitToShareOwner(
+		string $alias,
+		FederatedUser $federatedUser,
+		bool $reshares,
+		int $nodeId = 0,
+	): void {
 		$expr = $this->expr();
 
-		$orX = $expr->orX($this->exprLimit('uid_initiator', $federatedUser->getUserId(), $alias));
-
-		if ($reshares) {
-			$orX->add($this->exprLimit('uid_owner', $federatedUser->getUserId(), $alias));
+		if ($reshares === false) {
+			$this->andWhere($this->exprLimit('uid_initiator', $federatedUser->getUserId(), $alias));
+		} elseif ($nodeId === 0) {
+			$this->andWhere(
+				$expr->orX(
+					$this->exprLimit('uid_owner', $federatedUser->getUserId(), $alias),
+					$this->exprLimit('uid_initiator', $federatedUser->getUserId(), $alias)
+				)
+			);
 		}
-
-		$this->andWhere($orX);
 	}
 
 
@@ -1501,7 +1564,7 @@ class CoreQueryBuilder extends NC22ExtendedQueryBuilder {
 	 *
 	 * @throws RequestBuilderException
 	 */
-	public function leftJoinMountpoint(string $aliasMount, string $aliasMountMemberships = '') {
+	public function leftJoinMountpoint(string $aliasMount, IFederatedUser $federatedUser, string $aliasMountMemberships = '') {
 		$expr = $this->expr();
 
 		$aliasMountpoint = $this->generateAlias($aliasMount, self::MOUNTPOINT);
@@ -1513,7 +1576,7 @@ class CoreQueryBuilder extends NC22ExtendedQueryBuilder {
 			$aliasMountMemberships, CoreRequestBuilder::TABLE_MOUNTPOINT, $aliasMountpoint,
 			$expr->andX(
 				$expr->eq($aliasMountpoint . '.mount_id', $aliasMount . '.mount_id'),
-				$expr->eq($aliasMountpoint . '.single_id', $aliasMountMemberships . '.single_id')
+				$expr->eq($aliasMountpoint . '.single_id', $this->createNamedParameter($federatedUser->getSingleId()))
 			)
 		);
 
@@ -1567,7 +1630,7 @@ class CoreQueryBuilder extends NC22ExtendedQueryBuilder {
 	private function generateMembershipSelectAlias(
 		string $alias,
 		string $prefix = '',
-		array $default = []
+		array $default = [],
 	): self {
 		$this->generateSelectAlias(
 			CoreRequestBuilder::$tables[CoreRequestBuilder::TABLE_MEMBERSHIP],
@@ -1601,14 +1664,18 @@ class CoreQueryBuilder extends NC22ExtendedQueryBuilder {
 	/**
 	 * @param array $path
 	 * @param array $options
+	 *
+	 * @return CoreQueryBuilder
 	 */
-	public function setOptions(array $path, array $options): void {
+	public function setOptions(array $path, array $options): self {
 		$options = [self::OPTIONS => $options];
 		foreach (array_reverse($path) as $item) {
 			$options = [$item => $options];
 		}
 
-		$this->options = $options;
+		$this->options = array_merge_recursive($this->options, $options);
+
+		return $this;
 	}
 
 
@@ -1623,8 +1690,8 @@ class CoreQueryBuilder extends NC22ExtendedQueryBuilder {
 	public function generateAlias(string $base, string $extension, ?array &$options = []): string {
 		$search = str_replace('_', '.', $base);
 		$path = $search . '.' . $extension;
-		if (!$this->validKey($path, self::$SQL_PATH)
-			&& !in_array($extension, $this->getArray($search, self::$SQL_PATH))) {
+		if (!$this->validKey($path, $this->getSqlPath())
+			&& !in_array($extension, $this->getArray($search, $this->getSqlPath()))) {
 			throw new RequestBuilderException($extension . ' not found in ' . $search);
 		}
 
@@ -1637,7 +1704,7 @@ class CoreQueryBuilder extends NC22ExtendedQueryBuilder {
 			$optionPath = trim($optionPath . '.' . $p, '.');
 			$options = array_merge(
 				$options,
-				$this->getArray($optionPath . '.' . self::OPTIONS, self::$SQL_PATH),
+				$this->getArray($optionPath . '.' . self::OPTIONS, $this->getSqlPath()),
 				$this->getArray($optionPath . '.' . self::OPTIONS, $this->options)
 			);
 		}
@@ -1656,7 +1723,7 @@ class CoreQueryBuilder extends NC22ExtendedQueryBuilder {
 		$search = str_replace('_', '.', $prefix);
 
 		$path = [];
-		foreach ($this->getArray($search, self::$SQL_PATH) as $arr => $item) {
+		foreach ($this->getArray($search, $this->getSqlPath()) as $arr => $item) {
 			if (is_numeric($arr)) {
 				$k = $item;
 			} else {
@@ -1667,4 +1734,41 @@ class CoreQueryBuilder extends NC22ExtendedQueryBuilder {
 
 		return $path;
 	}
+
+
+	/**
+	 * @return array
+	 */
+	public function getSqlPath(): array {
+		if (empty($this->sqlPath)) {
+			return self::$SQL_PATH;
+		}
+
+		return $this->sqlPath;
+	}
+
+
+	/**
+	 * DataProbe uses this to set which data need to be extracted, based on self::$SQL_PATH.
+	 *
+	 * @param string $key
+	 * @param array $path
+	 *
+	 * @return $this
+	 */
+	public function setSqlPath(string $key, array $path = []): self {
+		if (empty($this->sqlPath)) {
+			$this->sqlPath = self::$SQL_PATH;
+		}
+
+		$this->sqlPath[$key] = $path;
+
+		return $this;
+	}
+
+	public function resetSqlPath(): self {
+		$this->sqlPath = [];
+
+		return $this;
+	}
 }
