@@ -161,7 +161,7 @@ OC.L10N.register(
     "When:" : "Wann:",
     "Location:" : "Ort:",
     "Link:" : "Link:",
-    "Occurring:" : "Vorkommend:",
+    "Occurring:" : "Findet statt:",
     "Accept" : "Akzeptieren",
     "Decline" : "Ablehnen",
     "More options …" : "Weitere Optionen …",
@@ -282,7 +282,7 @@ OC.L10N.register(
     "Saved availability" : "Verfügbarkeit gespeichert",
     "Failed to save availability" : "Verfügbarkeit konnte nicht gespeichert werden",
     "Time zone:" : "Zeitzone:",
-    "to" : "an",
+    "to" : "bis",
     "Delete slot" : "Slot löschen",
     "No working hours set" : "Keine Arbeitszeiten konfiguriert",
     "Add slot" : "Slot hinzufügen",
@@ -299,10 +299,10 @@ OC.L10N.register(
     "Calendar server" : "Kalender-Server",
     "Send invitations to attendees" : "Einladungen an die Teilnehmer senden",
     "Automatically generate a birthday calendar" : "Automatisch einen Kalender für Geburtstage erstellen",
-    "Birthday calendars will be generated by a background job." : "Kalender für Geburtstage werden von einem Hintergrund-Auftrag erstellt",
+    "Birthday calendars will be generated by a background job." : "Kalender für Geburtstage werden von einer Hintergrundaufgabe erstellt",
     "Hence they will not be available immediately after enabling but will show up after some time." : "Die Einträge werden nicht sofort angezeigt. Nach der Aktivierung wird es bis zur Anzeige ein wenig dauern.",
     "Send notifications for events" : "Sende Benachrichtigungen für Termine",
-    "Notifications are sent via background jobs, so these must occur often enough." : "Benachrichtigungen werden von Hintergrundjobs gesendet, so dass diese häufig genug ausgeführt werden.",
+    "Notifications are sent via background jobs, so these must occur often enough." : "Benachrichtigungen werden von Hintergrundaufgaben gesendet, so dass diese häufig genug ausgeführt werden.",
     "Send reminder notifications to calendar sharees as well" : "Erinnerungsbenachrichtigungen auch an die freigegebenen Kalender senden",
     "Reminders are always sent to organizers and attendees." : "Erinnerungen werden immer an Organisatoren und Teilnehmer gesendet.",
     "Enable notifications for events via push" : "Benachrichtigungen für Termine per Push aktivieren",
@@ -323,10 +323,6 @@ OC.L10N.register(
     "Please contact the organizer directly." : "Bitte den Organisator direkt kontaktieren.",
     "Are you accepting the invitation?" : "Die Einladung annehmen?",
     "Tentative" : "Vorläufig",
-    "Your attendance was updated successfully." : "Dein Teilnehmerstatus wurde aktualisiert.",
-    "Time:" : "Zeit:",
-    "Could not open file" : "Datei konnte nicht geöffnet werden",
-    "Invalid chunk name" : "Ungültiger Chunk-Name",
-    "Could not rename part file assembled from chunks" : "Aus Chunks zusammengesetzte temporäre Datei konnte nicht umbenannt werden"
+    "Your attendance was updated successfully." : "Dein Teilnehmerstatus wurde aktualisiert."
 },
 "nplurals=2; plural=(n != 1);");
