@@ -72,10 +72,20 @@ OC.L10N.register(
     "Description: %s" : "Cur síos: %s",
     "Where: %s" : "Cá: %s",
     "%1$s via %2$s" : "%1$s trí %2$s",
-    "In a %1$s on %2$s for the entire day" : "I %1$s ar %2$s ar feadh an lae ar fad",
-    "In a %1$s on %2$s between %3$s - %4$s" : "I %1$s ar %2$s idir %3$s - %4$s",
-    "In %1$s %2$s on %3$s for the entire day" : "I %1$s %2$s ar %3$s ar feadh an lae ar fad",
-    "In %1$s %2$s on %3$s between %4$s - %5$s" : "I %1$s %2$s ar %3$s idir %4$s - %5$s",
+    "In the past on %1$s for the entire day" : "San am atá thart ar %1$s don lá ar fad",
+    "_In a minute on %1$s for the entire day_::_In %n minutes on %1$s for the entire day_" : ["I gceann nóiméid ar%1$s don lá ar fad","I gceann %n nóiméad ar %1$s ar feadh an lae ar fad","I gceann %n nóiméad ar %1$s ar feadh an lae ar fad","I gceann %n nóiméad ar %1$s ar feadh an lae ar fad","I gceann %n nóiméad ar %1$s ar feadh an lae ar fad"],
+    "_In a hour on %1$s for the entire day_::_In %n hours on %1$s for the entire day_" : ["I gceann uair an chloig ar %1$s don lá ar fad","I gceann %n uair an chloig ar %1$s don lá ar fad","I gceann %n uair an chloig ar %1$s don lá ar fad","I gceann %n uair an chloig ar %1$s don lá ar fad","I gceann %n uair an chloig ar %1$s don lá ar fad"],
+    "_In a day on %1$s for the entire day_::_In %n days on %1$s for the entire day_" : ["I lá ar %1$s don lá ar fad","I gceann %n lá ar %1$s don lá ar fad","I gceann %n lá ar %1$s don lá ar fad","I gceann %n lá ar %1$s don lá ar fad","I gceann %n lá ar %1$s don lá ar fad"],
+    "_In a week on %1$s for the entire day_::_In %n weeks on %1$s for the entire day_" : ["I gceann seachtaine ar %1$s don lá ar fad","I gceann %n seachtain ar %1$s don lá ar fad","I gceann %n seachtain ar %1$s don lá ar fad","I gceann %n seachtain ar %1$s don lá ar fad","I gceann %n seachtain ar %1$s don lá ar fad"],
+    "_In a month on %1$s for the entire day_::_In %n months on %1$s for the entire day_" : ["I gceann míosa ar %1$s don lá ar fad","I gceann %n mí ar %1$s don lá ar fad","I gceann %n mí ar %1$s don lá ar fad","I gceann %n mí ar %1$s don lá ar fad","I gceann %n mí ar %1$s don lá ar fad"],
+    "_In a year on %1$s for the entire day_::_In %n years on %1$s for the entire day_" : ["I gceann bliana ar %1$s don lá ar fad","I gceann %n bliain ar %1$s don lá ar fad","I gceann %n bliain ar %1$s don lá ar fad","I gceann %n bliain ar %1$s don lá ar fad","I gceann %n bliain ar %1$s don lá ar fad"],
+    "In the past on %1$s between %2$s - %3$s" : "San am a chuaigh thart ar %1$s idir %2$s - %3$s",
+    "_In a minute on %1$s between %2$s - %3$s_::_In %n minutes on %1$s between %2$s - %3$s_" : ["I gceann nóiméid ar %1$s idir %2$s - %3$s","I %n nóiméad ar %1$s idir %2$s - %3$s","I %n nóiméad ar %1$s idir %2$s - %3$s","I %n nóiméad ar %1$s idir %2$s - %3$s","I %n nóiméad ar %1$s idir %2$s - %3$s"],
+    "_In a hour on %1$s between %2$s - %3$s_::_In %n hours on %1$s between %2$s - %3$s_" : ["I gceann uair an chloig ar %1$s idir %2$s - %3$s","I %n uair an chloig ar %1$s idir %2$s - %3$s","I %n uair an chloig ar %1$s idir %2$s - %3$s","I %n uair an chloig ar %1$s idir %2$s - %3$s","I %n uair an chloig ar %1$s idir %2$s - %3$s"],
+    "_In a day on %1$s between %2$s - %3$s_::_In %n days on %1$s between %2$s - %3$s_" : ["I lá ar %1$s idir %2$s - %3$s","I %n lá ar %1$s idir %2$s - %3$s","I %n lá ar %1$s idir %2$s - %3$s","I %n lá ar %1$s idir %2$s - %3$s","I %n lá ar %1$s idir %2$s - %3$s"],
+    "_In a week on %1$s between %2$s - %3$s_::_In %n weeks on %1$s between %2$s - %3$s_" : ["I gceann seachtaine ar %1$s idir %2$s - %3$s","I %n seachtain ar %1$s idir %2$s - %3$s","I %n seachtain ar %1$s idir %2$s - %3$s","I %n seachtain ar %1$s idir %2$s - %3$s","I %n seachtain ar %1$s idir %2$s - %3$s"],
+    "_In a month on %1$s between %2$s - %3$s_::_In %n months on %1$s between %2$s - %3$s_" : ["I gceann míosa ar %1$s idir %2$s - %3$s","I %n mí ar %1$s idir %2$s - %3$s","I %n mí ar %1$s idir %2$s - %3$s","I %n mí ar %1$s idir %2$s - %3$s","I %n mí ar %1$s idir %2$s - %3$s"],
+    "_In a year on %1$s between %2$s - %3$s_::_In %n years on %1$s between %2$s - %3$s_" : ["I mbliain ar %1$s idir %2$s - %3$s","I gceann %n bliain ar %1$s idir %2$s - %3$s","I gceann %n bliain ar %1$s idir %2$s - %3$s","I gceann %n bliain ar %1$s idir %2$s - %3$s","I gceann %n bliain ar %1$s idir %2$s - %3$s"],
     "Could not generate when statement" : "Níorbh fhéidir a ghiniúint nuair a ráiteas",
     "Every Day for the entire day" : "Gach Lá don lá ar fad",
     "Every Day for the entire day until %1$s" : "Gach Lá ar feadh an lae ar fad go dtí %1$s",
@@ -112,12 +122,27 @@ OC.L10N.register(
     "Every %1$d Years in %2$s on the %3$s between %4$s - %5$s until %6$s" : "Gach %1$d Bliain i %2$s ar an %3$s idir %4$s - %5$s go %6$s",
     "On specific dates for the entire day until %1$s" : "Ar dhátaí ar leith don lá iomlán go dtí %1$s",
     "On specific dates between %1$s - %2$s until %3$s" : "Ar dhátaí sonracha idir %1$s - %2$s go %3$s",
-    "In a %1$s on %2$s" : "I %1$s ar %2$s",
-    "In a %1$s on %2$s then on %3$s" : "I %1$s ar %2$s ansin ar %3$s",
-    "In a %1$s on %2$s then on %3$s and %4$s" : "I %1$s ar %2$s ansin ar %3$s agus %4$s",
-    "In %1$s %2$s on %3$s" : "I %1$s %2$s ar %3$s",
-    "In %1$s %2$s on %3$s then on %4$s" : "I %1$s %2$s ar %3$s ansin ar %4$s",
-    "In %1$s %2$s on %3$s then on %4$s and %5$s" : "I %1$s %2$s ar %3$s ansin ar %4$s agus %5$s",
+    "In the past on %1$s" : "San am a chuaigh thart ar %1$s",
+    "_In a minute on %1$s_::_In %n minutes on %1$s_" : ["I gceann nóiméid ar %1$s","I gceann %n nóiméad ar %1$s","I gceann %n nóiméad ar %1$s","I gceann %n nóiméad ar %1$s","I gceann %n nóiméad ar %1$s"],
+    "_In a hour on %1$s_::_In %n hours on %1$s_" : ["I gceann uair an chloig ar %1$s","I gceann %n uair ar %1$s","I gceann %n uair ar %1$s","I gceann %n uair ar %1$s","I gceann %n uair ar %1$s"],
+    "_In a day on %1$s_::_In %n days on %1$s_" : ["I gceann lá ar %1$s","I gceann %n lá ar %1$s","I gceann %n lá ar %1$s","I gceann %n lá ar %1$s","I gceann %n lá ar %1$s"],
+    "_In a week on %1$s_::_In %n weeks on %1$s_" : ["I gceann seachtaine ar %1$s","I gceann %n seachtain ar %1$s","I gceann %n seachtain ar %1$s","I gceann %n seachtain ar %1$s","I gceann %n seachtain ar %1$s"],
+    "_In a month on %1$s_::_In %n months on %1$s_" : ["I gceann míosa ar %1$s","I gceann %n mí ar %1$s","I gceann %n mí ar %1$s","I gceann %n mí ar %1$s","I gceann %n mí ar %1$s"],
+    "_In a year on %1$s_::_In %n years on %1$s_" : ["I gceann bliana ar %1$s","I gceann %n bliain ar %1$s","I gceann %n bliain ar %1$s","I gceann %n bliain ar %1$s","I gceann %n bliain ar %1$s"],
+    "In the past on %1$s then on %2$s" : "San am a chuaigh thart ar %1$s agus ansin ar %2$s",
+    "_In a minute on %1$s then on %2$s_::_In %n minutes on %1$s then on %2$s_" : ["I gceann nóiméid ar %1$s agus ansin ar %2$s","I gceann %n nóiméad ar %1$s ansin ar %2$s","I gceann %n nóiméad ar %1$s ansin ar %2$s","I gceann %n nóiméad ar %1$s ansin ar %2$s","I gceann %n nóiméad ar %1$s ansin ar %2$s"],
+    "_In a hour on %1$s then on %2$s_::_In %n hours on %1$s then on %2$s_" : ["I gceann uair an chloig ar %1$s agus ansin ar %2$s","I gceann %n uair an chloig ar %1$s ansin ar %2$s","I gceann %n uair an chloig ar %1$s ansin ar %2$s","I gceann %n uair an chloig ar %1$s ansin ar %2$s","I gceann %n uair an chloig ar %1$s ansin ar %2$s"],
+    "_In a day on %1$s then on %2$s_::_In %n days on %1$s then on %2$s_" : ["I gceann lá ar %1$s ansin ar %2$s","I gceann %n lá ar %1$s ansin ar %2$s","I gceann %n lá ar %1$s ansin ar %2$s","I gceann %n lá ar %1$s ansin ar %2$s","I gceann %n lá ar %1$s ansin ar %2$s"],
+    "_In a week on %1$s then on %2$s_::_In %n weeks on %1$s then on %2$s_" : ["I gceann seachtaine ar %1$s ansin ar %2$s","I gceann %n seachtain ar %1$s ansin ar %2$s","I gceann %n seachtain ar %1$s ansin ar %2$s","I gceann %n seachtain ar %1$s ansin ar %2$s","I gceann %n seachtain ar %1$s ansin ar %2$s"],
+    "_In a month on %1$s then on %2$s_::_In %n months on %1$s then on %2$s_" : ["I gceann míosa ar %1$s ansin ar %2$s","I gceann %n mí ar %1$s ansin ar %2$s","I gceann %n mí ar %1$s ansin ar %2$s","I gceann %n mí ar %1$s ansin ar %2$s","I gceann %n mí ar %1$s ansin ar %2$s"],
+    "_In a year on %1$s then on %2$s_::_In %n years on %1$s then on %2$s_" : ["I mbliain ar %1$s ansin ar %2$s","I gceann %n bliain ar %1$s ansin ar %2$s","I gceann %n bliain ar %1$s ansin ar %2$s","I gceann %n bliain ar %1$s ansin ar %2$s","I gceann %n bliain ar %1$s ansin ar %2$s"],
+    "In the past on %1$s then on %2$s and %3$s" : "San am a chuaigh thart ar %1$s ansin ar %2$s agus %3$s",
+    "_In a minute on %1$s then on %2$s and %3$s_::_In %n minutes on %1$s then on %2$s and %3$s_" : ["I gceann nóiméid ar %1$s ansin ar %2$s agus %3$s","I gceann %n nóiméad ar %1$s ansin ar %2$s agus %3$s","I gceann %n nóiméad ar %1$s ansin ar %2$s agus %3$s","I gceann %n nóiméad ar %1$s ansin ar %2$s agus %3$s","I gceann %n nóiméad ar %1$s ansin ar %2$s agus %3$s"],
+    "_In a hour on %1$s then on %2$s and %3$s_::_In %n hours on %1$s then on %2$s and %3$s_" : ["I gceann uair an chloig ar %1$s ansin ar %2$s agus %3$s","I gceann %n uair an chloig ar %1$s ansin ar %2$s agus %3$s","I gceann %n uair an chloig ar %1$s ansin ar %2$s agus %3$s","I gceann %n uair an chloig ar %1$s ansin ar %2$s agus %3$s","I gceann %n uair an chloig ar %1$s ansin ar %2$s agus %3$s"],
+    "_In a day on %1$s then on %2$s and %3$s_::_In %n days on %1$s then on %2$s and %3$s_" : ["I gceann lá ar %1$s ansin ar %2$s agus %3$s","I gceann %n lá ar %1$s ansin ar %2$s agus %3$s","I gceann %n lá ar %1$s ansin ar %2$s agus %3$s","I gceann %n lá ar %1$s ansin ar %2$s agus %3$s","I gceann %n lá ar %1$s ansin ar %2$s agus %3$s"],
+    "_In a week on %1$s then on %2$s and %3$s_::_In %n weeks on %1$s then on %2$s and %3$s_" : ["I gceann seachtaine ar %1$s ansin ar %2$s agus %3$s","I gceann %n seachtain ar %1$s ansin ar %2$s agus %3$s","I gceann %n seachtain ar %1$s ansin ar %2$s agus %3$s","I gceann %n seachtain ar %1$s ansin ar %2$s agus %3$s","I gceann %n seachtain ar %1$s ansin ar %2$s agus %3$s"],
+    "_In a month on %1$s then on %2$s and %3$s_::_In %n months on %1$s then on %2$s and %3$s_" : ["I gceann míosa ar %1$s ansin ar %2$s agus %3$s","I gceann %n mí ar %1$s ansin ar %2$s agus %3$s","I gceann %n mí ar %1$s ansin ar %2$s agus %3$s","I gceann %n mí ar %1$s ansin ar %2$s agus %3$s","I gceann %n mí ar %1$s ansin ar %2$s agus %3$s"],
+    "_In a year on %1$s then on %2$s and %3$s_::_In %n years on %1$s then on %2$s and %3$s_" : ["I mbliain ar %1$s ansin ar %2$s agus %3$s","I gceann %n bliain ar %1$s ansin ar %2$s agus %3$s","I gceann %n bliain ar %1$s ansin ar %2$s agus %3$s","I gceann %n bliain ar %1$s ansin ar %2$s agus %3$s","I gceann %n bliain ar %1$s ansin ar %2$s agus %3$s"],
     "Could not generate next recurrence statement" : "Níorbh fhéidir an chéad ráiteas atarlaithe eile a ghiniúint",
     "Cancelled: %1$s" : "Ar ceal: %1$s",
     "\"%1$s\" has been canceled" : "\"%1$s\" curtha ar ceal",
@@ -164,12 +189,12 @@ OC.L10N.register(
     "Second" : "Dara",
     "Third" : "Tríú",
     "Fourth" : "Ceathrú",
-    "Fifty" : "Caoga",
+    "Fifth" : "Cúigiú",
     "Last" : "Seo caite",
     "Second Last" : "Dara Deireanach",
     "Third Last" : "An Tríú Deireanach",
     "Fourth Last" : "Ceathrú Deireanach",
-    "Fifty Last" : "Caoga Deireanach",
+    "Fifth Last" : "An Cúigiú Deireanach",
     "Contacts" : "Teagmhálaithe",
     "{actor} created address book {addressbook}" : "chruthaigh {actor} leabhar seoltaí {addressbook}",
     "You created address book {addressbook}" : "Chruthaigh tú leabhar seoltaí {addressbook}",
@@ -207,7 +232,8 @@ OC.L10N.register(
     "Could not rename part file to final file, canceled by hook" : "Níorbh fhéidir páirtchomhad a athainmniú go comhad deiridh, curtha ar ceal le hook",
     "Could not rename part file to final file" : "Níorbh fhéidir páirtchomhad a athainmniú go dtí an comhad deiridh",
     "Failed to check file size: %1$s" : "Níorbh fhéidir méid an chomhaid a sheiceáil: %1$s",
-    "Could not open file" : "Níorbh fhéidir an comhad a oscailt",
+    "Could not open file: %1$s, file does seem to exist" : "Níorbh fhéidir comhad a oscailt: %1$s, is cosúil go bhfuil an comhad ann",
+    "Could not open file: %1$s, file doesn't seem to exist" : "Níorbh fhéidir comhad a oscailt: %1$s, is cosúil nach bhfuil an comhad ann",
     "Encryption not ready: %1$s" : "Níl an criptiúchán réidh: %1$s",
     "Failed to open file: %1$s" : "Níorbh fhéidir an comhad a oscailt: %1$s",
     "Failed to unlink: %1$s" : "Theip ar dhínascadh: %1$s",
@@ -224,6 +250,9 @@ OC.L10N.register(
     "Completed on %s" : "Críochnaithe ar %s",
     "Due on %s by %s" : "Dlite ar %s faoi %s",
     "Due on %s" : "Dlite ar %s",
+    "System Address Book" : "Leabhar Seoltaí Córais",
+    "The system address book contains contact information for all users in your instance." : "Tá faisnéis teagmhála i leabhar seoltaí an chórais do gach úsáideoir i do chás.",
+    "Enable System Address Book" : "Cumasaigh Leabhar Seoltaí an Chórais",
     "DAV system address book" : "Leabhar seoltaí córas DAV",
     "No outstanding DAV system address book sync." : "Níl sioncronú leabhar seoltaí córais DAV gan íoc.",
     "The DAV system address book sync has not run yet as your instance has more than 1000 users or because an error occurred. Please run it manually by calling \"occ dav:sync-system-addressbook\"." : "Níor rith sioncronú leabhar seoltaí an chórais DAV fós toisc go bhfuil níos mó ná 1000 úsáideoir ag do chás nó toisc gur tharla earráid. Rith de láimh é le do thoil trí ghlao a chur ar \"occ dav:sync-system-addressbook\".",
@@ -235,6 +264,10 @@ OC.L10N.register(
     "Calendars including events, details and attendees" : "Féilirí lena n-áirítear imeachtaí, sonraí agus lucht freastail",
     "Contacts and groups" : "Teagmhálaithe agus grúpaí",
     "WebDAV" : "WebDAV",
+    "Absence saved" : "Neamhláithreacht shábháil",
+    "Failed to save your absence settings" : "Theip ar do shocruithe asláithreachta a shábháil",
+    "Absence cleared" : "Neamhláithreacht glanta",
+    "Failed to clear your absence settings" : "Theip ar do shocruithe asláithreachta a ghlanadh",
     "First day" : "Céad lá",
     "Last day (inclusive)" : "Lá deiridh (san áireamh)",
     "Out of office replacement (optional)" : "Athsholáthar as oifig (roghnach)",
@@ -245,10 +278,9 @@ OC.L10N.register(
     "Long absence Message" : "Neamhláithreacht fada Teachtaireacht",
     "Save" : "Sábháil",
     "Disable absence" : "Díchumasaigh neamhláithreacht",
-    "Absence saved" : "Neamhláithreacht shábháil",
-    "Failed to save your absence settings" : "Theip ar do shocruithe asláithreachta a shábháil",
-    "Absence cleared" : "Neamhláithreacht glanta",
-    "Failed to clear your absence settings" : "Theip ar do shocruithe asláithreachta a ghlanadh",
+    "Failed to load availability" : "Theip ar infhaighteacht a lódáil",
+    "Saved availability" : "Infhaighteacht shábháilte",
+    "Failed to save availability" : "Theip ar infhaighteacht a shábháil",
     "Time zone:" : "Crios ama:",
     "to" : "chun",
     "Delete slot" : "Scrios sliotán",
@@ -258,13 +290,12 @@ OC.L10N.register(
     "Pick a start time for {dayName}" : "Roghnaigh am tosaithe le haghaidh {dayName}",
     "Pick a end time for {dayName}" : "Roghnaigh am críochnaithe le haghaidh {dayName}",
     "Automatically set user status to \"Do not disturb\" outside of availability to mute all notifications." : "Socraigh stádas úsáideora go huathoibríoch mar \"Ná cuir isteach\" taobh amuigh den infhaighteacht chun gach fógra a bhalbhú.",
-    "Failed to load availability" : "Theip ar infhaighteacht a lódáil",
-    "Saved availability" : "Infhaighteacht shábháilte",
-    "Failed to save availability" : "Theip ar infhaighteacht a shábháil",
     "Availability" : "Infhaighteacht",
     "If you configure your working hours, other people will see when you are out of office when they book a meeting." : "Má dhéanann tú do chuid uaireanta oibre a chumrú, feicfidh daoine eile nuair a bhíonn tú as oifig nuair a chuireann siad cruinniú in áirithe.",
     "Absence" : "Neamhláithreacht",
     "Configure your next absence period." : "Cumraigh do chéad tréimhse neamhláithreachta eile.",
+    "Also install the {calendarappstoreopen}Calendar app{linkclose}, or {calendardocopen}connect your desktop & mobile for syncing ↗{linkclose}." : "Suiteáil an {calendarappstoreopen}Féilire aip{linkclose} freisin, nó {calendardocopen}ceangail do dheasc & do ghutháin phóca le haghaidh sioncronaithe ↗{linkclose}.",
+    "Please make sure to properly set up {emailopen}the email server{linkclose}." : "Cinntigh le do thoil go socróidh tú {emailopen}an freastalaí ríomhphoist{linkclose} i gceart.",
     "Calendar server" : "Freastalaí féilire",
     "Send invitations to attendees" : "Seol cuirí chuig an lucht freastail",
     "Automatically generate a birthday calendar" : "Gin féilire lá breithe go huathoibríoch",
@@ -275,17 +306,23 @@ OC.L10N.register(
     "Send reminder notifications to calendar sharees as well" : "Seol fógraí meabhrúcháin chuig scaireanna féilire freisin",
     "Reminders are always sent to organizers and attendees." : "Seoltar meabhrúcháin chuig na heagraithe agus an lucht freastail i gcónaí.",
     "Enable notifications for events via push" : "Cumasaigh fógraí le haghaidh imeachtaí trí bhrú",
-    "Also install the {calendarappstoreopen}Calendar app{linkclose}, or {calendardocopen}connect your desktop & mobile for syncing ↗{linkclose}." : "Suiteáil an {calendarappstoreopen}Féilire aip{linkclose} freisin, nó {calendardocopen}ceangail do dheasc & do ghutháin phóca le haghaidh sioncronaithe ↗{linkclose}.",
-    "Please make sure to properly set up {emailopen}the email server{linkclose}." : "Cinntigh le do thoil go socróidh tú {emailopen}an freastalaí ríomhphoist{linkclose} i gceart.",
+    "Cancel" : "Cealaigh",
+    "Import" : "Iompórtáil",
+    "Error while saving settings" : "Earráid agus na socruithe á sábháil",
+    "Contact reset successfully" : "D'éirigh le hathshocrú teagmhála",
+    "Error while resetting contact" : "Earráid agus an teagmhálaí á athshocrú",
+    "Contact imported successfully" : "D'éirigh le hiompórtáil an teagmhálaí",
+    "Error while importing contact" : "Earráid agus an teagmhálaí á iompórtáil",
+    "Example Content" : "Ábhar Samplach",
+    "Set example content to be created on new user first login." : "Socraigh ábhar samplach le cruthú ar an gcéad logáil isteach úsáideora nua.",
+    "Import contact" : "Iompórtáil teagmhála",
+    "Reset to default contact" : "Athshocraigh go teagmhálaí réamhshocraithe",
+    "Import contacts" : "Teagmhálaithe a allmhairiú",
+    "Importing a new .vcf file will delete the existing default contact and replace it with the new one. Do you want to continue?" : "Má dhéantar comhad .vcf nua a iompórtáil, scriosfar an teagmhálaí réamhshocraithe atá ann cheana féin agus cuirfear an ceann nua ina ionad. Ar mhaith leat leanúint ar aghaidh?",
     "There was an error updating your attendance status." : "Tharla earráid agus do stádas freastail á nuashonrú.",
     "Please contact the organizer directly." : "Téigh i dteagmháil leis an eagraí go díreach le do thoil.",
     "Are you accepting the invitation?" : "An bhfuil tú ag glacadh leis an gcuireadh?",
     "Tentative" : "Sealadach",
-    "Your attendance was updated successfully." : "D'éirigh le do thinreamh a nuashonrú.",
-    "To-dos" : "Rudaí le déanamh",
-    "Time:" : "Am:",
-    "Invalid chunk name" : "Ainm smután neamhbhailí",
-    "Could not rename part file assembled from chunks" : "Níorbh fhéidir páirtchomhad a athainmniú as smután",
-    "If you configure your working hours, other users will see when you are out of office when they book a meeting." : "Má dhéanann tú d’uaireanta oibre a chumrú, feicfidh úsáideoirí eile nuair a bhíonn tú as oifig nuair a chuirfidh siad cruinniú in áirithe."
+    "Your attendance was updated successfully." : "D'éirigh le do thinreamh a nuashonrú."
 },
 "nplurals=5; plural=(n==1 ? 0 : n==2 ? 1 : n<7 ? 2 : n<11 ? 3 : 4);");
