@@ -72,7 +72,7 @@ OC.L10N.register(
     "Description: %s" : "Leírás: %s",
     "Where: %s" : "Hely: %s",
     "%1$s via %2$s" : "%1$s – %2$s",
-    "Could not generate when statement" : "Nem sikerlt létrehozni a mikor állítást",
+    "Could not generate when statement" : "Nem sikerült létrehozni amikor az állítást",
     "Every Day for the entire day" : "Minden Nap a teljes napra",
     "Every Day for the entire day until %1$s" : "Minden Nap a teljes napon eddig %1$s",
     "Every Day between %1$s - %2$s" : "Minden Nap %1$s - %2$sközött",
@@ -218,6 +218,10 @@ OC.L10N.register(
     "Calendars including events, details and attendees" : "Naptárak eseményekkel, részletekkel és résztvevőkkel",
     "Contacts and groups" : "Névjegyek és csoportok",
     "WebDAV" : "WebDAV",
+    "Absence saved" : "Távollét mentve",
+    "Failed to save your absence settings" : "Nem sikerlt a távolléti beállítások mentése",
+    "Absence cleared" : "Távollét törölve",
+    "Failed to clear your absence settings" : "Nem sikerült a távolléti beállítások törlése",
     "First day" : "Első nap",
     "Last day (inclusive)" : "Utols nap (beleértve)",
     "Out of office replacement (optional)" : "Távolléti helyettesítő (opcionális)",
@@ -228,10 +232,9 @@ OC.L10N.register(
     "Long absence Message" : "Hosszú távolléti állapot",
     "Save" : "Mentés",
     "Disable absence" : "Távollét tiltása",
-    "Absence saved" : "Távollét mentve",
-    "Failed to save your absence settings" : "Nem sikerlt a távolléti beállítások mentése",
-    "Absence cleared" : "Távollét törölve",
-    "Failed to clear your absence settings" : "Nem sikerült a távolléti beállítások törlése",
+    "Failed to load availability" : "Az elérhetőség betöltése sikertelen",
+    "Saved availability" : "Elérhetőség mentve",
+    "Failed to save availability" : "Az elérhetőség mentése sikertelen",
     "Time zone:" : "Időzóna:",
     "to" : "–",
     "Delete slot" : "Idősáv törlése",
@@ -241,13 +244,12 @@ OC.L10N.register(
     "Pick a start time for {dayName}" : "Válassz kezdő dátumot a {dayName}-hoz",
     "Pick a end time for {dayName}" : "Válassz vége dátumot a {dayName}-hoz",
     "Automatically set user status to \"Do not disturb\" outside of availability to mute all notifications." : "Az elérhetőségi időn túl, a felhasználói állapot automatikus beállítása „Ne zavarjanak” módba az összes értesítés némításához.",
-    "Failed to load availability" : "Az elérhetőség betöltése sikertelen",
-    "Saved availability" : "Elérhetőség mentve",
-    "Failed to save availability" : "Az elérhetőség mentése sikertelen",
     "Availability" : "Elérhetőség",
     "If you configure your working hours, other people will see when you are out of office when they book a meeting." : "Ha beállítja a munkaidejét, akkor más emberek a megbeszélések létrehozásakor látni fogják, hogy Ön mikor nem érhető el.",
     "Absence" : "Távollét",
     "Configure your next absence period." : "A követkeő távolléti periódus beállítása.",
+    "Also install the {calendarappstoreopen}Calendar app{linkclose}, or {calendardocopen}connect your desktop & mobile for syncing ↗{linkclose}." : "Telepítse a {calendarappstoreopen}Naptár alkalmazást{linkclose}, vagy {calendardocopen}csatlakoztassa asztali számítógépét és mobilját a szinkronizáláshoz ↗{linkclose}.",
+    "Please make sure to properly set up {emailopen}the email server{linkclose}." : "Ne felejtse el megfelelően beállítani az {emailopen}e-mail kiszolgálót{linkclose}.",
     "Calendar server" : "Naptárkiszolgáló",
     "Send invitations to attendees" : "Meghívó küldése a résztvevőknek",
     "Automatically generate a birthday calendar" : "Születésnapokat tartalmazó naptár automatikus létrehozása",
@@ -258,16 +260,13 @@ OC.L10N.register(
     "Send reminder notifications to calendar sharees as well" : "Emlékeztető értesítések küldése azoknak is, akikkel a naptár meg van osztva",
     "Reminders are always sent to organizers and attendees." : "Az értesítések mindig a szervezőknek és a résztvevőknek lesznek elküldve.",
     "Enable notifications for events via push" : "Leküldéses értesítések engedélyezése az eseményekhez",
-    "Also install the {calendarappstoreopen}Calendar app{linkclose}, or {calendardocopen}connect your desktop & mobile for syncing ↗{linkclose}." : "Telepítse a {calendarappstoreopen}Naptár alkalmazást{linkclose}, vagy {calendardocopen}csatlakoztassa asztali számítógépét és mobilját a szinkronizáláshoz ↗{linkclose}.",
-    "Please make sure to properly set up {emailopen}the email server{linkclose}." : "Ne felejtse el megfelelően beállítani az {emailopen}e-mail kiszolgálót{linkclose}.",
+    "Cancel" : "Mégse",
+    "Import" : "Importálás",
+    "Error while saving settings" : "Hiba a beállítások mentése során",
     "There was an error updating your attendance status." : "Hiba történt a részvételi állapotának frissítése során.",
     "Please contact the organizer directly." : "Vegye fel a kapcsolatot közvetlenül a szervezővel.",
     "Are you accepting the invitation?" : "Elfogadja az meghívást?",
     "Tentative" : "Feltételes",
-    "Your attendance was updated successfully." : "A részvétele frissítése sikeres.",
-    "Time:" : "Idő:",
-    "Could not open file" : "A fájl nem nyitható meg",
-    "Invalid chunk name" : "Érvénytelen darabnév",
-    "Could not rename part file assembled from chunks" : "Nem lehet átnevezni a darabokból összeállított részleges fájlt"
+    "Your attendance was updated successfully." : "A részvétele frissítése sikeres."
 },
 "nplurals=2; plural=(n != 1);");
