@@ -79,19 +79,41 @@ OC.L10N.register(
     "Organizer:" : "Organisator:",
     "Attendees:" : "Deelnemers:",
     "Title:" : "Titel:",
+    "When:" : "Wanneer:",
     "Location:" : "Locatie:",
     "Link:" : "Link:",
     "Accept" : "Accepteren",
     "Decline" : "Afwijzen",
     "More options …" : "Meer opties …",
     "More options at %s" : "Meer opties op %s",
+    "Monday" : "maandag",
+    "Tuesday" : "dinsdag",
+    "Wednesday" : "woensdag",
+    "Thursday" : "donderdag",
+    "Friday" : "vrijdag",
+    "Saturday" : "zaterdag",
+    "Sunday" : "zondag",
+    "January" : "Januari",
+    "February" : "Februari",
+    "March" : "Maart",
+    "April" : "April",
+    "May" : "Mei",
+    "June" : "Juni",
+    "July" : "Juli",
+    "August" : "Augustus",
+    "September" : "September",
+    "October" : "Oktober",
+    "November" : "November",
+    "December" : "December",
+    "First" : "Eerste",
+    "Last" : "Laatste",
     "Contacts" : "Contactpersonen",
     "{actor} created address book {addressbook}" : "{actor} creëerde adresboek {addressbook}",
     "You created address book {addressbook}" : "Je creëerde adresboek  {addressbook}",
     "{actor} deleted address book {addressbook}" : "{actor} verwijdede adresboek {addressbook}",
     "You deleted address book {addressbook}" : "Je verwijderde adresboek  {addressbook}",
     "{actor} updated address book {addressbook}" : "{actor} wijzigde adresboek {addressbook}",
-    "You updated address book {addressbook}" : "Je wijzigde adresboek  {addressbook}",
+    "You updated address book {addressbook}" : "Je wijzigde adresboek {addressbook}",
     "{actor} shared address book {addressbook} with you" : "{actor} deelde adresboek {addressbook} met jou",
     "You shared address book {addressbook} with {user}" : "Jij deelde adresboek {addressbook} met {user}",
     "{actor} shared address book {addressbook} with {user}" : "{actor} deelde adresboek {addressbook} met {user}",
@@ -99,7 +121,7 @@ OC.L10N.register(
     "You unshared address book {addressbook} from {user}" : "Je stopte met delen adresboek {addressbook} van {user}",
     "{actor} unshared address book {addressbook} from {user}" : " stopte met delen adresboek {addressbook} van {user}",
     "{actor} unshared address book {addressbook} from themselves" : "{actor} stopte het delen van het adresboek {addressbook} van zichzelf",
-    "You shared address book {addressbook} with group {group}" : "Je deelde adresboek {addressbook } met groep {group}",
+    "You shared address book {addressbook} with group {group}" : "Je deelde adresboek {addressbook} met groep {group}",
     "{actor} shared address book {addressbook} with group {group}" : "{actor} deelde adresboek {addressbook} met groep {group}",
     "You unshared address book {addressbook} from group {group}" : "Je stopte het delen van adresboek {addressbook} van groep {group}",
     "{actor} unshared address book {addressbook} from group {group}" : "{actor} stopte het delen van adresboek {addressbook} van groep {group}",
@@ -116,7 +138,6 @@ OC.L10N.register(
     "Could not rename part file to final file, canceled by hook" : "Kon bestandsdeel niet hernoemen naar definitief bestand, geannuleerd door hook",
     "Could not rename part file to final file" : "Kon bestandsdeel niet hernoemen naar definitief bestand",
     "Failed to check file size: %1$s" : "Kon bestandsomvang niet controleren: %1$s",
-    "Could not open file" : "Kan het bestand niet openen",
     "Encryption not ready: %1$s" : "Versleuteling niet gereed: %1$s",
     "Failed to open file: %1$s" : "Kon het bestand %1$s niet openen",
     "Failed to unlink: %1$s" : "Kon link niet verwijderen: %1$s",
@@ -137,23 +158,19 @@ OC.L10N.register(
     "Contacts and groups" : "Contactpersonen en groepen",
     "WebDAV" : "WebDAV",
     "Save" : "Opslaan",
+    "Failed to load availability" : "Kon beschikbaarheid niet laden",
     "Time zone:" : "Tijdzone:",
     "to" : "aan",
     "Delete slot" : "Verwijder slot",
     "No working hours set" : "Geen werkuren ingesteld",
     "Add slot" : "Voeg slot toe",
-    "Monday" : "maandag",
-    "Tuesday" : "dinsdag",
-    "Wednesday" : "woensdag",
-    "Thursday" : "donderdag",
-    "Friday" : "vrijdag",
-    "Saturday" : "zaterdag",
-    "Sunday" : "zondag",
+    "Weekdays" : "Weekdagen",
     "Automatically set user status to \"Do not disturb\" outside of availability to mute all notifications." : "Stel de gebruikersstatus automatisch in op \"Niet storen\" buiten de beschikbaarheid om alle meldingen te dempen.",
-    "Failed to load availability" : "Kon beschikbaarheid niet laden",
     "Availability" : "Beschikbaarheid",
     "Absence" : "Afwezigheid",
     "Configure your next absence period." : "Configureer uw volgende afwezigheidsperiode.",
+    "Also install the {calendarappstoreopen}Calendar app{linkclose}, or {calendardocopen}connect your desktop & mobile for syncing ↗{linkclose}." : "Installeer ook de {calendarappstoreopen}Agenda app{linkclose}, of {calendardocopen}verbind je desktop & mobiel voor synchronisatie ↗{linkclose}.",
+    "Please make sure to properly set up {emailopen}the email server{linkclose}." : "Zorg ervoor dat je de {emailopen}de e-mailserver{linkclose} correct instelt.",
     "Calendar server" : "Agendaserver",
     "Send invitations to attendees" : "Verzend uitnodigingen naar deelnemers",
     "Automatically generate a birthday calendar" : "Genereer verjaardagskalender automatisch",
@@ -162,17 +179,13 @@ OC.L10N.register(
     "Send notifications for events" : "Versturen meldingen voor afspraken",
     "Notifications are sent via background jobs, so these must occur often enough." : "Meldingen worden via achtergrondtaken verstuurd, dus die moeten vaak genoeg plaatsvinden.",
     "Enable notifications for events via push" : "Inschakelen push-melding voor afspraken",
-    "Also install the {calendarappstoreopen}Calendar app{linkclose}, or {calendardocopen}connect your desktop & mobile for syncing ↗{linkclose}." : "Installeer ook de {calendarappstoreopen}Agenda app{linkclose}, of {calendardocopen}verbind je desktop & mobiel voor synchronisatie ↗{linkclose}.",
-    "Please make sure to properly set up {emailopen}the email server{linkclose}." : "Zorg ervoor dat je de {emailopen}de e-mailserver{linkclose} correct instelt.",
+    "Cancel" : "Annuleren",
+    "Import" : "Import",
+    "Error while saving settings" : "Probleem tijdens het opslaan van instellingen",
     "There was an error updating your attendance status." : "Er trad een fout op bij het bijwerken van je deelnamestatus.",
     "Please contact the organizer directly." : "Neem rechtstreeks contact op met de organisator.",
     "Are you accepting the invitation?" : "Neem je de uitnodiging aan?",
     "Tentative" : "Onder voorbehoud",
-    "Your attendance was updated successfully." : "Je deelname is succesvol bijgewerkt.",
-    "To-dos" : "Taken",
-    "Time:" : "Tijd:",
-    "Invalid chunk name" : "Ongeldige chunknaam",
-    "Could not rename part file assembled from chunks" : "Kon een bestandsdeel dat uit chunks is samengesteld niet hernoemen",
-    "If you configure your working hours, other users will see when you are out of office when they book a meeting." : "Als je je werkuren instelt kunnen andere gebruikers zien wanneer je niet beschikbaar bent als ze een meeting willen plannen."
+    "Your attendance was updated successfully." : "Je deelname is succesvol bijgewerkt."
 },
 "nplurals=2; plural=(n != 1);");
