@@ -309,14 +309,20 @@ OC.L10N.register(
     "Cancel" : "Zrušiť",
     "Import" : "Import",
     "Error while saving settings" : "Chyba pri ukladaní nastavení",
+    "Contact reset successfully" : "Kontakt bol úspešne resetovaný",
+    "Error while resetting contact" : "Chyba počas resetovania kontaktu ",
+    "Contact imported successfully" : "Kontakt bol úspešne importovaný",
+    "Error while importing contact" : "Chyba pri importovaní kontaktu",
+    "Example Content" : "Príklad Obsahu",
+    "Set example content to be created on new user first login." : "Nastavte vzorový obsah, ktorý sa vytvorí pri prvom prihlásení nového používateľa.",
+    "Import contact" : "Importovať kontakt",
+    "Reset to default contact" : "Resetovať na predvolený kontakt",
+    "Import contacts" : "Importovať kontakty",
+    "Importing a new .vcf file will delete the existing default contact and replace it with the new one. Do you want to continue?" : "Importovaním nového súboru .vcf sa vymaže existujúci predvolený kontakt a nahradí sa novým. Chcete pokračovať?",
     "There was an error updating your attendance status." : "Nastal problém pri aktualizácii Vašej účasti.",
     "Please contact the organizer directly." : "Prosím kontaktujte priamo organizátora.",
     "Are you accepting the invitation?" : "Príjmate pozvánku?",
     "Tentative" : "Neistý",
-    "Your attendance was updated successfully." : "Vaša účasť bola aktualizovaná úspešne.",
-    "Time:" : "Čas:",
-    "Could not open file" : "Súbor sa nepodarilo otvoriť",
-    "Invalid chunk name" : "Neplatný názov bloku",
-    "Could not rename part file assembled from chunks" : "Nepodarilo sa premenovať dočasný súbor vytvorený z blokov"
+    "Your attendance was updated successfully." : "Vaša účasť bola aktualizovaná úspešne."
 },
 "nplurals=4; plural=(n % 1 == 0 && n == 1 ? 0 : n % 1 == 0 && n >= 2 && n <= 4 ? 1 : n % 1 != 0 ? 2: 3);");
