@@ -250,6 +250,9 @@ OC.L10N.register(
     "Completed on %s" : "%s tarihinde tamamlandı",
     "Due on %s by %s" : "%s tarihine kadar %s tarafından",
     "Due on %s" : "%s tarihine kadar",
+    "System Address Book" : "Sistem adres defteri",
+    "The system address book contains contact information for all users in your instance." : "Sistem adres defterinde, kopyanızdaki tüm kullanıcıların iletişim bilgileri bulunur.",
+    "Enable System Address Book" : "Sistem adres defteri kullanılsın",
     "DAV system address book" : "DAV sistem adres defteri",
     "No outstanding DAV system address book sync." : "Bekleyen bir DAV sistemi adres defteri eşitlemesi yok.",
     "The DAV system address book sync has not run yet as your instance has more than 1000 users or because an error occurred. Please run it manually by calling \"occ dav:sync-system-addressbook\"." : "Kopyanızda 1000 üzerinde kullanıcı olduğundan ya da bir sorun çıktığından DAV sistemi adres defteri eşitlemesi henüz yapılmamış. Lütfen \"occ dav:sync-system-addressbook\" komutunu yürüterek el ile eşitleyin.",
@@ -296,21 +299,30 @@ OC.L10N.register(
     "Calendar server" : "Takvim sunucusu",
     "Send invitations to attendees" : "Katılımcılara davet gönder",
     "Automatically generate a birthday calendar" : "Doğum günü takvimi otomatik oluşturulsun",
-    "Birthday calendars will be generated by a background job." : "Bu seçenek kullanıma alındığında, doğum günü takvimi arka plan görevi olarak oluşturulur.",
-    "Hence they will not be available immediately after enabling but will show up after some time." : "Kullanıma alındıktan hemen sonra görüntülenmez, bir süre sonra görüntülenir.",
+    "Birthday calendars will be generated by a background job." : "Bu seçenek etkinleştirildiğinde, doğum günü takvimi arka plan görevi olarak oluşturulur.",
+    "Hence they will not be available immediately after enabling but will show up after some time." : "Etkinleştirildikten hemen sonra görüntülenmez, bir süre sonra görüntülenir.",
     "Send notifications for events" : "Etkinlik bildirimleri gönderilsin",
     "Notifications are sent via background jobs, so these must occur often enough." : "Bildirimler arka plan işlemleri tarafından gönderilir. Bu nedenle sıklık değeri uygun şekilde ayarlanmalıdır.",
     "Send reminder notifications to calendar sharees as well" : "Takvim paylaşımlarına da hatırlatma bildirimleri gönderilsin",
-    "Reminders are always sent to organizers and attendees." : "Bu seçenek kullanıma alındığında, hatırlatıcılar her zaman düzenleyici ve katılımcılara gönderilir.",
+    "Reminders are always sent to organizers and attendees." : "Bu seçenek etkinleştirildiğinde, hatırlatıcılar her zaman düzenleyici ve katılımcılara gönderilir.",
     "Enable notifications for events via push" : "Anında etkinlik bildirimlerini aç",
+    "Cancel" : "İptal",
+    "Import" : "İçe aktar",
+    "Error while saving settings" : "Ayarlar kaydedilirken sorun çıktı",
+    "Contact reset successfully" : "Kişi sıfırlandı",
+    "Error while resetting contact" : "Kişi sıfırlanırken sorun çıktı",
+    "Contact imported successfully" : "Kişi içe aktarıldı",
+    "Error while importing contact" : "Kişi içe aktarılırken sorun çıktı",
+    "Example Content" : "Örnek içerik",
+    "Set example content to be created on new user first login." : "Yeni kullanıcının ilk oturum açmasında oluşturulacak örnek içeriği ayarlayın.",
+    "Import contact" : "Kişiyi içe aktar",
+    "Reset to default contact" : "Varsayılan kişiye sıfırla",
+    "Import contacts" : "Kişileri içe aktar",
+    "Importing a new .vcf file will delete the existing default contact and replace it with the new one. Do you want to continue?" : "Yeni bir .vcf dosyasını içe aktarmak, var olan varsayılan kişiyi siler ve yenisiyle değiştirir. İlerlemek istiyor musunuz?",
     "There was an error updating your attendance status." : "Katılım durumunuz güncellenirken bir sorun çıktı.",
     "Please contact the organizer directly." : "Lütfen düzenleyici ile doğrudan görüşün.",
     "Are you accepting the invitation?" : "Daveti kabul ediyor musunuz?",
     "Tentative" : "Kesin değil",
-    "Your attendance was updated successfully." : "Katılımınız güncellendi.",
-    "Time:" : "Zaman:",
-    "Could not open file" : "Dosya açılamadı",
-    "Invalid chunk name" : "Parça adı geçersiz",
-    "Could not rename part file assembled from chunks" : "Parçalardan oluşturulan parça dosyası yeniden adlandırılamadı "
+    "Your attendance was updated successfully." : "Katılımınız güncellendi."
 },
 "nplurals=2; plural=(n > 1);");
