@@ -1,13 +1,8 @@
 OC.L10N.register(
     "federatedfilesharing",
     {
-    "Do you want to add the remote share {name} from {owner}@{remote}?" : "{owner}@{remote} konumundan {name} uzak paylaşımını eklemek istiyor musunuz?",
-    "Remote share" : "Uzak paylaşım",
-    "Remote share password" : "Uzak paylaşım parolası",
-    "Cancel" : "İptal",
-    "Add remote share" : "Uzak paylaşım ekle",
     "Invalid Federated Cloud ID" : "Birleşik bulut kimliği geçersiz",
-    "Server to server sharing is not enabled on this server" : "Bu sunucuda sunucudan sunucuya paylaşım etkin değil",
+    "Server to server sharing is not enabled on this server" : "Bu sunucuda, sunucudan sunucuya paylaşım özelliği etkin değil",
     "Couldn't establish a federated share." : "Birleşik bir paylaşım oluşturulamadı.",
     "Couldn't establish a federated share, maybe the password was wrong." : "Birleşik bir paylaşım oluşturulamadı. Parola yanlış olabilir.",
     "Federated Share request sent, you will receive an invitation. Check your notifications." : "Birleşik paylaşım isteği gönderildi. Bir davet alacaksınız. Bildirimlerinizi denetleyin.",
@@ -28,38 +23,49 @@ OC.L10N.register(
     "Sharing" : "Paylaşım",
     "Federated file sharing" : "Birleşik dosya paylaşımı",
     "Provide federated file sharing across servers" : "Sunucular arasında birleşik dosya paylaşımı yapılmasını sağlar",
+    "Confirm data upload to lookup server" : "Arama sunucusuna veri yüklemeyi onaylayın",
+    "When enabled, all account properties (e.g. email address) with scope visibility set to \"published\", will be automatically synced and transmitted to an external system and made available in a public, global address book." : "Bu seçenek etkinleştirildiğinde, kapsam görünürlüğü \"yayınlanmış\" olarak ayarlanmış tüm hesap özellikleri (e-posta adresi gibi) otomatik olarak eşitlenerek ve bir dış sisteme iletilerek, herkese açık, genel bir adres defterinde yayınlanır.",
+    "Disable upload" : "Yüklenmesin",
+    "Enable data upload" : "Veriler yüklensin",
+    "Confirm querying lookup server" : "Arama sunucusu sorgulanabilsin",
+    "When enabled, the search input when creating shares will be sent to an external system that provides a public and global address book." : "Bu seçenek etkinleştirildiğinde, paylaşım oluştururken arama kaydı, herkese açık ve genel bir adres defteri sunan bir dış sisteme gönderilir.",
+    "This is used to retrieve the federated cloud ID to make federated sharing easier." : "Birleşik paylaşımı kolaylaştırmak için birleşik bulut kimliğini almakta kullanılır.",
+    "Moreover, email addresses of users might be sent to that system in order to verify them." : "Ayrıca, kullanıcıların e-posta adresleri onları doğrulamak için bu sisteme gönderilebilir.",
+    "Disable querying" : "Sorgulanamasın",
+    "Enable querying" : "Sorgulansın",
+    "Unable to update federated files sharing config" : "Birleşik dosya paylaşımı yapılandırması güncellenemedi",
     "Adjust how people can share between servers. This includes shares between people on this server as well if they are using federated sharing." : "Kişilerin sunucular arasındaki paylaşım yöntemini ayarlayın. Bu yöntem, bu sunucuda bulunan ve birleşik paylaşım kullanan kişiler arasındaki paylaşımları da belirler.",
     "Allow people on this server to send shares to other servers (this option also allows WebDAV access to public shares)" : "Bu sunucudaki kişiler diğer sunuculara paylaşım gönderebilsin (herkese açık paylaşımlara WebDAV erişimi de sağlar)",
     "Allow people on this server to receive shares from other servers" : "Bu sunucudaki kişiler diğer sunuculardan paylaşım alabilsin",
     "Allow people on this server to send shares to groups on other servers" : "Bu sunucudaki kişiler diğer sunuculardaki gruplara paylaşım gönderebilsin",
     "Allow people on this server to receive group shares from other servers" : "Bu sunucudaki kişiler diğer sunuculardaki grup paylaşımlarını alabilsin",
+    "The lookup server is only available for global scale." : "Arama sunucusu yalnızca genel ölçekte kullanılabilir.",
     "Search global and public address book for people" : "Genel ve herkese açık adres defterindeki kişiler aranabilsin",
     "Allow people to publish their data to a global and public address book" : "Kişiler bilgilerini genel ve herkese açık bir adres defterinde paylaşabilsin",
-    "Unable to update federated files sharing config" : "Birleşik dosya paylaşımı yapılandırması güncellenemedi",
-    "Federated Cloud" : "Birleşik bulut",
-    "You can share with anyone who uses a Nextcloud server or other Open Cloud Mesh (OCM) compatible servers and services! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "Nextcloud ya da Open Cloud Mesh (OCM) ile uyumlu sunucu ve hizmetler ile paylaşım yapılabilir. Paylaşım penceresine person@cloud.example.com gibi birleşik bulut kimliğini yazmanız yeterlidir.",
-    "Your Federated Cloud ID:" : "Birleşik bulut kimliğiniz:",
-    "Share it so your friends can share files with you:" : "Paylaşın, böylece arkadaşlarınız da sizinle dosya paylaşabilir:",
-    "Facebook" : "Facebook",
-    "Twitter" : "Twitter",
-    "Diaspora" : "Diaspora",
-    "Add to your website" : "Sitenize ekleyin",
-    "Share with me via Nextcloud" : "Benimle Nextcloud üzerinden paylaşın",
-    "HTML Code:" : "HTML kodu:",
+    "Trusted federation" : "Güvenilen birleşim",
+    "Automatically accept shares from trusted federated accounts and groups by default" : "Varsayılan olarak güvenilir birleşim hesaplarından ve gruplardan gelen paylaşımlar otomatik olarak kabul edilsin",
     "Share with me through my #Nextcloud Federated Cloud ID, see {url}" : "#Nextcloud birleşik bulut kimliğim ile paylaş,  {url} adresine bakın",
     "Share with me through my #Nextcloud Federated Cloud ID" : "#Nextcloud birleşik bulut kimliğim üzerinden benimle paylaş",
     "Cloud ID copied to the clipboard" : "Bulut kimliği panoya kopyalandı",
     "Copy to clipboard" : "Panoya kopyala",
-    "Clipboard is not available" : "Pano kullanılamıyor",
+    "Clipboard not available. Please copy the cloud ID manually." : "Pano kullanılamıyor. Lütfen bulut kimliğini el ile kopyalayın.",
     "Copied!" : "Kopyalandı!",
-    "Sharing %1$s failed, because this item is already shared with user %2$s" : "%1$s ögesi %2$s kullanıcısı ile zaten paylaşılmış olduğundan paylaşılamadı",
-    "Not allowed to create a federated share with the same user" : "Aynı kullanıcı ile bir birleşik paylaşım oluşturulamaz",
-    "Adjust how people can share between servers. This includes shares between users on this server as well if they are using federated sharing." : "Kullanıcıların sunucular arasındaki paylaşım yöntemini ayarlayın. Bu yöntem, bu sunucuda bulunan ve birleşik paylaşım kullanan kullanıcılar arasındaki paylaşımları da belirler.",
-    "Allow users on this server to send shares to other servers (this option also allows WebDAV access to public shares)" : "Bu sunucudaki kullanıcılar diğer sunuculara paylaşım gönderebilsin (herkese açık paylaşımlara WebDAV erişimi de sağlar)",
-    "Allow users on this server to receive shares from other servers" : "Bu sunucudaki kullanıcılar diğer sunuculardan paylaşım alabilsin",
-    "Allow users on this server to send shares to groups on other servers" : "Bu sunucudaki kullanıcılar diğer sunuculardaki gruplara paylaşım gönderebilsin",
-    "Allow users on this server to receive group shares from other servers" : "Bu sunucudaki kullanıcılar diğer sunuculardaki grup paylaşımlarını alabilsin",
-    "Search global and public address book for users" : "Genel ve herkese açık adres defterindeki kullanıcılar aranabilsin",
-    "Allow users to publish their data to a global and public address book" : "Kullanıcıların bilgilerini genel ve herkese açık bir adres defterinde paylaşabilsin"
+    "Federated Cloud" : "Birleşik bulut",
+    "You can share with anyone who uses a Nextcloud server or other Open Cloud Mesh (OCM) compatible servers and services! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "Nextcloud ya da Open Cloud Mesh (OCM) ile uyumlu sunucu ve hizmetler ile paylaşım yapılabilir. Paylaşım penceresine person@cloud.example.com gibi birleşik bulut kimliğini yazmanız yeterlidir.",
+    "Your Federated Cloud ID" : "Birleşik bulut kimliğiniz",
+    "Share it so your friends can share files with you:" : "Paylaşın, böylece arkadaşlarınız da sizinle dosya paylaşabilir:",
+    "Facebook" : "Facebook",
+    "X (formerly Twitter)" : "X (eski Twitter)",
+    "formerly Twitter" : "eski Twitter",
+    "Mastodon" : "Mastodon",
+    "Add to your website" : "Sitenize ekleyin",
+    "Share with me via Nextcloud" : "Benimle Nextcloud üzerinden paylaşın",
+    "HTML Code:" : "HTML kodu:",
+    "Cancel" : "İptal",
+    "Add remote share" : "Uzak paylaşım ekle",
+    "Remote share" : "Uzak paylaşım",
+    "Do you want to add the remote share {name} from {owner}@{remote}?" : "{owner}@{remote} konumundan {name} uzak paylaşımını eklemek istiyor musunuz?",
+    "Remote share password" : "Uzak paylaşım parolası",
+    "Incoming share could not be processed" : "Gelen paylaşım işlenemedi"
 },
 "nplurals=2; plural=(n > 1);");
