@@ -70,8 +70,6 @@ OC.L10N.register(
     "Transferred from %1$s on %2$s" : "تم النقل من %1$s في%2$s",
     "Files compatibility" : "توافقية الملفات",
     "Allow to restrict filenames to ensure files can be synced with all clients. By default all filenames valid on POSIX (e.g. Linux or macOS) are allowed." : "السماح بتقييد أسماء الملفات لضمان إمكانية مزامنة الملفات مع جميع العملاء. بشكل افتراضي، يُسمح بجميع أسماء الملفات الصالحة على POSIX (مثل Linux أو macOS).",
-    "After enabling the Windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "بعد تمكين أسماء الملفات المتوافقة مع نظام التشغيل Windows، لا يمكن تعديل الملفات الموجودة بعد الآن ولكن يمكن إعادة تسميتها بأسماء جديدة صالحة بواسطة مالكها.",
-    "It is also possible to migrate files automatically after enabling this setting, please refer to the documentation about the occ command." : "من الممكن أيضًا ترحيل الملفات تلقائيًا بعد تمكين هذا الإعداد، يرجى الرجوع إلى الوثائق المتعلقة بأمر occ.",
     "Enforce Windows compatibility" : "فرض التوافق مع ويندوز",
     "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity." : "سيؤدي هذا إلى حظر أسماء الملفات غير الصالحة على أنظمة Windows؛ مثل استخدام الأسماء المحجوزة أو الأحرف الخاصة. لكن هذا لن يفرض توافق حساسية الحالة.",
     "File Management" : "إدارة الملفات",
@@ -97,19 +95,16 @@ OC.L10N.register(
     "Renamed \"{oldName}\" to \"{newName}\"" : "تمت إعادة تسمية \"{oldName}\" إلى \"{newName}\"",
     "Rename file" : "إعادة تسمية الملف",
     "Folder" : "مجلد",
-    "Unknown file type" : "نوع ملف غير معروف",
     "Pending" : "قيد الانتظار",
     "Unknown date" : "تاريخ غير معروف",
     "Clear filter" : "إزالة التصفية",
     "Modified" : "التعديل",
-    "Search everywhere" : "البحث الشامل",
     "Type" : "النوع",
     "Active filters" : "فلاتر نشطة",
     "Remove filter" : "إزالة عامل التصفية ",
     "Total rows summary" : "ملخص مجموع الأسطر",
     "Toggle selection for all files and folders" : "تبديل الاختيار لكل الملفات و المجلدات",
     "Name" : "الاسم",
-    "File type" : "نوع الملف",
     "Size" : "الحجم",
     "\"{displayName}\" failed on some elements" : "\"{displayName}\" فشل في بعض العناصر",
     "\"{displayName}\" batch action executed successfully" : "\"{displayName}\" حزمة الأوامر تم تنفيذها بنجاح",
@@ -121,8 +116,7 @@ OC.L10N.register(
     "Column headers with buttons are sortable." : "ترويسات الأعمدة ذات الأزرار قابلة للترتيب.",
     "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "لم يتم عرض هذه القائمة بالكامل لأسباب تتعلق بالأداء. سيتم عرض الملفات تباعاً أثناء التنقل عبر القائمة.",
     "File not found" : "تعذر العثور على الملف",
-    "_{count} selected_::_{count} selected_" : ["{count} تمّ تحديده","{count} تمّ تحديده","{count} تمّ تحديده","{count} تمّ تحديده","{count} تمّ تحديده","{count} تمّ تحديده"],
-    "Search globally" : "بحث عام",
+    "{count} selected" : "{count} تم تحديده",
     "{usedQuotaByte} used" : "{usedQuotaByte} مستخدمة",
     "{used} of {quota} used" : "{used} من {quota} مستخدم",
     "{relative}% used" : "{relative}% مستخدمة",
@@ -177,6 +171,7 @@ OC.L10N.register(
     "No files in here" : "لا توجد ملفات هنا ",
     "Upload some content or sync with your devices!" : "ارفع بعض المحتوى أو قم بالمزامنة مع أجهزتك!",
     "Go back" : "العودة",
+    "Filter file names …" : "فلترة أسماء الملفات ...",
     "Views" : "مشاهدات",
     "Files settings" : "إعدادات الملفات",
     "Your files" : "ملفاتك",
@@ -185,13 +180,11 @@ OC.L10N.register(
     "The file could not be found or you do not have permissions to view it. Ask the sender to share it." : "إمّا أن الملف غير موجود أو أنك لا تمتلك الصلاحية لعرضه. أُطلُب من المُرسل أن يتشاركه معك.",
     "Clipboard is not available" : "الحافظة غير متاحة",
     "WebDAV URL copied to clipboard" : "تم نسخ WebDAV URL إلى الحافظة",
-    "All files" : "كل الملفات",
-    "Personal files" : "ملفات شخصية",
     "Sort favorites first" : "فرز المفضلة أولا",
     "Sort folders before files" : "فرز المجلدات قبل الملفات",
     "Show hidden files" : "عرض الملفات المخفية",
-    "Show file type column" : "عرض عمود نوع الملف",
     "Crop image previews" : "اقتصاص صورة العروض",
+    "Enable the grid view" : "تمكين العرض الشبكي",
     "Enable folder tree" : "تمكين شجرة المجلدات",
     "Additional settings" : "الإعدادات المتقدمة",
     "WebDAV" : "WebDAV",
@@ -226,7 +219,6 @@ OC.L10N.register(
     "Show those shortcuts" : "أعرُض تلك الاختصارات",
     "You" : "أنت",
     "Shared multiple times with different people" : "تمّت مشاركته عدة مرات مع أشخاص متعددين",
-    "Unable to change the favorite state of the file" : "تعذّر تغيير حالة المُفضَّلة للملف",
     "Error while loading the file data" : "خطأ اثناء تحميل بيانات الملف",
     "Owner" : "المالك",
     "Remove from favorites" : "إزالة من المفضلة",
@@ -267,11 +259,8 @@ OC.L10N.register(
     "_You are about to delete {count} item_::_You are about to delete {count} items_" : ["أنت على وشك أن تحذف {count} عنصراً","أنت على وشك أن تحذف {count} عنصراً","أنت على وشك أن تحذف {count} عنصراً","أنت على وشك أن تحذف {count} عناصر","أنت على وشك أن تحذف {count} عناصر","أنت على وشك أن تحذف {count} عنصراً"],
     "Confirm deletion" : "تأكيد الحذف",
     "Cancel" : "إلغاء",
-    "Download" : "تنزيل",
     "Moving \"{source}\" to \"{destination}\" …" : "نقل \"{source}\" إلى \"{destination}\" …",
     "Copying \"{source}\" to \"{destination}\" …" : "نسخ \"{source}\" إلى \"{destination}\" …",
-    "Destination is not a folder" : "الوجهة ليست مجلد",
-    "This file/folder is already in that directory" : "هذا الملف/المجلد موجود سلفاً في ذلك المجلد",
     "You cannot move a file/folder onto itself or into a subfolder of itself" : "لا يمكنك نقل ملف/مجلد إلى نفسه أو إلى مجلد فرعي منه",
     "(copy)" : "(نسخ)",
     "(copy %n)" : "(نسخ %n)",
@@ -333,9 +322,6 @@ OC.L10N.register(
     "Files moved successfully" : "تمّ نقل الملفات بنجاح",
     "Conflicts resolution skipped" : "تمّ تخطّي حلّ التعارضات",
     "Upload cancelled" : "تمّ إلغاء الرفع",
-    "Could not rename \"{oldName}\", it does not exist any more" : "تعذر إعادة تسمية \"{oldName}\"، لم يعد موجودًا",
-    "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "الاسم \"{newName}\" مستعمل سلفاً في المجلد\"{dir}\". إختر اسماً آخر رجاءً.",
-    "Could not rename \"{oldName}\"" : "تعذرت إعادة تسمية \"{oldName}\"",
     "This operation is forbidden" : "هذه العملية ممنوعة ",
     "This directory is unavailable, please check the logs or contact the administrator" : "هذا المجلد غير متوفر، الرجاء مراجعة سجل الحركات أو الاتصال بمشرف النظام",
     "Storage is temporarily not available" : "وحدة التخزين غير متوفرة",
@@ -350,8 +336,10 @@ OC.L10N.register(
     "List of favorite files and folders." : "قائمة بالملفات و المجلدات المُفضّلة.",
     "No favorites yet" : "ليس لديك ملفات مفضلة",
     "Files and folders you mark as favorite will show up here" : "الملفات والمجلدات التي حددتها كمفضلة سوف تظهر هنا ",
+    "All files" : "كل الملفات",
     "List of your files and folders." : "قائمة بملفاتك و مجلداتك",
     "All folders" : "كل المجلدات",
+    "Personal files" : "ملفات شخصية",
     "List of your files and folders that are not shared." : "قائمة بالملفات و المجلدات التي لم تتم مشاركتها.",
     "No personal files found" : "لا توجد أي ملفات شخصية",
     "Files that are not shared will show up here." : "الملفات التي لم تتم مشاركتها يتم عرضها هنا",
@@ -359,12 +347,12 @@ OC.L10N.register(
     "List of recently modified files and folders." : "قائمة بالملفات والمجلدات التي تمّ تعديلها مؤخراً.",
     "No recently modified files" : "لا توجد أي ملفات تمّ تعديلها مؤخراً",
     "Files and folders you recently modified will show up here." : "الملفات و المجلدات التي تمّ تعديلها مؤخراً ستظهر هنا.",
-    "Search" : "بحث",
     "No entries found in this folder" : "لا يوجد مدخلات في هذا المجلد ",
     "Select all" : "تحديد الكل ",
     "Upload too large" : "حجم الرفع أعلى من المسموح",
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "حجم الملفات التي تريد رفعها أعلى من المسموح على الخادم.",
     "File could not be found" : "لم يتم العثور على الملف",
+    "Download" : "تنزيل",
     "Show list view" : "اظهر معاينات الروابط",
     "Show grid view" : "عرض شبكي",
     "Close" : "إغلاق",
@@ -403,6 +391,9 @@ OC.L10N.register(
     "Copied {origin} inside {destination}" : "تم نسخ {origin} داخل {destination}",
     "Copied {origin} and {nbfiles} other files inside {destination}" : "تم نسخ {origin} و {nbfiles} ملفات اخرى داخل {destination}",
     "{newName} already exists" : "{newName} موجود مسبقاً",
+    "Could not rename \"{fileName}\", it does not exist any more" : "لا يمكن اعادة تسمية \"{fileName}\", لأنه لم يعد موجود",
+    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "الاسم \"{targetName}\" مستخدم من قبل في المجلد \"{dir}\". الرجاء اختيار اسم اخر.",
+    "Could not rename \"{fileName}\"" : "إعادة تسمية الملف \"{fileName}\" لم تنجح",
     "Could not create file \"{file}\"" : "لا يمكن إنشاء الملف\"{file}\"",
     "Could not create file \"{file}\" because it already exists" : "فشل إنشاء الملف \"{file}\" فهو موجود بالفعل",
     "Could not create folder \"{dir}\" because it already exists" : "فشل إنشاء المجلد \"{dir}\" فهو موجود بالفعل",
@@ -444,7 +435,6 @@ OC.L10N.register(
     "Upload (max. %s)" : "الرفع ( حد اقصى. %s ) ",
     "Submitting fields…" : "إرسال الحقول...",
     "Filter filenames…" : "تصفية باسم الملف...",
-    "Enable the grid view" : "تمكين العرض الشبكي",
     "_{folderCount} folder_::_{folderCount} folders_" : ["{folderCount} مجلد","{folderCount} مجلد","{folderCount} مجلد","{folderCount} مجلدات","{folderCount} مجلد","{folderCount} مجلد"],
     "_{fileCount} file_::_{fileCount} files_" : ["{fileCount} ملف","{fileCount} ملف","{fileCount} ملف","{fileCount} ملفات","{fileCount} ملف","{fileCount} ملف"],
     "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["1 ملف و {folderCount} مجلد","1 ملف و {folderCount} مجلد","1 ملف و {folderCount} مجلد","1 ملف و{folderCount} مجلدات","1 ملف و {folderCount} مجلد","1 ملف و {folderCount} مجلد"],
@@ -453,8 +443,7 @@ OC.L10N.register(
     "Personal Files" : "ملفات شخصية",
     "Text file" : "ملف نصي",
     "New text file.txt" : "ملف نصي جديد fille.txt",
-    "renamed file" : "ملف معاد تسميته",
-    "After enabling the windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "بعد تمكين أسماء الملفات المتوافقة مع نظام التشغيل Windows، لا يمكن تعديل الملفات الموجودة بعد الآن ولكن يمكن إعادة تسميتها إلى أسماء جديدة صالحة بواسطة مالكها.",
-    "Filter file names …" : "تصفية بأسماء الملفات..."
+    "{count} files could not be converted" : "{count} ملفات تعذّر تحويلها",
+    "{count} files successfully converted" : "{count} ملف تمّ تحويلها بنجاحٍ"
 },
 "nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");
