@@ -51,10 +51,6 @@ OC.L10N.register(
     "You do not have permission to create a file at the specified location" : "You do not have permission to create a file at the specified location",
     "The file could not be converted." : "The file could not be converted.",
     "Could not get relative path to converted file" : "Could not get relative path to converted file",
-    "Limit must be a positive integer." : "Limit must be a positive integer.",
-    "The replacement character may only be a single character." : "The replacement character may only be a single character.",
-    "Filename sanitization already started." : "Filename sanitization already started.",
-    "No filename sanitization in progress." : "No filename sanitation in progress.",
     "Favorite files" : "Favorite files",
     "No favorites" : "No favourites",
     "More favorites" : "More favorites",
@@ -72,6 +68,12 @@ OC.L10N.register(
     "The ownership transfer of {path} from {user} has completed." : "The ownership transfer of {path} from {user} has completed.",
     "in %s" : "in %s",
     "Transferred from %1$s on %2$s" : "Transferred from %1$s on %2$s",
+    "Files compatibility" : "Files compatibility",
+    "Allow to restrict filenames to ensure files can be synced with all clients. By default all filenames valid on POSIX (e.g. Linux or macOS) are allowed." : "Allow to restrict filenames to ensure files can be synced with all clients. By default all filenames valid on POSIX (e.g. Linux or macOS) are allowed.",
+    "After enabling the Windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "After enabling the Windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner.",
+    "It is also possible to migrate files automatically after enabling this setting, please refer to the documentation about the occ command." : "It is also possible to migrate files automatically after enabling this setting, please refer to the documentation about the occ command.",
+    "Enforce Windows compatibility" : "Enforce Windows compatibility",
+    "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity." : "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity.",
     "File Management" : "File Management",
     "Home" : "Home",
     "Target folder does not exist any more" : "Target folder does not exist any more",
@@ -104,7 +106,6 @@ OC.L10N.register(
     "Unknown date" : "Unknown date",
     "Clear filter" : "Clear filter",
     "Modified" : "Modified",
-    "Search everywhere" : "Search everywhere",
     "Type" : "Type",
     "Active filters" : "Active filters",
     "Remove filter" : "Remove filter",
@@ -113,9 +114,9 @@ OC.L10N.register(
     "Name" : "Name",
     "File type" : "File type",
     "Size" : "Size",
-    "{displayName}: failed on some elements" : "{displayName}: failed on some elements",
-    "{displayName}: done" : "{displayName}: done",
-    "{displayName}: failed" : "{displayName}: failed",
+    "\"{displayName}\" failed on some elements" : "\"{displayName}\" failed on some elements",
+    "\"{displayName}\" batch action executed successfully" : "\"{displayName}\" batch action executed successfully",
+    "\"{displayName}\" action failed" : "\"{displayName}\" action failed",
     "Actions" : "Actions",
     "(selected)" : "(selected)",
     "List of files and folders." : "List of files and folders.",
@@ -123,9 +124,7 @@ OC.L10N.register(
     "Column headers with buttons are sortable." : "Column headers with buttons are sortable.",
     "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list.",
     "File not found" : "File not found",
-    "_{count} selected_::_{count} selected_" : ["{count} selected","{count} selected"],
-    "Search scope options" : "Search scope options",
-    "Search here" : "Search here",
+    "{count} selected" : "{count} selected",
     "{usedQuotaByte} used" : "{usedQuotaByte} used",
     "{used} of {quota} used" : "{used} of {quota} used",
     "{relative}% used" : "{relative}% used",
@@ -137,25 +136,8 @@ OC.L10N.register(
     "Create new folder" : "Create new folder",
     "This name is already in use." : "This name is already in use.",
     "Create" : "Create",
-    "Files starting with a dot are hidden by default" : "Files starting with a dot are hidden by default",
-    "Failed to start filename sanitization." : "Failed to start filename sanitization.",
-    "Failed to refresh filename sanitization status." : "Failed to refresh filename sanitization status.",
-    "Filename sanitization in progress." : "Filename sanitization in progress.",
-    "Currently {processedUsers} of {totalUsers} accounts are already processed." : "Currently {processedUsers} of {totalUsers} accounts are already processed.",
-    "Refresh" : "Refresh",
-    "All files have been santized for Windows filename support." : "All files have been santized for Windows filename support.",
-    "Some files could not be sanitized, please check your logs." : "Some files could not be sanitized, please check your logs.",
-    "Sanitization errors" : "Sanitization errors",
-    "Not sanitized filenames" : "Not sanitized filenames",
-    "Windows filename support has been enabled." : "Windows filename support has been enabled.",
-    "While this blocks users from creating new files with unsupported filenames, existing files are not yet renamed and thus still may break sync on Windows." : "While this blocks users from creating new files with unsupported filenames, existing files are not yet renamed and thus still may break sync on Windows.",
-    "You can trigger a rename of files with invalid filenames, this will be done in the background and may take some time." : "You can trigger a rename of files with invalid filenames, this will be done in the background and may take some time.",
-    "Please note that this may cause high workload on the sync clients." : "Please note that this may cause high workload on the sync clients.",
-    "Limit" : "Limit",
-    "This allows to configure how many users should be processed in one background job run." : "This allows to configure how many users should be processed in one background job run.",
-    "Sanitize filenames" : "Sanitize filenames",
-    "(starting)" : "(starting)",
     "Fill template fields" : "Fill template fields",
+    "Submitting fields …" : "Submitting fields …",
     "Submit" : "Submit",
     "Choose a file or folder to transfer" : "Choose a file or folder to transfer",
     "Transfer" : "Transfer",
@@ -179,51 +161,6 @@ OC.L10N.register(
     "Do not show this dialog again." : "Do not show this dialogue again.",
     "Select file or folder to link to" : "Select file or folder to link to",
     "Choose {file}" : "Choose {file}",
-    "Clipboard is not available" : "Clipboard is not available",
-    "WebDAV URL copied" : "WebDAV URL copied",
-    "Files settings" : "Files settings",
-    "General" : "General",
-    "Default view" : "Default view",
-    "All files" : "All files",
-    "Personal files" : "Personal files",
-    "Sort favorites first" : "Sort favourites first",
-    "Sort folders before files" : "Sort folders before files",
-    "Folder tree" : "Folder tree",
-    "Appearance" : "Appearance",
-    "Show hidden files" : "Show hidden files",
-    "Show file type column" : "Show file type column",
-    "Show file extensions" : "Show file extensions",
-    "Crop image previews" : "Crop image previews",
-    "Additional settings" : "Additional settings",
-    "WebDAV" : "WebDAV",
-    "WebDAV URL" : "WebDAV URL",
-    "Copy" : "Copy",
-    "How to access files using WebDAV" : "How to access files using WebDAV",
-    "Two-Factor Authentication is enabled for your account, and therefore you need to use an app password to connect an external WebDAV client." : "Two-Factor Authentication is enabled for your account, and therefore you need to use an app password to connect an external WebDAV client.",
-    "Warnings" : "Warnings",
-    "Warn before changing a file extension" : "Warn before changing a file extension",
-    "Warn before deleting files" : "Warn before deleting files",
-    "Keyboard shortcuts" : "Keyboard shortcuts",
-    "File actions" : "File actions",
-    "Rename" : "Rename",
-    "Delete" : "Delete",
-    "Add or remove favorite" : "Add or remove favorite",
-    "Manage tags" : "Manage tags",
-    "Selection" : "Selection",
-    "Select all files" : "Select all files",
-    "Deselect all" : "Deselect all",
-    "Select or deselect" : "Select or deselect",
-    "Select a range" : "Select a range",
-    "Navigation" : "Navigation",
-    "Go to parent folder" : "Go to parent folder",
-    "Go to file above" : "Go to file above",
-    "Go to file below" : "Go to file below",
-    "Go left in grid" : "Go left in grid",
-    "Go right in grid" : "Go right in grid",
-    "View" : "View",
-    "Toggle grid view" : "Toggle grid view",
-    "Open file sidebar" : "Open file sidebar",
-    "Show those shortcuts" : "Show those shortcuts",
     "Share" : "Share",
     "Shared by link" : "Shared by link",
     "Shared" : "Shared",
@@ -236,38 +173,74 @@ OC.L10N.register(
     "Error during upload: {message}" : "Error during upload: {message}",
     "Error during upload, status code {status}" : "Error during upload, status code {status}",
     "Unknown error during upload" : "Unknown error during upload",
+    "\"{displayName}\" action executed successfully" : "\"{displayName}\" action executed successfully",
     "Loading current folder" : "Loading current folder",
     "Retry" : "Retry",
     "No files in here" : "No files in here",
     "Upload some content or sync with your devices!" : "Upload some content or sync with your devices!",
     "Go back" : "Go back",
+    "Filter file names …" : "Filter file names …",
     "Views" : "Views",
+    "Files settings" : "Files settings",
+    "Your files" : "Your files",
+    "Open in files" : "Open in files",
+    "File cannot be accessed" : "File cannot be accessed",
+    "The file could not be found or you do not have permissions to view it. Ask the sender to share it." : "The file could not be found or you do not have permissions to view it. Ask the sender to share it.",
+    "Clipboard is not available" : "Clipboard is not available",
+    "WebDAV URL copied to clipboard" : "WebDAV URL copied to clipboard",
+    "Sort favorites first" : "Sort favourites first",
+    "Sort folders before files" : "Sort folders before files",
+    "Show hidden files" : "Show hidden files",
+    "Show file type column" : "Show file type column",
+    "Crop image previews" : "Crop image previews",
+    "Enable the grid view" : "Enable the grid view",
+    "Enable folder tree" : "Enable folder tree",
+    "Additional settings" : "Additional settings",
+    "WebDAV" : "WebDAV",
+    "WebDAV URL" : "WebDAV URL",
+    "Copy to clipboard" : "Copy to clipboard",
+    "Use this address to access your Files via WebDAV" : "Use this address to access your Files via WebDAV",
+    "If you have enabled 2FA, you must create and use a new app password by clicking here." : "If you have enabled 2FA, you must create and use a new app password by clicking here.",
+    "Warnings" : "Warnings",
+    "Prevent warning dialogs from open or reenable them." : "Prevent warning dialogues from opening or reenable them.",
+    "Show a warning dialog when changing a file extension." : "Show a warning dialogue when changing a file extension.",
+    "Keyboard shortcuts" : "Keyboard shortcuts",
+    "Speed up your Files experience with these quick shortcuts." : "Speed up your Files experience with these quick shortcuts.",
+    "Open the actions menu for a file" : "Open the actions menu for a file",
+    "Rename a file" : "Rename a file",
+    "Delete a file" : "Delete a file",
+    "Favorite or remove a file from favorites" : "Favourite or remove a file from favourites",
+    "Manage tags for a file" : "Manage tags for a file",
+    "Selection" : "Selection",
+    "Select all files" : "Select all files",
+    "Deselect all files" : "Deselect all files",
+    "Select or deselect a file" : "Select or deselect a file",
+    "Select a range of files" : "Select a range of files",
+    "Navigation" : "Navigation",
+    "Navigate to the parent folder" : "Navigate to the parent folder",
+    "Navigate to the file above" : "Navigate to the file above",
+    "Navigate to the file below" : "Navigate to the file below",
+    "Navigate to the file on the left (in grid mode)" : "Navigate to the file on the left (in grid mode)",
+    "Navigate to the file on the right (in grid mode)" : "Navigate to the file on the right (in grid mode)",
+    "View" : "View",
+    "Toggle the grid view" : "Toggle the grid view",
+    "Open the sidebar for a file" : "Open the sidebar for a file",
+    "Show those shortcuts" : "Show those shortcuts",
     "You" : "You",
     "Shared multiple times with different people" : "Shared multiple times with different people",
-    "Unable to change the favorite state of the file" : "Unable to change the favorite state of the file",
     "Error while loading the file data" : "Error while loading the file data",
     "Owner" : "Owner",
     "Remove from favorites" : "Remove from favourites",
     "Add to favorites" : "Add to favourites",
     "Tags" : "Tags",
-    "Your files" : "Your files",
-    "Open in files" : "Open in files",
-    "File cannot be accessed" : "File cannot be accessed",
-    "The file could not be found or you do not have permissions to view it. Ask the sender to share it." : "The file could not be found or you do not have permissions to view it. Ask the sender to share it.",
-    "No search results for “{query}”" : "No search results for “{query}”",
-    "Search for files" : "Search for files",
-    "Allow to restrict filenames to ensure files can be synced with all clients. By default all filenames valid on POSIX (e.g. Linux or macOS) are allowed." : "Allow to restrict filenames to ensure files can be synced with all clients. By default all filenames valid on POSIX (e.g. Linux or macOS) are allowed.",
-    "After enabling the Windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "After enabling the Windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner.",
-    "Failed to toggle Windows filename support" : "Failed to toggle Windows filename support",
-    "Files compatibility" : "Files compatibility",
-    "Enforce Windows compatibility" : "Enforce Windows compatibility",
-    "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity." : "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity.",
     "Blank" : "Blank",
     "Unable to create new file from template" : "Unable to create new file from template",
     "Pick a template for {name}" : "Pick a template for {name}",
     "Create a new file with the selected template" : "Create a new file with the selected template",
     "Creating file" : "Creating file",
     "Save as {displayName}" : "Save as {displayName}",
+    "Save as …" : "Save as …",
+    "Converting files …" : "Converting files …",
     "Failed to convert files: {message}" : "Failed to convert files: {message}",
     "All files failed to be converted" : "All files failed to be converted",
     "One file could not be converted: {message}" : "One file could not be converted: {message}",
@@ -275,9 +248,11 @@ OC.L10N.register(
     "_One file successfully converted_::_%n files successfully converted_" : ["One file successfully converted","%n files successfully converted"],
     "Files successfully converted" : "Files successfully converted",
     "Failed to convert files" : "Failed to convert files",
+    "Converting file …" : "Converting file …",
     "File successfully converted" : "File successfully converted",
     "Failed to convert file: {message}" : "Failed to convert file: {message}",
     "Failed to convert file" : "Failed to convert file",
+    "Deletion cancelled" : "Deletion cancelled",
     "Leave this share" : "Leave this share",
     "Leave these shares" : "Leave these shares",
     "Disconnect storage" : "Disconnect storage",
@@ -288,27 +263,29 @@ OC.L10N.register(
     "Delete files" : "Delete files",
     "Delete folder" : "Delete folder",
     "Delete folders" : "Delete folders",
+    "Delete" : "Delete",
     "_You are about to permanently delete {count} item_::_You are about to permanently delete {count} items_" : ["You are about to permanently delete {count} item","You are about to permanently delete {count} items"],
     "_You are about to delete {count} item_::_You are about to delete {count} items_" : ["You are about to delete {count} item","You are about to delete {count} items"],
     "Confirm deletion" : "Confirm deletion",
     "Cancel" : "Cancel",
-    "Download" : "Download",
-    "The requested file is not available." : "The requested file is not available.",
-    "The requested files are not available." : "The requested files are not available.",
-    "Destination is not a folder" : "Destination is not a folder",
-    "This file/folder is already in that directory" : "This file/folder is already in that directory",
+    "Moving \"{source}\" to \"{destination}\" …" : "Moving \"{source}\" to \"{destination}\" …",
+    "Copying \"{source}\" to \"{destination}\" …" : "Copying \"{source}\" to \"{destination}\" …",
     "You cannot move a file/folder onto itself or into a subfolder of itself" : "You cannot move a file/folder onto itself or into a subfolder of itself",
     "(copy)" : "(copy)",
     "(copy %n)" : "(copy %n)",
+    "Move cancelled" : "Move cancelled",
     "A file or folder with that name already exists in this folder" : "A file or folder with that name already exists in this folder",
     "The files are locked" : "The files are locked",
     "The file does not exist anymore" : "The file does not exist anymore",
     "Choose destination" : "Choose destination",
     "Copy to {target}" : "Copy to {target}",
+    "Copy" : "Copy",
     "Move to {target}" : "Move to {target}",
     "Move" : "Move",
     "Move or copy operation failed" : "Move or copy operation failed",
     "Move or copy" : "Move or copy",
+    "Cancelled move or copy of \"{filename}\"." : "Cancelled move or copy of \"{filename}\".",
+    "Cancelled move or copy operation" : "Cancelled move or copy operation",
     "Open folder {displayName}" : "Open folder {displayName}",
     "Open in Files" : "Open in Files",
     "Open locally" : "Open locally",
@@ -317,7 +294,8 @@ OC.L10N.register(
     "The file should now open on your device. If it doesn't, please check that you have the desktop app installed." : "The file should now open on your device. If it doesn't, please check that you have the desktop app installed.",
     "Retry and close" : "Retry and close",
     "Open online" : "Open online",
-    "Details" : "Details",
+    "Rename" : "Rename",
+    "Open details" : "Open details",
     "View in folder" : "View in folder",
     "Today" : "Today",
     "Last 7 days" : "Last 7 days",
@@ -330,15 +308,15 @@ OC.L10N.register(
     "PDFs" : "PDFs",
     "Folders" : "Folders",
     "Audio" : "Audio",
-    "Images" : "Images",
+    "Photos and images" : "Photos and images",
     "Videos" : "Videos",
+    "New folder creation cancelled" : "New folder creation cancelled",
     "Created new folder \"{name}\"" : "Created new folder \"{name}\"",
     "Unable to initialize the templates directory" : "Unable to initialize the templates directory",
     "Create templates folder" : "Create templates folder",
     "Templates" : "Templates",
     "New template folder" : "New template folder",
     "In folder" : "In folder",
-    "Search in all files" : "Search in all files",
     "Search in folder: {folder}" : "Search in folder: {folder}",
     "One of the dropped files could not be processed" : "One of the dropped files could not be processed",
     "Your browser does not support the Filesystem API. Directories will not be uploaded" : "Your browser does not support the Filesystem API. Directories will not be uploaded",
@@ -353,11 +331,8 @@ OC.L10N.register(
     "Files moved successfully" : "Files moved successfully",
     "Conflicts resolution skipped" : "Conflicts resolution skipped",
     "Upload cancelled" : "Upload cancelled",
-    "Could not rename \"{oldName}\", it does not exist any more" : "Could not rename \"{oldName}\", it does not exist any more",
-    "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name.",
-    "Could not rename \"{oldName}\"" : "Could not rename \"{oldName}\"",
     "This operation is forbidden" : "This operation is forbidden",
-    "This folder is unavailable, please try again later or contact the administration" : "This folder is unavailable, please try again later or contact the administration",
+    "This directory is unavailable, please check the logs or contact the administrator" : "This directory is unavailable, please check the logs or contact the administrator",
     "Storage is temporarily not available" : "Storage is temporarily not available",
     "Unexpected error: {error}" : "Unexpected error: {error}",
     "_%n file_::_%n files_" : ["%n file","%n files"],
@@ -371,7 +346,10 @@ OC.L10N.register(
     "List of favorite files and folders." : "List of favourite files and folders.",
     "No favorites yet" : "No favourites yet",
     "Files and folders you mark as favorite will show up here" : "Files and folders you mark as favourite will show up here",
+    "All files" : "All files",
     "List of your files and folders." : "List of your files and folders.",
+    "All folders" : "All folders",
+    "Personal files" : "Personal files",
     "List of your files and folders that are not shared." : "List of your files and folders that are not shared.",
     "No personal files found" : "No personal files found",
     "Files that are not shared will show up here." : "Files that are not shared will show up here.",
@@ -379,13 +357,12 @@ OC.L10N.register(
     "List of recently modified files and folders." : "List of recently modified files and folders.",
     "No recently modified files" : "No recently modified files",
     "Files and folders you recently modified will show up here." : "Files and folders you recently modified will show up here.",
-    "Search" : "Search",
-    "Search results within your files." : "Search results within your files.",
     "No entries found in this folder" : "No entries found in this folder",
     "Select all" : "Select all",
     "Upload too large" : "Upload too large",
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "The files you are trying to upload exceed the maximum size for file uploads on this server.",
     "File could not be found" : "File could not be found",
+    "Download" : "Download",
     "Show list view" : "Show list view",
     "Show grid view" : "Show grid view",
     "Close" : "Close",
@@ -410,12 +387,12 @@ OC.L10N.register(
     "Edit locally" : "Edit locally",
     "Open" : "Open",
     "Could not load info for file \"{file}\"" : "Could not load info for file \"{file}\"",
+    "Details" : "Details",
     "Please select tag(s) to add to the selection" : "Please select tag(s) to add to the selection",
     "Apply tag(s) to selection" : "Apply tag(s) to selection",
     "Select directory \"{dirName}\"" : "Select directory \"{dirName}\"",
     "Select file \"{fileName}\"" : "Select file \"{fileName}\"",
     "Unable to determine date" : "Unable to determine date",
-    "This directory is unavailable, please check the logs or contact the administrator" : "This directory is unavailable, please check the logs or contact the administrator",
     "Could not move \"{file}\", target exists" : "Could not move \"{file}\", target exists",
     "Could not move \"{file}\"" : "Could not move \"{file}\"",
     "copy" : "copy",
@@ -424,6 +401,9 @@ OC.L10N.register(
     "Copied {origin} inside {destination}" : "Copied {origin} inside {destination}",
     "Copied {origin} and {nbfiles} other files inside {destination}" : "Copied {origin} and {nbfiles} other files inside {destination}",
     "{newName} already exists" : "{newName} already exists",
+    "Could not rename \"{fileName}\", it does not exist any more" : "Could not rename \"{fileName}\", it does not exist any more",
+    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name.",
+    "Could not rename \"{fileName}\"" : "Could not rename \"{fileName}\"",
     "Could not create file \"{file}\"" : "Could not create file \"{file}\"",
     "Could not create file \"{file}\" because it already exists" : "Could not create file \"{file}\" because it already exists",
     "Could not create folder \"{dir}\" because it already exists" : "Could not create folder \"{dir}\" because it already exists",
@@ -463,65 +443,20 @@ OC.L10N.register(
     "Not favored" : "Not favoured",
     "An error occurred while trying to update the tags" : "An error occurred whilst trying to update the tags",
     "Upload (max. %s)" : "Upload (max. %s)",
-    "\"{displayName}\" action executed successfully" : "\"{displayName}\" action executed successfully",
-    "\"{displayName}\" action failed" : "\"{displayName}\" action failed",
-    "\"{displayName}\" failed on some elements" : "\"{displayName}\" failed on some elements",
-    "\"{displayName}\" batch action executed successfully" : "\"{displayName}\" batch action executed successfully",
     "Submitting fields…" : "Submitting fields…",
     "Filter filenames…" : "Filter filenames…",
-    "WebDAV URL copied to clipboard" : "WebDAV URL copied to clipboard",
-    "Enable the grid view" : "Enable the grid view",
-    "Enable folder tree" : "Enable folder tree",
-    "Copy to clipboard" : "Copy to clipboard",
-    "Use this address to access your Files via WebDAV" : "Use this address to access your Files via WebDAV",
-    "If you have enabled 2FA, you must create and use a new app password by clicking here." : "If you have enabled 2FA, you must create and use a new app password by clicking here.",
-    "Deletion cancelled" : "Deletion cancelled",
-    "Moving \"{source}\" to \"{destination}\" …" : "Moving \"{source}\" to \"{destination}\" …",
-    "Copying \"{source}\" to \"{destination}\" …" : "Copying \"{source}\" to \"{destination}\" …",
-    "Move cancelled" : "Move cancelled",
-    "Cancelled move or copy of \"{filename}\"." : "Cancelled move or copy of \"{filename}\".",
-    "Cancelled move or copy operation" : "Cancelled move or copy operation",
-    "Open details" : "Open details",
-    "Photos and images" : "Photos and images",
-    "New folder creation cancelled" : "New folder creation cancelled",
     "_{folderCount} folder_::_{folderCount} folders_" : ["{folderCount} folder","{folderCount} folders"],
     "_{fileCount} file_::_{fileCount} files_" : ["{fileCount} file","{fileCount} files"],
     "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["1 file and {folderCount} folder","1 file and {folderCount} folders"],
     "_{fileCount} file and 1 folder_::_{fileCount} files and 1 folder_" : ["{fileCount} file and 1 folder","{fileCount} files and 1 folder"],
     "{fileCount} files and {folderCount} folders" : "{fileCount} files and {folderCount} folders",
-    "All folders" : "All folders",
     "Personal Files" : "Personal Files",
     "Text file" : "Text file",
     "New text file.txt" : "New text file.txt",
     "%1$s (renamed)" : "%1$s (renamed)",
     "renamed file" : "renamed file",
     "After enabling the windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "After enabling the windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner.",
-    "It is also possible to migrate files automatically after enabling this setting, please refer to the documentation about the occ command." : "It is also possible to migrate files automatically after enabling this setting, please refer to the documentation about the occ command.",
-    "Submitting fields …" : "Submitting fields …",
-    "Filter file names …" : "Filter file names …",
-    "Prevent warning dialogs from open or reenable them." : "Prevent warning dialogues from opening or reenable them.",
-    "Show a warning dialog when changing a file extension." : "Show a warning dialog when changing a file extension.",
-    "Speed up your Files experience with these quick shortcuts." : "Speed up your Files experience with these quick shortcuts.",
-    "Open the actions menu for a file" : "Open the actions menu for a file",
-    "Rename a file" : "Rename a file",
-    "Delete a file" : "Delete a file",
-    "Favorite or remove a file from favorites" : "Favourite or remove a file from favourites",
-    "Manage tags for a file" : "Manage tags for a file",
-    "Deselect all files" : "Deselect all files",
-    "Select or deselect a file" : "Select or deselect a file",
-    "Select a range of files" : "Select a range of files",
-    "Navigate to the parent folder" : "Navigate to the parent folder",
-    "Navigate to the file above" : "Navigate to the file above",
-    "Navigate to the file below" : "Navigate to the file below",
-    "Navigate to the file on the left (in grid mode)" : "Navigate to the file on the left (in grid mode)",
-    "Navigate to the file on the right (in grid mode)" : "Navigate to the file on the right (in grid mode)",
-    "Toggle the grid view" : "Toggle the grid view",
-    "Open the sidebar for a file" : "Open the sidebar for a file",
-    "Save as …" : "Save as …",
-    "Converting files …" : "Converting files …",
-    "Converting file …" : "Converting file …",
-    "Search everywhere …" : "Search everywhere …",
-    "Search here …" : "Search here …",
-    "Preparing …" : "Preparing …"
+    "{count} files could not be converted" : "{count} files could not be converted",
+    "{count} files successfully converted" : "{count} files successfully converted"
 },
 "nplurals=2; plural=(n != 1);");
