@@ -54,7 +54,6 @@ OC.L10N.register(
     "Favorite files" : "Archivos favoritos",
     "No favorites" : "No hay favoritos",
     "More favorites" : "Más favoritos",
-    "Upload (max. %s)" : "Subida (máx. %s)",
     "Accept" : "Aceptar",
     "Reject" : "Rechazar",
     "Incoming ownership transfer from {user}" : "Ha llegado una transferencia de propiedad de {user}",
@@ -281,12 +280,12 @@ OC.L10N.register(
     "Cancelled move or copy operation" : "Se canceló la operación de mover o copiar",
     "Open folder {displayName}" : "Abrir carpeta {displayName}",
     "Open in Files" : "Abrir en Archivos",
+    "Open locally" : "Abrir localmente",
+    "Failed to redirect to client" : "Fallo al redirigir al cliente",
     "Open file locally" : "Abrir archivo localmente",
     "The file should now open on your device. If it doesn't, please check that you have the desktop app installed." : "El archivo se abrirá ahora en tu dispositivo. Si esto no ocurre, por favor verifica que has instalado la aplicación de escritorio",
     "Retry and close" : "Reintentar y cerrar",
     "Open online" : "Abrir en línea",
-    "Failed to redirect to client" : "Fallo al redirigir al cliente",
-    "Open locally" : "Abrir localmente",
     "Rename" : "Renombrar",
     "Open details" : "Abrir detalles",
     "View in folder" : "Ver en carpeta",
@@ -429,34 +428,26 @@ OC.L10N.register(
     "Direct link was copied (only works for people who have access to this file/folder)" : "El enlace directo fue copiado (solo funciona para usuarios que tienen acceso a este archivo/carpeta)",
     "Path" : "Ruta",
     "_%n byte_::_%n bytes_" : ["%n byte","%n bytes","%n bytes"],
-    "Favorited" : "Agregado a favoritos",
+    "Favored" : "Favorecido",
+    "Favor" : "Favorecer",
     "Copy direct link (only works for people who have access to this file/folder)" : "El enlace directo fue copiado (solo funciona para usuarios que tienen acceso a este archivo/carpeta)",
     "Upload file" : "Subir archivo",
-    "Not favorited" : "Quitado como favorito",
+    "Not favored" : "No favorecido",
     "An error occurred while trying to update the tags" : "Se produjo un error al tratar de actualizar las etiquetas",
-    "You don't have permission to upload or create files here." : "No tiene permisos para subir o crear archivos aquí.",
-    "Storage informations" : "Informaciones de almacenamiento",
-    "Choose file" : "Elegir archivo",
-    "Go to the previous folder" : "Ir a la carpeta anterior",
-    "Open the files app settings" : "Abrir la configuración de la app Archivos",
-    "Unable to change the favourite state of the file" : "No se ha podido cambiar el estado de favorito del fichero",
-    "Edit file locally" : "Editar archivo localmente",
-    "Edit online" : "Editar en línea",
-    "Create new templates folder" : "Crear nueva carpeta de plantillas",
+    "Upload (max. %s)" : "Subida (máx. %s)",
+    "Submitting fields…" : "Enviando campos…",
+    "Filter filenames…" : "Filtrar nombres de archivo…",
     "_{folderCount} folder_::_{folderCount} folders_" : ["{folderCount} carpeta","{folderCount} carpetas","{folderCount} carpetas"],
     "_{fileCount} file_::_{fileCount} files_" : ["{fileCount} archivo","{fileCount} archivos","{fileCount} archivos"],
     "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["1 archivo y {folderCount} carpeta","1 archivo y {folderCount} carpetas","1 archivo y {folderCount} carpetas"],
     "_{fileCount} file and 1 folder_::_{fileCount} files and 1 folder_" : ["{fileCount} archivo y 1 carpeta","{fileCount} archivos y 1 carpeta","{fileCount} archivos y 1 carpeta"],
     "{fileCount} files and {folderCount} folders" : "{fileCount} archivos y {folderCount} carpetas",
-    "List of favorites files and folders." : "Lista de archivos y carpetas favoritos.",
     "Personal Files" : "Archivos Personales",
     "Text file" : "Archivo de texto",
     "New text file.txt" : "Nuevo archivo.txt",
-    "Favored" : "Favorecido",
-    "Favor" : "Favorecer",
-    "Not favored" : "No favorecido",
-    "Submitting fields…" : "Enviando campos…",
-    "Filter filenames…" : "Filtrar nombres de archivo…",
+    "%1$s (renamed)" : "%1$s (renombrado)",
+    "renamed file" : "archivo renombrado",
+    "After enabling the windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "Luego de habilitar los nombres de archivo compatibles con windows, los archivos existentes no podrán ser modificados, pero, podrán ser renombrados a nuevos nombres válidos por su respectivo propietario.",
     "{count} files could not be converted" : "{count} archivos no han podido ser convertidos",
     "{count} files successfully converted" : "{count} archivos convertidos correctamente"
 },
