@@ -85,28 +85,21 @@ OC.L10N.register(
     "Rename file" : "Преименувај датотека",
     "Folder" : "Папка",
     "Pending" : "Чека",
-    "Unknown date" : "Непознат датум",
     "Clear filter" : "Исчисти филтри",
     "Modified" : "Променето",
-    "Search everywhere" : "Барај насекаде",
     "Type" : "Вид",
-    "Active filters" : "Активни филтри",
-    "Remove filter" : "Острани филтер",
     "Total rows summary" : "Резиме на вкупно редови",
     "Name" : "Име",
-    "File type" : "Вид на датотека",
     "Size" : "Големина",
     "\"{displayName}\" batch action executed successfully" : "\"{displayName}\" сериската акција е успешно извршена",
     "\"{displayName}\" action failed" : "\"{displayName}\" акцијата не успеа",
     "Actions" : "Акции",
     "(selected)" : "(означени)",
     "List of files and folders." : "Листа на датотеки и папки.",
-    "You have used your space quota and cannot upload files anymore." : "Го имате искористено лимитот на просторот за прикачување и повеќе неможете да прикачувате датотеки.",
     "Column headers with buttons are sortable." : "Насловите на колоните со копчиња се сортираат.",
     "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "Оваа листа не е целосно прикажана поради заштеда на перформанси. Датотеките ќе се прикажуваат додека се движите низ листата.",
     "File not found" : "Датотеката не е пронајдена",
-    "_{count} selected_::_{count} selected_" : ["{count} означена","{count} означени"],
-    "Search globally" : "Пребарај глобално",
+    "{count} selected" : "{count} селектирани",
     "{usedQuotaByte} used" : "искористено {usedQuotaByte}",
     "{used} of {quota} used" : "Искористени {used} од {quota}",
     "{relative}% used" : "искористено {relative}% ",
@@ -151,15 +144,12 @@ OC.L10N.register(
     "Your files" : "Ваши датотеки",
     "Open in files" : "Отвори во датотеките",
     "File cannot be accessed" : "Неможе да се пристапи до датотеката",
-    "Search for files" : "Пребарај датотеки",
     "Clipboard is not available" : "Клипбордот не е достапен",
     "WebDAV URL copied to clipboard" : "CalDAV линкот е копиран",
-    "Default view" : "Стандарден поглед",
-    "All files" : "Сите датотеки",
-    "Personal files" : "Лични датотеки",
     "Sort favorites first" : "Прво омилените",
     "Show hidden files" : "Прикажи сокриени датотеки",
     "Crop image previews" : "Исечи ја сликата за преглед",
+    "Enable the grid view" : "Овозможи поглед во мрежа",
     "Additional settings" : "Дополнителни параметри",
     "WebDAV" : "WebDAV",
     "WebDAV URL" : "WebDAV адреса",
@@ -171,7 +161,7 @@ OC.L10N.register(
     "Rename a file" : "Преименувај датотека",
     "Delete a file" : "Избриши датотека",
     "Navigation" : "Навигација",
-    "View" : "Поглед",
+    "View" : "Погледни",
     "You" : "Вас",
     "Error while loading the file data" : "Грешка при вчитување на податоците од датотеката",
     "Owner" : "Сопственик",
@@ -196,9 +186,6 @@ OC.L10N.register(
     "Delete" : "Избриши",
     "Confirm deletion" : "Потврди бришење",
     "Cancel" : "Откажи",
-    "Download" : "Преземи",
-    "Destination is not a folder" : "Дестинацијата не е папка",
-    "This file/folder is already in that directory" : "Оваа папка/датотека се наоѓа веќе во таа папка",
     "You cannot move a file/folder onto itself or into a subfolder of itself" : "Неможете да преместите датотека/папка во себеси или во подпапка во себеси",
     "(copy)" : "(копирај)",
     "(copy %n)" : "(копирај %n)",
@@ -235,30 +222,26 @@ OC.L10N.register(
     "Templates" : "Шаблони",
     "One of the dropped files could not be processed" : "Една од испуштените датотеки неможе да се процесоира",
     "Some files could not be moved" : "Некои датотеки не можат да се преместат",
-    "Could not rename \"{oldName}\", it does not exist any more" : "Неможе да се преименува \"{oldName}\", не постои повеќе",
-    "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Името \"{newName}\" веќе се користи во папката \"{dir}\". Ве молиме изберете друго име.",
-    "Could not rename \"{oldName}\"" : "Неможе да се преименува \"{oldName}\"",
     "This operation is forbidden" : "Операцијата не е дозволена",
     "This directory is unavailable, please check the logs or contact the administrator" : "Овој директориум е недостапен, ве молиме проверете ги логовите или контактирајте со администраторот",
     "Storage is temporarily not available" : "Складиштето моментално не е достапно",
     "_%n file_::_%n files_" : ["%n датотека","%n датотеки"],
     "_%n folder_::_%n folders_" : ["%n папка","%n папки"],
-    "Filename must not be empty." : "Името на датотеката не може да биде празно.",
     "No favorites yet" : "Сеуште нема фаворити",
     "Files and folders you mark as favorite will show up here" : "Датотеките и папките кои ќе ги означите како чести, ќе се појават тука",
+    "All files" : "Сите датотеки",
     "List of your files and folders." : "Листа на вашите датотеки и папки.",
     "All folders" : "Сите папки",
-    "No personal files found" : "Не се пронајдени лични датотеки ",
     "Recent" : "Неодамнешни",
     "List of recently modified files and folders." : "Листа на скоро изменети датотеки и папки.",
     "No recently modified files" : "Нема скоро изменети датотеки",
     "Files and folders you recently modified will show up here." : "Датотеките и папките кои скоро ќе ги измените ќе се појават тука.",
-    "Search" : "Барај",
     "No entries found in this folder" : "Нема ништо во оваа папка",
     "Select all" : "Избери се",
     "Upload too large" : "Фајлот кој се вчитува е преголем",
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Датотеките кои се обидувате да ги подигнете ја надминуваат максималната големина за подигнување датотеки на овој сервер.",
     "File could not be found" : "Неможе да се пронајде датотеката",
+    "Download" : "Преземи",
     "Show list view" : "Прикажи поглед во листа",
     "Show grid view" : "Прикажи поглед во мрежа",
     "Close" : "Затвори",
@@ -297,6 +280,9 @@ OC.L10N.register(
     "Copied {origin} inside {destination}" : "Копирана {origin} во {destination}",
     "Copied {origin} and {nbfiles} other files inside {destination}" : "Копирана {origin} и {nbfiles} други датотеки во {destination}",
     "{newName} already exists" : "{newName} веќе постои",
+    "Could not rename \"{fileName}\", it does not exist any more" : "Неможе да се преименува \"{fileName}\", датотеката не постои",
+    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Името \"{targetName}\" веќе се користи во папката \"{dir}\". Ве молиме изберете друго име.",
+    "Could not rename \"{fileName}\"" : "Неможе да се преименува \"{fileName}\"",
     "Could not create file \"{file}\"" : "Неможе да се креира датотека \"{file}\"",
     "Could not create file \"{file}\" because it already exists" : "Неможе да се креира датотека \"{file}\" бидејќи веќе постои",
     "Could not create folder \"{dir}\" because it already exists" : "Неможе да се креира папка \"{dir}\" бидејќи веќе постои",
@@ -333,13 +319,12 @@ OC.L10N.register(
     "Upload file" : "Прикачи датотека",
     "An error occurred while trying to update the tags" : "Се случи грешка додека се обидувавте да ги освежите таговите",
     "Upload (max. %s)" : "Префрлање (макс. %s)",
-    "Enable the grid view" : "Овозможи поглед во мрежа",
     "_{folderCount} folder_::_{folderCount} folders_" : ["{folderCount} папка","{folderCount} папки"],
     "_{fileCount} file_::_{fileCount} files_" : ["{fileCount} датотека","{fileCount} датотеки"],
     "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["1 датотека и {folderCount} папки","1 датотека и {folderCount} папки"],
     "_{fileCount} file and 1 folder_::_{fileCount} files and 1 folder_" : ["{fileCount} датотека и 1 папка","{fileCount} датотеки и 1 папка"],
     "{fileCount} files and {folderCount} folders" : "{fileCount} датотеки и {folderCount} папки",
-    "Personal Files" : "Лични датотеки",
+    "Personal Files" : "Персонални датотеки",
     "Text file" : "Текстуална датотека",
     "New text file.txt" : "Нова текстуална датотека file.txt"
 },
