@@ -54,7 +54,6 @@ OC.L10N.register(
     "Favorite files" : "Ulubione pliki",
     "No favorites" : "Brak ulubionych",
     "More favorites" : "Więcej ulubionych",
-    "Upload (max. %s)" : "Wysyłanie (maks. %s)",
     "Accept" : "Akceptuj",
     "Reject" : "Odrzuć",
     "Incoming ownership transfer from {user}" : "Przychodzące przeniesienie własności od {user}",
@@ -71,6 +70,7 @@ OC.L10N.register(
     "Transferred from %1$s on %2$s" : "Przeniesiono z %1$s dnia %2$s",
     "Files compatibility" : "Zgodność plików",
     "Allow to restrict filenames to ensure files can be synced with all clients. By default all filenames valid on POSIX (e.g. Linux or macOS) are allowed." : "Zezwalaj na ograniczenie nazw plików, aby zapewnić synchronizację plików ze wszystkimi klientami. Domyślnie dozwolone są wszystkie nazwy plików obowiązujące w systemie POSIX (np. Linux lub macOS).",
+    "After enabling the Windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "Po włączeniu nazw plików zgodnych z systemem Windows, istniejące pliki nie można już modyfikować, ale ich właściciel może zmienić ich nazwy na nowe, prawidłowe.",
     "It is also possible to migrate files automatically after enabling this setting, please refer to the documentation about the occ command." : "Możliwe jest również automatyczne migrowanie plików po włączeniu tego ustawienia. Więcej informacji można znaleźć w dokumentacji polecenia occ.",
     "Enforce Windows compatibility" : "Wymuszaj zgodność z systemem Windows",
     "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity." : "Spowoduje to zablokowanie nazw plików nieprawidłowych w systemach Windows, na przykład nazw zastrzeżonych lub znaków specjalnych. Nie wymusi to jednak zgodności z rozróżnianiem wielkości liter.",
@@ -97,6 +97,11 @@ OC.L10N.register(
     "Renamed \"{oldName}\" to \"{newName}\"" : "Zmieniono nazwę \"{oldName}\" na \"{newName}\"",
     "Rename file" : "Zmień nazwę pliku",
     "Folder" : "Katalog",
+    "Unknown file type" : "Nieznany typ pliku",
+    "{ext} image" : "{ext} zdjęcie",
+    "{ext} video" : "{ext} wideo",
+    "{ext} audio" : "{ext} dźwiękowy",
+    "{ext} text" : "{ext} tekstowy",
     "Pending" : "Oczekujące",
     "Unknown date" : "Nieznana data",
     "Clear filter" : "Wyczyść filtr",
@@ -107,6 +112,7 @@ OC.L10N.register(
     "Total rows summary" : "Podsumowanie wszystkich wierszy",
     "Toggle selection for all files and folders" : "Przełącz zaznaczenie dla wszystkich plików i katalogów",
     "Name" : "Nazwa",
+    "File type" : "Typ pliku",
     "Size" : "Rozmiar",
     "\"{displayName}\" failed on some elements" : "\"{displayName}\" nie powiodło się w niektórych elementach",
     "\"{displayName}\" batch action executed successfully" : "Akcja wsadowa \"{displayName}\" została wykonana pomyślnie",
@@ -185,6 +191,7 @@ OC.L10N.register(
     "Sort favorites first" : "Najpierw sortuj ulubione",
     "Sort folders before files" : "Sortuj katalogi przed plikami",
     "Show hidden files" : "Pokaż ukryte pliki",
+    "Show file type column" : "Pokaż kolumnę typu pliku",
     "Crop image previews" : "Przytnij podglądy obrazów",
     "Enable the grid view" : "Włącz widok siatki",
     "Enable folder tree" : "Włącz drzewo katalogów",
@@ -281,12 +288,12 @@ OC.L10N.register(
     "Cancelled move or copy operation" : "Anulowano operację przenoszenia lub kopiowania",
     "Open folder {displayName}" : "Otwórz katalog {displayName}",
     "Open in Files" : "Otwórz w Plikach",
+    "Open locally" : "Otwórz lokalnie",
+    "Failed to redirect to client" : "Nie udało się przekierować do klienta",
     "Open file locally" : "Otwórz plik lokalnie",
     "The file should now open on your device. If it doesn't, please check that you have the desktop app installed." : "Plik powinien teraz otworzyć się na Twoim urządzeniu. Jeśli tak się nie stanie, sprawdź, czy masz zainstalowaną aplikację komputerową.",
     "Retry and close" : "Spróbuj ponownie i zamknij",
     "Open online" : "Otwórz online",
-    "Failed to redirect to client" : "Nie udało się przekierować do klienta",
-    "Open locally" : "Otwórz lokalnie",
     "Rename" : "Zmień nazwę",
     "Open details" : "Otwórz szczegóły",
     "View in folder" : "Zobacz w katalogu",
@@ -429,34 +436,26 @@ OC.L10N.register(
     "Direct link was copied (only works for people who have access to this file/folder)" : "Bezpośredni link został skopiowany (działa tylko dla użytkowników, którzy mają dostęp do tego pliku/katalogu)",
     "Path" : "Ścieżka",
     "_%n byte_::_%n bytes_" : ["%n bajt","%n bajty","%n bajtów","%n bajtów"],
-    "Favorited" : "Ulubiony",
+    "Favored" : "Polubione",
+    "Favor" : "Polub",
     "Copy direct link (only works for people who have access to this file/folder)" : "Skopiuj bezpośredni link (działa tylko dla użytkowników, którzy mają dostęp do tego pliku/katalogu)",
     "Upload file" : "Wyślij plik",
-    "Not favorited" : "Wyłączone z ulubionych",
+    "Not favored" : "Nie polubiono",
     "An error occurred while trying to update the tags" : "Wystąpił błąd podczas próby aktualizacji etykiet",
-    "You don't have permission to upload or create files here." : "Nie masz uprawnień do wysyłania lub tworzenia plików w tym miejscu.",
-    "Storage informations" : "Informacje o przechowywaniu",
-    "Choose file" : "Wybierz plik",
-    "Go to the previous folder" : "Przejdź do poprzedniego katalogu",
-    "Open the files app settings" : "Otwórz ustawienia aplikacji plików",
-    "Unable to change the favourite state of the file" : "Nie można zmienić ulubionego stanu pliku",
-    "Edit file locally" : "Edytuj plik lokalnie",
-    "Edit online" : "Edycja online",
-    "Create new templates folder" : "Utwórz nowy katalog z szablonami",
+    "Upload (max. %s)" : "Wysyłanie (maks. %s)",
+    "Submitting fields…" : "Przesyłanie pól…",
+    "Filter filenames…" : "Filtruj nazwy plików…",
     "_{folderCount} folder_::_{folderCount} folders_" : ["{folderCount} katalog","{folderCount} katalogi","{folderCount} katalogów","{folderCount} katalogów"],
     "_{fileCount} file_::_{fileCount} files_" : ["{fileCount} plik","{fileCount} pliki","{fileCount} plików","{fileCount} plików"],
     "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["1 plik i {folderCount} katalog","1 plik i {folderCount} katalogi","1 plik i {folderCount} katalogów","1 plik i {folderCount} katalogów"],
     "_{fileCount} file and 1 folder_::_{fileCount} files and 1 folder_" : ["{fileCount} plik i 1 katalog","{fileCount} pliki i 1 katalog","{fileCount} plików i 1 katalog","{fileCount} plików i 1 katalog"],
     "{fileCount} files and {folderCount} folders" : "{fileCount} plików i {folderCount} katalogów",
-    "List of favorites files and folders." : "Lista ulubionych plików i katalogów.",
     "Personal Files" : "Pliki osobiste",
     "Text file" : "Plik tekstowy",
     "New text file.txt" : "Nowy plik tekstowy.txt",
-    "Favored" : "Polubione",
-    "Favor" : "Polub",
-    "Not favored" : "Nie polubiono",
-    "Submitting fields…" : "Przesyłanie pól…",
-    "Filter filenames…" : "Filtruj nazwy plików…",
+    "%1$s (renamed)" : "%1$s (zmieniona nazwa)",
+    "renamed file" : "zmieniona nazwa pliku",
+    "After enabling the windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "Po włączeniu nazw plików zgodnych z systemem Windows, istniejących plików nie można już modyfikować, ale ich właściciel może zmienić ich nazwy na nowe, prawidłowe.",
     "{count} files could not be converted" : "Nie można przekonwertować {count} plików",
     "{count} files successfully converted" : "Zostały pomyślnie przekonwertowane{count} plików"
 },
