@@ -1,119 +1,6 @@
 OC.L10N.register(
     "files",
     {
-    "File could not be found" : "ไม่พบไฟล์",
-    "Move or copy" : "ย้ายหรือคัดลอก",
-    "Download" : "ดาวน์โหลด",
-    "Delete" : "ลบ",
-    "Tags" : "แท็ก",
-    "Show list view" : "แสดงมุมมองรายการ",
-    "Show grid view" : "แสดงมุมมองตาราง",
-    "Home" : "หน้าหลัก",
-    "Close" : "ปิด",
-    "Could not create folder \"{dir}\"" : "ไม่สามารถสร้างโฟลเดอร์ \"{dir}\"",
-    "This will stop your current uploads." : "การกระทำนี้จะหยุดการอัปโหลดปัจจุบันของคุณ",
-    "Upload cancelled." : "การอัปโหลดถูกยกเลิก",
-    "Processing files …" : "กำลังประมวลผลไฟล์ …",
-    "…" : "…",
-    "Unable to upload {filename} as it is a directory or has 0 bytes" : "ไม่สามารถอัปโหลด {filename} เนื่องจากเป็นไดเรกทอรีหรือมี 0 ไบต์",
-    "Not enough free space, you are uploading {size1} but only {size2} is left" : "พื้นที่ว่างไม่เพียงพอ คุณกำลังจะอัปโหลด {size1} แต่เหลือพื้นที่แค่ {size2}",
-    "Target folder \"{dir}\" does not exist any more" : "ไม่มีโฟลเดอร์เป้าหมาย \"{dir}\" อีกต่อไป",
-    "Not enough free space" : "พื้นที่ว่างไม่เพียงพอ",
-    "An unknown error has occurred" : "เกิดข้อผิดพลาดที่ไม่รู้จัก",
-    "File could not be uploaded" : "ไม่สามารถอัปโหลดไฟล์",
-    "Uploading …" : "กำลังอัปโหลด …",
-    "{remainingTime} ({currentNumber}/{total})" : "{remainingTime} ({currentNumber}/{total})",
-    "Uploading … ({currentNumber}/{total})" : "กำลังอัปโหลด … ({currentNumber}/{total})",
-    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} จาก {totalSize} ({bitrate})",
-    "Uploading that item is not supported" : "ไม่รองรับการอัปโหลดสิ่งนั้น",
-    "Target folder does not exist any more" : "ไม่มีโฟลเดอร์เป้าหมายอีกต่อไป",
-    "Operation is blocked by access control" : "การดำเนินการถูกห้ามไว้โดยการควบคุมการเข้าถึง",
-    "Error when assembling chunks, status code {status}" : "ข้อผิดพลาดขณะประกอบกลุ่ม รหัสสถานะ {status}",
-    "Actions" : "การกระทำ",
-    "Rename" : "เปลี่ยนชื่อ",
-    "Move" : "ย้าย",
-    "Copy" : "คัดลอก",
-    "Choose target folder" : "เลือกโฟลเดอร์เป้าหมาย",
-    "Edit locally" : "แก้ไขในต้นทาง",
-    "Open" : "เปิด",
-    "_Delete file_::_Delete files_" : ["ลบไฟล์"],
-    "_Delete folder_::_Delete folders_" : ["ลบโฟลเดอร์"],
-    "_Disconnect storage_::_Disconnect storages_" : ["เลิกเชื่อมต่อพื้นที่จัดเก็บข้อมูล"],
-    "_Leave this share_::_Leave these shares_" : ["ออกจากการแชร์เหล่านี้"],
-    "Could not load info for file \"{file}\"" : "ไม่สามารถโหลดข้อมูลสำหรับไฟล์ \"{file}\"",
-    "Files" : "ไฟล์",
-    "Details" : "รายละเอียด",
-    "Please select tag(s) to add to the selection" : "กรุณาเลือกแท็กเพื่อเพิ่มเข้าไปในรายการที่เลือก",
-    "Apply tag(s) to selection" : "นำแท็กไปใช้ในรายการที่เลือก",
-    "Select directory \"{dirName}\"" : "เลือกไดเร็กทอรี \"{dirname}\"",
-    "Select file \"{fileName}\"" : "เลือกไฟล์ \"{fileName}\"",
-    "Pending" : "อยู่ระหว่างดำเนินการ",
-    "Unable to determine date" : "ไม่สามารถระบุวัน",
-    "This operation is forbidden" : "การดำเนินการนี้ถูกห้าม",
-    "This directory is unavailable, please check the logs or contact the administrator" : "ไม่สามารถใช้งานไดเรกทอรีนี้ โปรดตรวจสอบบันทึกหรือติดต่อผู้ดูแลระบบ",
-    "Storage is temporarily not available" : "พื้นที่จัดเก็บข้อมูลไม่สามารถใช้งานได้ชั่วคราว",
-    "Could not move \"{file}\", target exists" : "ไม่สามารถย้าย \"{file}\" เป้าหมายมีอยู่แล้ว",
-    "Could not move \"{file}\"" : "ไม่สามารถย้ายไฟล์ \"{file}\"",
-    "copy" : "คัดลอก",
-    "Could not copy \"{file}\", target exists" : "ไม่สามารถคัดลอก \"{file}\" เป้าหมายมีอยู่แล้ว",
-    "Could not copy \"{file}\"" : "ไม่สามารถคัดลอก \"{file}\"",
-    "Copied {origin} inside {destination}" : "คัดลอก {origin} ไว้ใน {destination} แล้ว",
-    "Copied {origin} and {nbfiles} other files inside {destination}" : "คัดลอก {origin} และ {nbfiles} ไฟล์อื่น ๆ ไว้ใน {destination} แล้ว",
-    "Failed to redirect to client" : "เปลี่ยนเส้นทางไปยังไคลเอ็นต์ล้มเหลว",
-    "{newName} already exists" : "{newName} มีอยู่แล้ว",
-    "Could not rename \"{fileName}\", it does not exist any more" : "ไม่สามารถเปลี่ยนชื่อไฟล์ \"{fileName}\" ไฟล์นั้นไม่มีอยู่",
-    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "ชื่อ \"{targetName}\" มีอยู่แล้วในโฟลเดอร์ \"{dir}\" กรุณาเปลี่ยนชื่อใหม่",
-    "Could not rename \"{fileName}\"" : "ไม่สามารถเปลี่ยนชื่อไฟล์ \"{fileName}\"",
-    "Could not create file \"{file}\"" : "ไม่สามารถสร้างไฟล์ \"{file}\"",
-    "Could not create file \"{file}\" because it already exists" : "ไม่สามารถสร้างไฟล์ \"{file}\" เพราะมันมีอยู่แล้ว",
-    "Could not create folder \"{dir}\" because it already exists" : "ไม่สามารถสร้างโฟลเดอร์ \"{dir}\" เพราะมันมีอยู่แล้ว",
-    "Could not fetch file details \"{file}\"" : "ไม่สามารถดึงข้อมูลไฟล์ \"{file}\"",
-    "Error deleting file \"{fileName}\"." : "เกิดข้อผิดพลาดขณะลบไฟล์ \"{fileName}\"",
-    "No search results in other folders for {tag}{filter}{endtag}" : "ไม่มีผลลัพธ์การค้นหาในโฟลเดอร์อื่นสำหรับ {tag}{filter}{endtag}",
-    "Enter more than two characters to search in other folders" : "ใส่มากกว่า 2 ตัวอักษร เพื่อค้นหาในโฟลเดอร์อื่น",
-    "Name" : "ชื่อ",
-    "Size" : "ขนาด",
-    "Modified" : "แก้ไขเมื่อ",
-    "_%n folder_::_%n folders_" : ["%n โฟลเดอร์"],
-    "_%n file_::_%n files_" : ["%n ไฟล์"],
-    "{dirs} and {files}" : "{dirs} และ {files}",
-    "_including %n hidden_::_including %n hidden_" : ["รวมถึง %n ไฟล์ที่ซ่อนอยู่"],
-    "You do not have permission to upload or create files here" : "คุณไม่ได้รับอนุญาตให้อัปโหลดหรือสร้างไฟล์ที่นี่",
-    "_Uploading %n file_::_Uploading %n files_" : ["กำลังอัปโหลด %n ไฟล์"],
-    "New" : "ใหม่",
-    "New file/folder menu" : "เมนูไฟล์/โฟลเดอร์ใหม่",
-    "Select file range" : "เลือกช่วงไฟล์",
-    "{used}%" : "{used}%",
-    "{used} of {quota} used" : "ใช้ไป {used} จาก {quota}",
-    "{used} used" : "ใช้ไป {used}",
-    "\"{name}\" is an invalid file name." : "\"{name}\" เป็นชื่อไฟล์ที่ไม่ถูกต้อง",
-    "File name cannot be empty." : "ชื่อไฟล์ไม่สามารถเว้นว่างได้",
-    "\"/\" is not allowed inside a file name." : "ไม่อนุญาตให้ใช้ \"/\" ในชื่อไฟล์",
-    "\"{name}\" is not an allowed filetype" : "\"{name}\" เป็นประเภทไฟล์ที่ไม่ได้รับอนุญาต",
-    "Storage of {owner} is full, files cannot be updated or synced anymore!" : "พื้นที่จัดเก็บข้อมูลของ {owner} เต็มแล้ว ไม่สามารถอัปเดตหรือซิงค์ไฟล์ได้อีก!",
-    "Group folder \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "โฟลเดอร์กลุ่ม \"{mountPoint}\" เต็มแล้ว ไม่สามารถอัปเดตหรือซิงค์ไฟล์ได้อีก!",
-    "External storage \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "พื้นที่จัดเก็บข้อมูลภายนอก \"{mountPoint}\" เต็มแล้ว ไม่สามารถอัปเดตหรือซิงค์ไฟล์ได้อีก!",
-    "Your storage is full, files cannot be updated or synced anymore!" : "พื้นที่จัดเก็บข้อมูลของคุณเต็มแล้ว ไม่สามารถอัปเดตหรือซิงค์ไฟล์ได้อีก!",
-    "Storage of {owner} is almost full ({usedSpacePercent}%)." : "พื้นที่จัดเก็บข้อมูลของ {owner} ใกล้เต็มแล้ว ({usedSpacePercent}%)",
-    "Group folder \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "โฟลเดอร์กลุ่ม \"{mountPoint}\" ใกล้เต็มแล้ว ({usedSpacePercent}%)",
-    "External storage \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "พื้นที่จัดเก็บข้อมูลภายนอก \"{mountPoint}\" ใกล้เต็มแล้ว ({usedSpacePercent}%)",
-    "Your storage is almost full ({usedSpacePercent}%)." : "พื้นที่จัดเก็บข้อมูลของคุณใกล้เต็มแล้ว ({usedSpacePercent}%)",
-    "_matches \"{filter}\"_::_match \"{filter}\"_" : ["ตรงกับ \"{filter}\""],
-    "View in folder" : "ดูในโฟลเดอร์",
-    "Direct link was copied (only works for people who have access to this file/folder)" : "คัดลอกลิงก์โดยตรงแล้ว (ใช้ได้เฉพาะผู้ใช้ที่มีสิทธิ์เข้าถึงไฟล์/โฟลเดอร์นี้)",
-    "Path" : "เส้นทาง",
-    "_%n byte_::_%n bytes_" : ["%n ไบต์"],
-    "Favorited" : "เพิ่มในรายการโปรดแล้ว",
-    "Favorite" : "รายการโปรด",
-    "Copy direct link (only works for people who have access to this file/folder)" : "คัดลอกลิงก์โดยตรง (ใช้ได้เฉพาะผู้ใช้ที่มีสิทธิ์เข้าถึงไฟล์/โฟลเดอร์นี้)",
-    "New folder" : "โฟลเดอร์ใหม่",
-    "Create new folder" : "สร้างโฟลเดอร์ใหม่",
-    "Upload file" : "อัปโหลดไฟล์",
-    "Recent" : "ล่าสุด",
-    "Not favorited" : "ไม่ได้เป็นรายการโปรด",
-    "Remove from favorites" : "เอาออกจากรายการโปรด",
-    "Add to favorites" : "เพิ่มในรายการโปรด",
-    "An error occurred while trying to update the tags" : "เกิดข้อผิดพลาดขณะกำลังพยายามอัปเดตแท็ก",
     "Added to favorites" : "เพิ่มในรายการโปรดแล้ว",
     "Removed from favorites" : "เอาออกจากรายการโปรดแล้ว",
     "You added {file} to your favorites" : "คุณได้เพิ่ม {file} ในรายการโปรดของคุณ",
@@ -153,9 +40,10 @@ OC.L10N.register(
     "You moved {oldfile} to {newfile}" : "คุณได้ย้าย {oldfile} ไปยัง {newfile}",
     "{user} moved {oldfile} to {newfile}" : "{user} ได้ย้าย {oldfile} ไปยัง {newfile}",
     "A file has been added to or removed from your <strong>favorites</strong>" : "มีไฟล์ที่ถูกเพิ่มเข้าหรือเอาออกจาก<strong>รายการโปรด</strong>ของคุณ",
+    "Files" : "ไฟล์",
     "A file or folder has been <strong>changed</strong>" : "มีไฟล์หรือโฟลเดอร์ที่มีการ<strong>เปลี่ยนแปลง</strong>",
     "A favorite file or folder has been <strong>changed</strong>" : "มีไฟล์หรือโฟลเดอร์ในรายการโปรดที่มีการ<strong>เปลี่ยนแปลง</strong>",
-    "Upload (max. %s)" : "อัปโหลด (สูงสุด %s)",
+    "No favorites" : "ยังไม่มีรายการโปรด",
     "Accept" : "ยอมรับ",
     "Reject" : "ปฏิเสธ",
     "Incoming ownership transfer from {user}" : "คำขอการโอนย้ายความเป็นเจ้าของจาก {user}",
@@ -168,19 +56,28 @@ OC.L10N.register(
     "The ownership transfer of {path} from {user} has completed." : "การโอนย้ายความเป็นเจ้าของของ {path} จาก {user} สำเร็จแล้ว",
     "in %s" : "ใน %s",
     "File Management" : "การจัดการไฟล์",
-    "You don’t have permission to upload or create files here" : "คุณไม่ได้รับอนุญาตให้อัปโหลดหรือสร้างไฟล์ที่นี่",
+    "Home" : "หน้าหลัก",
+    "Target folder does not exist any more" : "ไม่มีโฟลเดอร์เป้าหมายอีกต่อไป",
+    "Favorite" : "รายการโปรด",
+    "Filename" : "ชื่อไฟล์",
     "Folder name" : "ชื่อโฟลเดอร์",
+    "Folder" : "โฟลเดอร์",
+    "Pending" : "อยู่ระหว่างดำเนินการ",
+    "Modified" : "แก้ไขเมื่อ",
+    "Type" : "ประเภท",
+    "Name" : "ชื่อ",
+    "Size" : "ขนาด",
+    "Actions" : "การกระทำ",
     "File not found" : "ไม่พบไฟล์",
-    "Storage informations" : "ข้อมูลพื้นที่จัดเก็บ",
     "{usedQuotaByte} used" : "ใช้ไป {usedQuotaByte}",
+    "{used} of {quota} used" : "ใช้ไป {used} จาก {quota}",
     "{relative}% used" : "ใช้ไป {relative}%",
     "Could not refresh storage stats" : "ไม่สามารถรีเฟรชสถิติพื้นที่จัดเก็บ",
     "Your storage is full, files can not be updated or synced anymore!" : "พื้นที่จัดเก็บข้อมูลของคุณเต็มแล้ว ไม่สามารถอัปเดตหรือซิงค์ไฟล์ได้อีก!",
+    "New folder" : "โฟลเดอร์ใหม่",
+    "Create new folder" : "สร้างโฟลเดอร์ใหม่",
     "Create" : "สร้าง",
-    "Transfer ownership of a file or folder" : "โอนย้ายความเป็นเจ้าของไฟล์หรือโฟลเดอร์",
-    "Choose file or folder to transfer" : "เลือกไฟล์หรือโฟลเดอร์ที่จะโอนย้าย",
-    "Change" : "เปลี่ยนแปลง",
-    "New owner" : "เจ้าของใหม่",
+    "Submit" : "ส่ง",
     "Choose a file or folder to transfer" : "เลือกไฟล์หรือโฟลเดอร์ที่จะโอนย้าย",
     "Transfer" : "โอนย้าย",
     "Transfer {path} to {userid}" : "โอนย้าย {path} ไปยัง {userid}",
@@ -188,58 +85,158 @@ OC.L10N.register(
     "Unknown error" : "ข้อผิดพลาดที่ไม่รู้จัก",
     "Ownership transfer request sent" : "ส่งคำขอโอนย้ายความเป็นเจ้าของแล้ว",
     "Cannot transfer ownership of a file or folder you do not own" : "ไม่สามารถโอนย้ายความเป็นเจ้าของไฟล์หรือโฟลเดอร์ที่คุณไม่ได้เป็นเจ้าของ",
+    "Transfer ownership of a file or folder" : "โอนย้ายความเป็นเจ้าของไฟล์หรือโฟลเดอร์",
+    "Choose file or folder to transfer" : "เลือกไฟล์หรือโฟลเดอร์ที่จะโอนย้าย",
+    "Change" : "เปลี่ยนแปลง",
+    "New owner" : "เจ้าของใหม่",
     "Choose {file}" : "เลือก {file}",
+    "Shared by link" : "แชร์โดยลิงก์",
+    "Shared" : "ถูกแชร์",
+    "Not enough free space" : "พื้นที่ว่างไม่เพียงพอ",
+    "Operation is blocked by access control" : "การดำเนินการถูกห้ามไว้โดยการควบคุมการเข้าถึง",
     "No files in here" : "ไม่มีไฟล์ที่นี่",
     "Upload some content or sync with your devices!" : "ลองอัปโหลดเนื้อหาหรือซิงค์กับอุปกรณ์อื่นของคุณ",
     "Go back" : "กลับไป",
-    "Shared by link" : "แชร์โดยลิงก์",
-    "Shared" : "ถูกแชร์",
-    "Open the files app settings" : "เปิดการตั้งค่าแอปไฟล์",
     "Files settings" : "การตั้งค่าไฟล์",
+    "Clipboard is not available" : "คลิปบอร์ดไม่พร้อมใช้งาน",
     "Show hidden files" : "แสดงไฟล์ที่ซ่อนอยู่",
     "Crop image previews" : "ครอปตัดรูปภาพตัวอย่าง",
     "Additional settings" : "การตั้งค่าเพิ่มเติม",
     "WebDAV" : "WebDAV",
     "Copy to clipboard" : "คัดลอกไปยังคลิปบอร์ด",
     "Use this address to access your Files via WebDAV" : "ใช้ที่อยู่นี้เพื่อเข้าถึงไฟล์ของคุณผ่าน WebDAV",
-    "Clipboard is not available" : "คลิปบอร์ดไม่พร้อมใช้งาน",
-    "Unable to change the favourite state of the file" : "ไม่สามารถเปลี่ยนสถานะรายการโปรดของไฟล์",
+    "Keyboard shortcuts" : "แป้นพิมพ์ลัด",
+    "View" : "มุมมอง",
     "Error while loading the file data" : "ข้อผิดพลาดขณะโหลดข้อมูลไฟล์",
+    "Owner" : "เจ้าของ",
+    "Remove from favorites" : "เอาออกจากรายการโปรด",
+    "Add to favorites" : "เพิ่มในรายการโปรด",
+    "Tags" : "แท็ก",
+    "Blank" : "ว่าง",
+    "Unable to create new file from template" : "ไม่สามารถสร้างไฟล์ใหม่จากเทมเพลต",
     "Pick a template for {name}" : "เลือกเทมเพลตสำหรับ {name}",
     "Create a new file with the selected template" : "สร้างไฟล์ใหม่ด้วยเทมเพลตที่เลือก",
     "Creating file" : "กำลังสร้างไฟล์",
-    "Blank" : "ว่าง",
-    "Unable to create new file from template" : "ไม่สามารถสร้างไฟล์ใหม่จากเทมเพลต",
+    "Leave this share" : "ออกจากการแชร์นี้",
+    "Leave these shares" : "ออกจากการแชร์เหล่านี้",
+    "Disconnect storage" : "ยกเลิกการเชื่อมต่อพื้นที่จัดเก็บข้อมูล",
+    "Disconnect storages" : "เลิกเชื่อมต่อพื้นที่จัดเก็บข้อมูล",
     "Delete permanently" : "ลบแบบถาวร",
+    "Delete file" : "ลบไฟล์",
+    "Delete files" : "ลบไฟล์",
+    "Delete folders" : "ลบโฟลเดอร์",
+    "Delete" : "ลบ",
     "Cancel" : "ยกเลิก",
     "Copy to {target}" : "คัดลอกไปยัง {target}",
+    "Copy" : "คัดลอก",
     "Move to {target}" : "ย้ายไปยัง {target}",
-    "Filename" : "ชื่อไฟล์",
+    "Move" : "ย้าย",
+    "Move or copy" : "ย้ายหรือคัดลอก",
+    "Failed to redirect to client" : "เปลี่ยนเส้นทางไปยังไคลเอ็นต์ล้มเหลว",
+    "Rename" : "เปลี่ยนชื่อ",
+    "View in folder" : "ดูในโฟลเดอร์",
+    "Today" : "วันนี้",
+    "Last 7 days" : "ภายใน 7 วัน",
+    "Last 30 days" : "ภายใน 30 วัน",
+    "Folders" : "โฟลเดอร์",
+    "Audio" : "เสียง",
+    "Videos" : "วิดีโอ",
     "Unable to initialize the templates directory" : "ไม่สามารถเตรียมไดเรกทอรีเทมเพลต",
     "Templates" : "เทมเพลต",
+    "Some files could not be moved" : "ไม่สามารถย้ายบางไฟล์",
+    "This operation is forbidden" : "การดำเนินการนี้ถูกห้าม",
+    "This directory is unavailable, please check the logs or contact the administrator" : "ไม่สามารถใช้งานไดเรกทอรีนี้ โปรดตรวจสอบบันทึกหรือติดต่อผู้ดูแลระบบ",
+    "Storage is temporarily not available" : "พื้นที่จัดเก็บข้อมูลไม่สามารถใช้งานได้ชั่วคราว",
+    "_%n file_::_%n files_" : ["%n ไฟล์"],
+    "_%n folder_::_%n folders_" : ["%n โฟลเดอร์"],
     "No favorites yet" : "ยังไม่มีรายการโปรด",
     "Files and folders you mark as favorite will show up here" : "ไฟล์และโฟลเดอร์ที่คุณระบุเป็นรายการโปรดจะแสดงที่นี่",
     "All files" : "ไฟล์ทั้งหมด",
+    "Personal files" : "ไฟล์ส่วนตัว",
+    "Recent" : "ล่าสุด",
     "No entries found in this folder" : "ไม่พบรายการในโฟลเดอร์นี้",
     "Select all" : "เลือกทั้งหมด",
     "Upload too large" : "ไฟล์ที่อัปโหลดมีขนาดใหญ่เกินไป",
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "ไฟล์ที่คุณพยายามที่จะอัปโหลดมีขนาดเกินกว่าขนาดสูงสุดที่อัปโหลดได้สำหรับเซิร์ฟเวอร์นี้",
+    "File could not be found" : "ไม่พบไฟล์",
+    "Download" : "ดาวน์โหลด",
+    "Show list view" : "แสดงมุมมองรายการ",
+    "Show grid view" : "แสดงมุมมองตาราง",
+    "Close" : "ปิด",
+    "Could not create folder \"{dir}\"" : "ไม่สามารถสร้างโฟลเดอร์ \"{dir}\"",
+    "This will stop your current uploads." : "การกระทำนี้จะหยุดการอัปโหลดปัจจุบันของคุณ",
+    "Upload cancelled." : "การอัปโหลดถูกยกเลิก",
+    "Processing files …" : "กำลังประมวลผลไฟล์ …",
+    "…" : "…",
+    "Unable to upload {filename} as it is a directory or has 0 bytes" : "ไม่สามารถอัปโหลด {filename} เนื่องจากเป็นไดเรกทอรีหรือมี 0 ไบต์",
+    "Not enough free space, you are uploading {size1} but only {size2} is left" : "พื้นที่ว่างไม่เพียงพอ คุณกำลังจะอัปโหลด {size1} แต่เหลือพื้นที่แค่ {size2}",
+    "Target folder \"{dir}\" does not exist any more" : "ไม่มีโฟลเดอร์เป้าหมาย \"{dir}\" อีกต่อไป",
+    "An unknown error has occurred" : "เกิดข้อผิดพลาดที่ไม่รู้จัก",
+    "File could not be uploaded" : "ไม่สามารถอัปโหลดไฟล์",
+    "Uploading …" : "กำลังอัปโหลด …",
+    "{remainingTime} ({currentNumber}/{total})" : "{remainingTime} ({currentNumber}/{total})",
+    "Uploading … ({currentNumber}/{total})" : "กำลังอัปโหลด … ({currentNumber}/{total})",
+    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} จาก {totalSize} ({bitrate})",
+    "Uploading that item is not supported" : "ไม่รองรับการอัปโหลดสิ่งนั้น",
+    "Error when assembling chunks, status code {status}" : "ข้อผิดพลาดขณะประกอบกลุ่ม รหัสสถานะ {status}",
+    "Choose target folder" : "เลือกโฟลเดอร์เป้าหมาย",
+    "Edit locally" : "แก้ไขในต้นทาง",
+    "Open" : "เปิด",
+    "Could not load info for file \"{file}\"" : "ไม่สามารถโหลดข้อมูลสำหรับไฟล์ \"{file}\"",
+    "Details" : "รายละเอียด",
+    "Please select tag(s) to add to the selection" : "กรุณาเลือกแท็กเพื่อเพิ่มเข้าไปในรายการที่เลือก",
+    "Apply tag(s) to selection" : "นำแท็กไปใช้ในรายการที่เลือก",
+    "Select directory \"{dirName}\"" : "เลือกไดเร็กทอรี \"{dirName}\"",
+    "Select file \"{fileName}\"" : "เลือกไฟล์ \"{fileName}\"",
+    "Unable to determine date" : "ไม่สามารถระบุวัน",
+    "Could not move \"{file}\", target exists" : "ไม่สามารถย้าย \"{file}\" เป้าหมายมีอยู่แล้ว",
+    "Could not move \"{file}\"" : "ไม่สามารถย้ายไฟล์ \"{file}\"",
+    "copy" : "คัดลอก",
+    "Could not copy \"{file}\", target exists" : "ไม่สามารถคัดลอก \"{file}\" เป้าหมายมีอยู่แล้ว",
+    "Could not copy \"{file}\"" : "ไม่สามารถคัดลอก \"{file}\"",
+    "Copied {origin} inside {destination}" : "คัดลอก {origin} ไว้ใน {destination} แล้ว",
+    "Copied {origin} and {nbfiles} other files inside {destination}" : "คัดลอก {origin} และ {nbfiles} ไฟล์อื่น ๆ ไว้ใน {destination} แล้ว",
+    "{newName} already exists" : "{newName} มีอยู่แล้ว",
+    "Could not rename \"{fileName}\", it does not exist any more" : "ไม่สามารถเปลี่ยนชื่อไฟล์ \"{fileName}\" ไฟล์นั้นไม่มีอยู่",
+    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "ชื่อ \"{targetName}\" มีอยู่แล้วในโฟลเดอร์ \"{dir}\" กรุณาเปลี่ยนชื่อใหม่",
+    "Could not rename \"{fileName}\"" : "ไม่สามารถเปลี่ยนชื่อไฟล์ \"{fileName}\"",
+    "Could not create file \"{file}\"" : "ไม่สามารถสร้างไฟล์ \"{file}\"",
+    "Could not create file \"{file}\" because it already exists" : "ไม่สามารถสร้างไฟล์ \"{file}\" เพราะมันมีอยู่แล้ว",
+    "Could not create folder \"{dir}\" because it already exists" : "ไม่สามารถสร้างโฟลเดอร์ \"{dir}\" เพราะมันมีอยู่แล้ว",
+    "Could not fetch file details \"{file}\"" : "ไม่สามารถดึงข้อมูลไฟล์ \"{file}\"",
+    "Error deleting file \"{fileName}\"." : "เกิดข้อผิดพลาดขณะลบไฟล์ \"{fileName}\"",
+    "No search results in other folders for {tag}{filter}{endtag}" : "ไม่มีผลลัพธ์การค้นหาในโฟลเดอร์อื่นสำหรับ {tag}{filter}{endtag}",
+    "Enter more than two characters to search in other folders" : "ใส่มากกว่า 2 ตัวอักษร เพื่อค้นหาในโฟลเดอร์อื่น",
+    "{dirs} and {files}" : "{dirs} และ {files}",
+    "_including %n hidden_::_including %n hidden_" : ["รวมถึง %n ไฟล์ที่ซ่อนอยู่"],
+    "You do not have permission to upload or create files here" : "คุณไม่ได้รับอนุญาตให้อัปโหลดหรือสร้างไฟล์ที่นี่",
+    "_Uploading %n file_::_Uploading %n files_" : ["กำลังอัปโหลด %n ไฟล์"],
+    "New" : "ใหม่",
+    "New file/folder menu" : "เมนูไฟล์/โฟลเดอร์ใหม่",
+    "Select file range" : "เลือกช่วงไฟล์",
+    "{used}%" : "{used}%",
+    "{used} used" : "ใช้ไป {used}",
+    "\"{name}\" is an invalid file name." : "\"{name}\" เป็นชื่อไฟล์ที่ไม่ถูกต้อง",
+    "File name cannot be empty." : "ชื่อไฟล์ไม่สามารถเว้นว่างได้",
+    "\"/\" is not allowed inside a file name." : "ไม่อนุญาตให้ใช้ \"/\" ในชื่อไฟล์",
+    "\"{name}\" is not an allowed filetype" : "\"{name}\" เป็นประเภทไฟล์ที่ไม่ได้รับอนุญาต",
+    "Storage of {owner} is full, files cannot be updated or synced anymore!" : "พื้นที่จัดเก็บข้อมูลของ {owner} เต็มแล้ว ไม่สามารถอัปเดตหรือซิงค์ไฟล์ได้อีก!",
+    "Group folder \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "โฟลเดอร์กลุ่ม \"{mountPoint}\" เต็มแล้ว ไม่สามารถอัปเดตหรือซิงค์ไฟล์ได้อีก!",
+    "External storage \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "พื้นที่จัดเก็บข้อมูลภายนอก \"{mountPoint}\" เต็มแล้ว ไม่สามารถอัปเดตหรือซิงค์ไฟล์ได้อีก!",
+    "Your storage is full, files cannot be updated or synced anymore!" : "พื้นที่จัดเก็บข้อมูลของคุณเต็มแล้ว ไม่สามารถอัปเดตหรือซิงค์ไฟล์ได้อีก!",
+    "Storage of {owner} is almost full ({usedSpacePercent}%)." : "พื้นที่จัดเก็บข้อมูลของ {owner} ใกล้เต็มแล้ว ({usedSpacePercent}%)",
+    "Group folder \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "โฟลเดอร์กลุ่ม \"{mountPoint}\" ใกล้เต็มแล้ว ({usedSpacePercent}%)",
+    "External storage \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "พื้นที่จัดเก็บข้อมูลภายนอก \"{mountPoint}\" ใกล้เต็มแล้ว ({usedSpacePercent}%)",
+    "Your storage is almost full ({usedSpacePercent}%)." : "พื้นที่จัดเก็บข้อมูลของคุณใกล้เต็มแล้ว ({usedSpacePercent}%)",
+    "_matches \"{filter}\"_::_match \"{filter}\"_" : ["ตรงกับ \"{filter}\""],
+    "Direct link was copied (only works for people who have access to this file/folder)" : "คัดลอกลิงก์โดยตรงแล้ว (ใช้ได้เฉพาะผู้ใช้ที่มีสิทธิ์เข้าถึงไฟล์/โฟลเดอร์นี้)",
+    "Path" : "เส้นทาง",
+    "_%n byte_::_%n bytes_" : ["%n ไบต์"],
+    "Copy direct link (only works for people who have access to this file/folder)" : "คัดลอกลิงก์โดยตรง (ใช้ได้เฉพาะผู้ใช้ที่มีสิทธิ์เข้าถึงไฟล์/โฟลเดอร์นี้)",
+    "Upload file" : "อัปโหลดไฟล์",
+    "An error occurred while trying to update the tags" : "เกิดข้อผิดพลาดขณะกำลังพยายามอัปเดตแท็ก",
+    "Upload (max. %s)" : "อัปโหลด (สูงสุด %s)",
     "Text file" : "ไฟล์ข้อความ",
-    "New text file.txt" : "ไฟล์ข้อความใหม่.txt",
-    "Direct link was copied (only works for users who have access to this file/folder)" : "คัดลอกลิงก์โดยตรงแล้ว (ใช้ได้เฉพาะผู้ใช้ที่มีสิทธิ์เข้าถึงไฟล์/โฟลเดอร์นี้)",
-    "Copy direct link (only works for users who have access to this file/folder)" : "คัดลอกลิงก์โดยตรง (ใช้ได้เฉพาะผู้ใช้ที่มีสิทธิ์เข้าถึงไฟล์/โฟลเดอร์นี้)",
-    "You can only favorite a single file or folder at a time" : "คุณสามารถระบุเป็นรายการโปรดได้แค่ครั้งละ 1 ไฟล์หรือโฟลเดอร์",
-    "\"remote user\"" : "\"ผู้ใช้รีโมท\"",
-    "Search users" : "ค้นหาผู้ใช้",
-    "Set up templates folder" : "ตั้งค่าโฟลเดอร์เทมเพลต",
-    "Toggle %1$s sublist" : "สลับรายการย่อย %1$s",
-    "Toggle grid view" : "สลับมุมมองตาราง",
-    "Deleted files" : "ไฟล์ที่ถูกลบ",
-    "Shares" : "การแชร์",
-    "Shared with others" : "แชร์กับผู้อื่น",
-    "Shared with you" : "แชร์กับคุณ",
-    "Deleted shares" : "การแชร์ที่ถูกลบ",
-    "Pending shares" : "การแชร์ที่กำลังดำเนินการ",
-    "Choose" : "เลือก"
+    "New text file.txt" : "ไฟล์ข้อความใหม่.txt"
 },
 "nplurals=1; plural=0;");
