@@ -61,6 +61,10 @@ OC.L10N.register(
     "The ownership transfer of {path} from {user} has completed." : "Việc chuyển quyền sở hữu {path} từ {user} đã hoàn tất.",
     "in %s" : "trong %s",
     "Transferred from %1$s on %2$s" : "Chuyển từ %1$s tại %2$s",
+    "Files compatibility" : "Khả năng tương thích của tập tin",
+    "Allow to restrict filenames to ensure files can be synced with all clients. By default all filenames valid on POSIX (e.g. Linux or macOS) are allowed." : "Giới hạn tên tệp để đảm bảo tệp có thể đáp ứng với toàn bộ người dùng. Mặc định hệ thống sẽ cho phép các tập tin có tên hợp lệ trên hệ POSIX (vd. Linux hoặc macOS).",
+    "Enforce Windows compatibility" : "Bắt buộc tên tệp phải tương thích với Windows",
+    "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity." : "Tính năng này sẽ chặn tên tệp không hợp lệ trên hệ thống Windows, như sử dụng tên dành riêng hoặc ký tự đặc biệt. Tuy nhiên, tính năng này sẽ không bắt buộc với chữ in hoa và in thường.",
     "File Management" : "Quản lý tệp tin",
     "Home" : "Trang nhà",
     "Target folder does not exist any more" : "Thư mục đích không còn tồn tại",
@@ -86,7 +90,6 @@ OC.L10N.register(
     "Pending" : "Đang chờ",
     "Clear filter" : "Xóa bộ lọc",
     "Modified" : "Đã thay đổi vào:",
-    "Search everywhere" : "Tìm ở bất kì đâu",
     "Type" : "Loại",
     "Active filters" : "Bộ lọc đang hoạt động",
     "Remove filter" : "Xoá bộ lọc",
@@ -94,12 +97,15 @@ OC.L10N.register(
     "Toggle selection for all files and folders" : "Lựa chọn toàn bộ tập tin và thư mục",
     "Name" : "Tên",
     "Size" : "Kích cỡ",
+    "\"{displayName}\" batch action executed successfully" : "Chỉnh sửa hàng loạt \"{displayName}\" được thực hiện thành công",
+    "\"{displayName}\" action failed" : "Hành động \"{displayName}\" đã thực thi thất bại",
     "Actions" : "Hành động",
     "(selected)" : "(đã chọn)",
     "List of files and folders." : "Danh sách các tập tin và thư mục.",
     "Column headers with buttons are sortable." : "Tiêu đề cột có thể sắp xếp được.",
     "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "Danh sách này không được hiển thị đầy đủ để tăng hiệu năng. Các tập tin sẽ được hiển thị khi bạn điều hướng qua danh sách.",
     "File not found" : "Không tìm thấy tập tin",
+    "{count} selected" : "đã chọn {count} ",
     "{usedQuotaByte} used" : "{usedQuotaByte} đã được sử dụng",
     "{used} of {quota} used" : "{used} trong {quota} đã được sử dụng",
     "{relative}% used" : "đã sử dụng {relative}%",
@@ -111,7 +117,6 @@ OC.L10N.register(
     "Create new folder" : "Tạo thư mục mới",
     "This name is already in use." : "Tên này đã được sử dụng.",
     "Create" : "Tạo",
-    "Refresh" : "Tải mới",
     "Fill template fields" : "Tự động điền các trường thông tin",
     "Submit" : "Gửi",
     "Choose a file or folder to transfer" : "Chọn tệp hoặc thư mục cần chuyển",
@@ -127,25 +132,6 @@ OC.L10N.register(
     "New owner" : "Chủ sở hữu mới",
     "Select file or folder to link to" : "Chọn tập tin hoặc thư mục để liên kết tới",
     "Choose {file}" : "Chọn {file}",
-    "Clipboard is not available" : "Bộ nhớ tạm không có sẵn",
-    "Files settings" : "Cài đặt tập tin",
-    "General" : "Cài đặt chung",
-    "All files" : "Tất cả tệp tin",
-    "Sort favorites first" : "Sắp xếp mục yêu thích trước",
-    "Sort folders before files" : "Sắp xếp thư mục trước tập tin",
-    "Appearance" : "Giao diện",
-    "Show hidden files" : "Hiển thị các tệp ẩn",
-    "Crop image previews" : "Xén ảnh xem trước",
-    "Additional settings" : "Cài đặt bổ sung",
-    "Copy" : "Sao chép",
-    "Keyboard shortcuts" : "Phím tắt",
-    "Rename" : "Đổi tên",
-    "Delete" : "Xóa",
-    "Manage tags" : "Quản lý nhãn",
-    "Selection" : "Lựa chọn",
-    "Deselect all" : "Bỏ chọn tất cả",
-    "Navigation" : "Điều hướng",
-    "View" : "Xem",
     "Share" : "Chia sẻ",
     "Shared by link" : "Được chia sẻ với liên kết",
     "Shared" : "Đã chia sẻ",
@@ -157,12 +143,34 @@ OC.L10N.register(
     "Error during upload: {message}" : "Lỗi khi đang tải lên: {message}",
     "Error during upload, status code {status}" : "Lỗi khi đang tải lên, mã lỗi {status}",
     "Unknown error during upload" : "Lỗi không xác định trong quá trình tải lên",
+    "\"{displayName}\" action executed successfully" : "Hành động \"{displayName}\" đã thực thi thành công",
     "Loading current folder" : "Đang tải thư mục hiện tại",
     "Retry" : "Thử lại",
     "No files in here" : "Không có tệp nào",
     "Upload some content or sync with your devices!" : "Tải lên một số nội dung hoặc đồng bộ với thiết bị của bạn!",
     "Go back" : "Quay lại",
     "Views" : "Lượt xem",
+    "Files settings" : "Cài đặt tập tin",
+    "Your files" : "Tập tin của bạn",
+    "Open in files" : "Mở trong Tệp",
+    "File cannot be accessed" : "Không thể truy cập tập tin",
+    "The file could not be found or you do not have permissions to view it. Ask the sender to share it." : "Không thể tìm thấy tệp hoặc bạn không có quyền xem tệp. Hãy yêu cầu người gửi cấp quyền truy cập.",
+    "Clipboard is not available" : "Bộ nhớ tạm không có sẵn",
+    "WebDAV URL copied to clipboard" : "Đã sao chép URL WebDAV vào bộ nhớ tạm",
+    "Sort favorites first" : "Sắp xếp mục yêu thích trước",
+    "Sort folders before files" : "Sắp xếp thư mục trước tập tin",
+    "Show hidden files" : "Hiển thị các tệp ẩn",
+    "Crop image previews" : "Xén ảnh xem trước",
+    "Enable the grid view" : "Bật chế độ xem lưới",
+    "Enable folder tree" : "Bật cây thư mục",
+    "Additional settings" : "Cài đặt bổ sung",
+    "Copy to clipboard" : "Sao chép vào bộ nhớ tạm",
+    "Use this address to access your Files via WebDAV" : "Sử dụng địa chỉ này để truy cập Tệp của bạn qua WebDAV",
+    "If you have enabled 2FA, you must create and use a new app password by clicking here." : "Nếu bạn đã bật 2FA, bạn phải tạo và sử dụng mật khẩu ứng dụng mới bằng cách nhấp vào đây.",
+    "Keyboard shortcuts" : "Phím tắt",
+    "Selection" : "Lựa chọn",
+    "Navigation" : "Điều hướng",
+    "View" : "Xem",
     "You" : "Bạn",
     "Shared multiple times with different people" : "Được chia sẻ nhiều lần với những người khác nhau",
     "Error while loading the file data" : "Lỗi xảy ra trong khi tải dữ liệu tệp",
@@ -170,19 +178,12 @@ OC.L10N.register(
     "Remove from favorites" : "Xóa khỏi ưa thích",
     "Add to favorites" : "Thêm vào ưa thích",
     "Tags" : "Nhãn",
-    "Your files" : "Tập tin của bạn",
-    "Open in files" : "Mở trong Tệp",
-    "File cannot be accessed" : "Không thể truy cập tập tin",
-    "The file could not be found or you do not have permissions to view it. Ask the sender to share it." : "Không thể tìm thấy tệp hoặc bạn không có quyền xem tệp. Hãy yêu cầu người gửi cấp quyền truy cập.",
-    "Allow to restrict filenames to ensure files can be synced with all clients. By default all filenames valid on POSIX (e.g. Linux or macOS) are allowed." : "Giới hạn tên tệp để đảm bảo tệp có thể đáp ứng với toàn bộ người dùng. Mặc định hệ thống sẽ cho phép các tập tin có tên hợp lệ trên hệ POSIX (vd. Linux hoặc macOS).",
-    "Files compatibility" : "Khả năng tương thích của tập tin",
-    "Enforce Windows compatibility" : "Bắt buộc tên tệp phải tương thích với Windows",
-    "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity." : "Tính năng này sẽ chặn tên tệp không hợp lệ trên hệ thống Windows, như sử dụng tên dành riêng hoặc ký tự đặc biệt. Tuy nhiên, tính năng này sẽ không bắt buộc với chữ in hoa và in thường.",
     "Blank" : "Trống",
     "Unable to create new file from template" : "Không thể tạo tệp mới từ mẫu",
     "Pick a template for {name}" : "Hãy chọn một mẫu cho {name}",
     "Create a new file with the selected template" : "Tạo tệp mới với mẫu đã chọn",
     "Creating file" : "Tạo tệp",
+    "Deletion cancelled" : "Thao tác xóa bị hủy",
     "Leave this share" : "Rời khỏi mục chia sẻ này",
     "Leave these shares" : "Rời khỏi mục chia sẻ",
     "Disconnect storage" : "Ngắt kết nối bộ nhớ",
@@ -193,31 +194,36 @@ OC.L10N.register(
     "Delete files" : "Xoá các tập tin",
     "Delete folder" : "Xoá thư mục",
     "Delete folders" : "Xoá các thư mục",
+    "Delete" : "Xóa",
     "_You are about to permanently delete {count} item_::_You are about to permanently delete {count} items_" : ["Bặn sắp xoá vĩnh viễn {count} mục"],
     "_You are about to delete {count} item_::_You are about to delete {count} items_" : ["Bạn sắp xoá {count} mục"],
     "Confirm deletion" : "Xác nhận xoá",
     "Cancel" : "Hủy bỏ",
-    "Download" : "Tải về",
-    "Destination is not a folder" : "Đích đến không phải là một thư mục",
-    "This file/folder is already in that directory" : "Tệp/thư mục này đã có trong thư mục đó",
+    "Moving \"{source}\" to \"{destination}\" …" : "Di chuyển \"{source}\" đến \"{destination}\" …",
+    "Copying \"{source}\" to \"{destination}\" …" : "Sao chéo \"{source}\" đến \"{destination}\" …",
     "You cannot move a file/folder onto itself or into a subfolder of itself" : "Bạn không thể di chuyển một tập tin/thư mục vào chính nó hoặc vào một thư mục con của chính nó",
     "(copy)" : "(sao chép)",
     "(copy %n)" : "(sao chép %n)",
+    "Move cancelled" : "Di chuyển bị dừng",
     "A file or folder with that name already exists in this folder" : "Tệp hoặc thư mục có tên đó đã tồn tại trong thư mục này",
     "The files are locked" : "Tập tin bị khoá",
     "The file does not exist anymore" : "Tập tin không tồn tại nữa",
     "Choose destination" : "Lựa chọn điểm đến",
     "Copy to {target}" : "Copy to {target}",
+    "Copy" : "Sao chép",
     "Move to {target}" : "Di chuyển đến {target}",
     "Move" : "Dịch chuyển",
     "Move or copy operation failed" : "Thao tác di chuyển hoặc sao chép thất bại",
     "Move or copy" : "Di chuyển hoặc sao chép",
+    "Cancelled move or copy of \"{filename}\"." : "Đã huỷ việc di chuyển hoặc sao chép của \"{filename}\".",
+    "Cancelled move or copy operation" : "Đã hủy thao tác di chuyển hoặc sao chép",
     "Open folder {displayName}" : "Mở thư mục {displayName}",
     "Open in Files" : "Mở trong Tệp",
     "Open locally" : "Mở cục bộ (local)/ ngoại tuyến",
     "Failed to redirect to client" : "Không thể chuyển hướng đến ứng dụng khách",
     "Open file locally" : "Mở tệp cục bộ (local)/ ngoại tuyến",
-    "Details" : "Chi tiết",
+    "Rename" : "Đổi tên",
+    "Open details" : "Mở chi tiết",
     "View in folder" : "Xem trong thư mục",
     "Today" : "Hôm nay",
     "Last 7 days" : "7 ngày trước",
@@ -227,8 +233,9 @@ OC.L10N.register(
     "Presentations" : "Bản trình chiếu",
     "Folders" : "Thư mục",
     "Audio" : "Âm thanh",
-    "Images" : "Hình ảnh",
+    "Photos and images" : "Ảnh",
     "Videos" : "Phim",
+    "New folder creation cancelled" : "Lỗi tạo thư mục",
     "Created new folder \"{name}\"" : "Đã tạo thư mục mới \"{name}\"",
     "Unable to initialize the templates directory" : "Không thể khởi tạo thư mục mẫu",
     "Create templates folder" : "Tạo thư mục mẫu",
@@ -247,10 +254,8 @@ OC.L10N.register(
     "Files moved successfully" : "Tệp tin được di chuyển thành công",
     "Conflicts resolution skipped" : "Đã bỏ qua giải quyết xung đột",
     "Upload cancelled" : "Hủy tải lên",
-    "Could not rename \"{oldName}\", it does not exist any more" : "Không thể đổi tên \"{oldName}\", tệp tin không còn tồn tại",
-    "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Tên \"{newName}\" đã được sử dụng trong thư mục \"{dir}\". Vui lòng chọn một tên khác.",
-    "Could not rename \"{oldName}\"" : "Không thể đổi tên \"{oldName}\"",
     "This operation is forbidden" : "Thao tác bị cấm",
+    "This directory is unavailable, please check the logs or contact the administrator" : "Thư mục này không sẵn có, hãy kiểm tra log hoặc liên hệ người quản lý",
     "Storage is temporarily not available" : "Kho lưu trữ tạm thời không khả dụng",
     "_%n file_::_%n files_" : ["%n tập tin"],
     "_%n folder_::_%n folders_" : ["%n thư mục"],
@@ -262,7 +267,9 @@ OC.L10N.register(
     "List of favorite files and folders." : "Danh sách tệp và thư mục yêu thích.",
     "No favorites yet" : "Chưa có yêu thích nào",
     "Files and folders you mark as favorite will show up here" : "Các tệp và thư mục mà bạn đánh dấu là yêu thích sẽ hiển thị ở đây",
+    "All files" : "Tất cả tệp tin",
     "List of your files and folders." : "Danh sách các tập tin và thư mục của bạn.",
+    "All folders" : "Tất cả tệp tin",
     "List of your files and folders that are not shared." : "Danh sách tệp tin và thư mục không được chia sẻ của bạn.",
     "No personal files found" : "Không có tệp cá nhân nào được tìm thấy",
     "Files that are not shared will show up here." : "Các tệp và thư mục bạn đã không chia sẻ sẽ hiện thị ở đây.",
@@ -270,12 +277,12 @@ OC.L10N.register(
     "List of recently modified files and folders." : "Danh sách các tập tin và thư mục được sửa đổi gần đây.",
     "No recently modified files" : "Không có tập tin được sửa đổi gần đây",
     "Files and folders you recently modified will show up here." : "Các tập tin và thư mục bạn sửa đổi gần đây sẽ hiển thị ở đây.",
-    "Search" : "Tìm kiếm",
     "No entries found in this folder" : "Chưa có mục nào trong thư mục",
     "Select all" : "Chọn tất cả",
     "Upload too large" : "Tập tin tải lên quá lớn",
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Các tập tin bạn đang tải lên vượt quá kích thước tối đa cho phép trên máy chủ .",
     "File could not be found" : "Tệp tin không tồn tại",
+    "Download" : "Tải về",
     "Show list view" : "Hiển thị chế độ xem danh sách",
     "Show grid view" : "Hiển thị chế độ xem lưới",
     "Close" : "Đóng",
@@ -299,12 +306,12 @@ OC.L10N.register(
     "Edit locally" : "Chỉnh sửa cục bộ/ngoại tuyến",
     "Open" : "Mở",
     "Could not load info for file \"{file}\"" : "Không thể tải thông tin cho tệp \"{file}\"",
+    "Details" : "Chi tiết",
     "Please select tag(s) to add to the selection" : "Vui lòng chọn (các) thẻ để thêm vào lựa chọn",
     "Apply tag(s) to selection" : "Áp dụng (các) thẻ cho lựa chọn",
     "Select directory \"{dirName}\"" : "Chọn thư mục \"{dirName}\"",
     "Select file \"{fileName}\"" : "Chọn tệp tin \"{fileName}\"",
     "Unable to determine date" : "Không thể xác định ngày",
-    "This directory is unavailable, please check the logs or contact the administrator" : "Thư mục này không sẵn có, hãy kiểm tra log hoặc liên hệ người quản lý",
     "Could not move \"{file}\", target exists" : "Không thể di chuyển \"{file}\", trùng đích đến",
     "Could not move \"{file}\"" : "Không thể di chuyển \"{file}\"",
     "copy" : "sao chép",
@@ -313,6 +320,9 @@ OC.L10N.register(
     "Copied {origin} inside {destination}" : "Được sao chép {origin} vào trong {destination}",
     "Copied {origin} and {nbfiles} other files inside {destination}" : "Đã sao chép {origin} và {nbfiles} các file vào trong {destination}",
     "{newName} already exists" : "{newName} đã có",
+    "Could not rename \"{fileName}\", it does not exist any more" : "Không thể đổi tên \"{fileName}\", tập tin không tồn tại",
+    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Tên \"{targetName}\" đã được dùng trong thư mục \"{dir}\". Hãy thử tên khác",
+    "Could not rename \"{fileName}\"" : "Không thể đổi tên \"{fileName}\"",
     "Could not create file \"{file}\"" : "Không thể tạo tập tin \"{file}\"",
     "Could not create file \"{file}\" because it already exists" : "Không thể tạo tập tin \"{file}\" vì đã có ",
     "Could not create folder \"{dir}\" because it already exists" : "Không thể tạo thư mục “{dir}” vì đã có",
@@ -351,31 +361,12 @@ OC.L10N.register(
     "Not favored" : "Không được ưa thích",
     "An error occurred while trying to update the tags" : "Đã xảy ra lỗi khi cố gắng cập nhật tags",
     "Upload (max. %s)" : "Tải lên (tối đa %s)",
-    "\"{displayName}\" action executed successfully" : "Hành động \"{displayName}\" đã thực thi thành công",
-    "\"{displayName}\" action failed" : "Hành động \"{displayName}\" đã thực thi thất bại",
-    "\"{displayName}\" batch action executed successfully" : "Chỉnh sửa hàng loạt \"{displayName}\" được thực hiện thành công",
     "Filter filenames…" : "Lọc tên tệp…",
-    "WebDAV URL copied to clipboard" : "Đã sao chép URL WebDAV vào bộ nhớ tạm",
-    "Enable the grid view" : "Bật chế độ xem lưới",
-    "Enable folder tree" : "Bật cây thư mục",
-    "Copy to clipboard" : "Sao chép vào bộ nhớ tạm",
-    "Use this address to access your Files via WebDAV" : "Sử dụng địa chỉ này để truy cập Tệp của bạn qua WebDAV",
-    "If you have enabled 2FA, you must create and use a new app password by clicking here." : "Nếu bạn đã bật 2FA, bạn phải tạo và sử dụng mật khẩu ứng dụng mới bằng cách nhấp vào đây.",
-    "Deletion cancelled" : "Thao tác xóa bị hủy",
-    "Moving \"{source}\" to \"{destination}\" …" : "Di chuyển \"{source}\" đến \"{destination}\" …",
-    "Copying \"{source}\" to \"{destination}\" …" : "Sao chéo \"{source}\" đến \"{destination}\" …",
-    "Move cancelled" : "Di chuyển bị dừng",
-    "Cancelled move or copy of \"{filename}\"." : "Đã huỷ việc di chuyển hoặc sao chép của \"{filename}\".",
-    "Cancelled move or copy operation" : "Đã hủy thao tác di chuyển hoặc sao chép",
-    "Open details" : "Mở chi tiết",
-    "Photos and images" : "Ảnh",
-    "New folder creation cancelled" : "Lỗi tạo thư mục",
     "_{folderCount} folder_::_{folderCount} folders_" : ["thư mục {folderCount}"],
     "_{fileCount} file_::_{fileCount} files_" : ["tệp {fileCount}"],
     "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["1 tệp và thư mục {folderCount}"],
     "_{fileCount} file and 1 folder_::_{fileCount} files and 1 folder_" : ["tệp {fileCount} và 1 thư mục"],
     "{fileCount} files and {folderCount} folders" : "Tệp {fileCount} và thư mục {folderCount}",
-    "All folders" : "Tất cả tệp tin",
     "Personal Files" : "Tệp tin cá nhân",
     "Text file" : "Tập tin văn bản",
     "New text file.txt" : "Tệp văn bản mới.txt"
