@@ -21,9 +21,6 @@ OC.L10N.register(
     "Mark selection as favorite" : "Merkitse valinta suosikeiksi",
     "Add selection to favorites" : "Lisää valinta suosikkeihin",
     "Remove selection from favorites" : "Poista valinta suosikeista",
-    "This name is already in use." : "Tämä nimi on jo käytössä.",
-    "\"{char}\" is not allowed inside a filename." : "\"{char}\" ei ole sallittu tiedoston nimessä.",
-    "Invalid filename." : "Epäkelpo tiedostonimi.",
     "Name of the album" : "Albumin nimi",
     "Location of the album" : "Albumin sijainti",
     "Back" : "Takaisin",
@@ -42,6 +39,8 @@ OC.L10N.register(
     "Add people or groups who can edit your album" : "Lisää henkilöitä tai ryhmiä, jotka voivat muokata albumia",
     "Search people or groups" : "Etsi käyttäjiä tai ryhmiä",
     "No recommendations. Start typing." : "Ei suosituksia. Aloita kirjoittaminen.",
+    "Group" : "Ryhmä",
+    "Remove {collaboratorLabel} from the collaborators list" : "Poista {collaboratorLabel} osanottajista",
     "Copy the public link" : "Kopioi julkinen linkki",
     "Public link copied!" : "Julkinen linkki kopioitu!",
     "Copy public link" : "Kopioi julkinen linkki",
@@ -113,7 +112,7 @@ OC.L10N.register(
     "This might take some time depending on the size of your photo library." : "Tämä saattaa kestää hetken riippuen kuvakirjastosi koosta.",
     "Recognized people will show up here" : "Tunnistetut henkilöt näkyvät täällä",
     "This folder does not exist" : "Tätä kansiota ei ole olemassa",
-    "Loading folders…" : "Ladataan kansioita…",
+    "Loading folders …" : "Ladataan kansioita…",
     "No photos in here" : "Ei kuvia täällä",
     "Taken on {date} at {time}" : "Otettu {date} kello {time}",
     "This place does not have any photos or videos yet!" : "Tässä sijainnissa ei ole vielä kuvia tai videoita!",
@@ -143,19 +142,13 @@ OC.L10N.register(
     "Tagged photos" : "Tunnisteilla varustetut kuvat",
     "Tagged photo {title}" : "Kuvaan {title} asetettu tunniste",
     "{title}'s face" : "Henkilön {title} kasvot",
-    "Last week" : "Viime viikko",
     "{startDate} to {endDate}" : "{startDate} - {endDate}",
     "Details" : "Tiedot",
-    "Failed to delete {fileBaseName}" : "Kohteen {fileBaseName} poistaminen epäonnistui",
-    "Failed to delete {collectionFileName}" : "Kohteen {collectionFileName} poistaminen epäonnistui",
     "Failed to delete {faceName}" : "Kohteen {faceName} poistaminen epäonnistui",
     "Failed to delete {fileId}" : "Kohteen {fileId} poistaminen epäonnistui",
     "Failed to delete {fileName}" : "Kohteen {fileName} poistaminen epäonnistui",
-    "Group" : "Ryhmä",
-    "Remove {collaboratorLabel} from the collaborators list" : "Poista {collaboratorLabel} osanottajista",
     "Back to {folder}" : "Takaisin kansioon {folder}",
     "Share this folder" : "Jaa tämä kansio",
-    "Loading folders …" : "Ladataan kansioita…",
     "One of the source folders does not exists" : "Yksi lähdekansioista ei ole olemassa",
     "Add" : "Lisää"
 },
