@@ -52,15 +52,17 @@ OC.L10N.register(
     "No picture for this day" : "Non ci sono foto in questo giorno",
     "Picture taken on this day will show up here." : "Le foto di questo giorno appariranno qui.",
     "More photos from this day" : "Più foto di questo giorno",
+    "_%n photos_::_%n photos_" : ["%n foto","%n foto","%n foto"],
     "_%n unassigned photo_::_%n unassigned photos_" : ["%n foto non assegnata","%n foto non assegnate","%n foto non assegnate"],
     "Favorite" : "Preferito",
     "Favorite image, open the full size \"{name}\" image" : "Immagine preferita, apri l'immagine \"{name}\" a dimensione intera",
     "Open the full size \"{name}\" image" : "Apri l'immagine \"{name}\" a dimensione piena",
     "Select image {imageName}" : "Seleziona immagine {imageName}",
     "Open the \"{name}\" folder" : "Apri la cartella \"{name}\"",
-    "Back to {folder}" : "Torna a {folder}",
     "Go back" : "Indietro",
-    "Share this folder" : "Condividi questa cartella",
+    "Date range" : "Intervallo di date",
+    "Select a date range" : "Seleziona un intervallo di date",
+    "Select places" : "Seleziona luoghi",
     "Dates" : "Date",
     "Jump to specific date in list" : "Vai alla data specifica nella lista",
     "Jump to {date}" : "Vai a {date}",
@@ -86,6 +88,7 @@ OC.L10N.register(
     "Choose the folder where photos and albums are uploaded to." : "Scegli la cartella dove foto ed album verranno caricati",
     "_%n photo_::_%n photos_" : ["%n foto","%n foto","%n foto"],
     "Unselect all" : "Deseleziona tutto",
+    "Toggle filter" : "Attiva/disattiva filtro",
     "Add photos to this album" : "Aggiungi foto a questo album",
     "Manage collaborators for this album" : "Gestisci i collaboratori di questo album",
     "Open actions menu" : "Apri il menu azioni",
@@ -134,10 +137,10 @@ OC.L10N.register(
     "Delete selection" : "Elimina selezione",
     "No photos or videos in here" : "Nessuna foto o video qui",
     "Unassigned faces" : "Volti non assegnati",
-    "_%n photos_::_%n photos_" : ["%n foto","%n foto","%n foto"],
     "Failed to fetch collection." : "Recupero della categoria non riuscito.",
     "Failed to fetch collections list." : "Recupero della lista di collezioni non riuscito.",
     "Failed to fetch faces list." : "Recupero della lista di volti non riuscito.",
+    "Error fetching files" : "Errore durante il recupero dei file",
     "All your media" : "Tutti i tuoi media",
     "Album {title}" : "Album {title}",
     "Shared Albums" : "Album condivisi",
@@ -155,6 +158,8 @@ OC.L10N.register(
     "Failed to set favorite state for {fileId}" : "Impossibile impostare lo stato preferito per {fileId}",
     "Failed to set favorite state for {fileName}" : "Impossibile impostare lo stato preferito per {fileName}",
     "Could not load photos folder" : "Non è stato possibile caricare la cartella foto",
+    "Back to {folder}" : "Torna a {folder}",
+    "Share this folder" : "Condividi questa cartella",
     "One of the source folders does not exists" : "Una delle cartelle sorgenti non esiste",
     "Add" : "Aggiungi"
 },
