@@ -34,6 +34,8 @@ OC.L10N.register(
     "Create new album" : "Креирај албум",
     "New album" : "Нови албум",
     "_%n item_::_%n photos and videos_" : ["%n ставка","%n фотографије и видео снимка","%n форографија и видео снимака"],
+    "Failed to fetch collaborators list." : "Није успело добављање листе сарадника.",
+    "Failed to update album." : "Није успело ажурирање албума.",
     "Add people or groups who can edit your album" : "Додај људе или групе које могу да уређују ваш албум",
     "Search people or groups" : "Претрага људи и група",
     "No recommendations. Start typing." : "Нема препорука. Започните куцање.",
@@ -45,38 +47,40 @@ OC.L10N.register(
     "Delete the public link" : "Обриши јавни линк",
     "Create public link share" : "Направи дељење јавном везом",
     "Share via public link" : "Подели путем јавног линка",
-    "Failed to fetch collaborators list." : "Није успело добављање листе сарадника.",
-    "Failed to update album." : "Није успело ажурирање албума.",
     "This collection does not exist" : "Ова колекција не постоји",
     "An error occurred" : "Догодила се грешка",
     "No picture for this day" : "Нема слика за данашњи дан",
     "Picture taken on this day will show up here." : "Овде ће се појавити слика направљена на данашњи дан.",
     "More photos from this day" : "Још слика за данас",
+    "_%n photos_::_%n photos_" : ["%n фотографија","%n фотографије","%n фотографија"],
     "_%n unassigned photo_::_%n unassigned photos_" : ["%n недодељена фотографија","%n недодељене фотографије","%n недодељених фотографија"],
     "Favorite" : "Омиљени",
-    "Select image {imageName}" : "Изабери слику {imageName}",
     "Favorite image, open the full size \"{name}\" image" : "Омиљена слика, отвори слику „{name}” у пуној величини",
     "Open the full size \"{name}\" image" : "Отвори слику „{name}” у пуној величини",
+    "Select image {imageName}" : "Изабери слику {imageName}",
     "Open the \"{name}\" folder" : "Отвори „{name}” директоријум",
     "Go back" : "Иди назад",
-    "Back to {folder}" : "Назад у {folder}",
-    "Share this folder" : "Дели ову фасциклу",
+    "Date range" : "Опсег датума",
+    "Select a date range" : "Изаберите опсег датума",
+    "Select places" : "Изаберите места",
     "Dates" : "Датуми",
     "Jump to specific date in list" : "Скок на одређени датум у листи",
     "Jump to {date}" : "Скочи на {date}",
     "Add to {destination}" : "Додај у {destination}",
+    "The destination folder is owned by {owner}" : "{owner} је власник циљног фолдера",
     "There are no photos or videos yet!" : "Још увек нема фотографија или видео снимака!",
     "_{years} year ago_::_{years} years ago_" : ["пре {years} године","пре {years} године","пре {years} година"],
     "Enable squared photos view" : "Укључи квадратасти приказ слика",
     "Delete source directory" : "Обриши изворни директоријум",
+    "Pick folder" : "Изаберите фолдер",
+    "Select a source folder for your media" : "Изаберите извирни фолдер за своје медије",
     "All folders" : "Сви фолдери",
     "Add a Photos source for the timelines" : "Додајте извор који ће Фотографије употребити за временске линије",
     "Add folder" : "Додај фасциклу",
-    "Select a source folder for your media" : "Изаберите извирни фолдер за своје медије",
+    "Select the default upload location for your media" : "Изаберите подразумевано место отпремања својих медија",
     "Home" : "Почетна",
     "Choose default Photos upload and Albums location" : "Изаберите подразумевано место за отпремање Фотографија и албума",
     "Choose a different folder" : "Изаберите неки други фолдер",
-    "Select the default upload location for your media" : "Изаберите подразумевано место отпремања својих медија",
     "View" : "Погледај",
     "Media folders" : "Фолдери медија",
     "Choose the folders from where photos and videos are shown." : "Изаберите фолдере из којих се приказују фотографије и видео снимци.",
@@ -84,6 +88,8 @@ OC.L10N.register(
     "Choose the folder where photos and albums are uploaded to." : "Изаберите фолдер у који се отпремају фотографије и албуми.",
     "_%n photo_::_%n photos_" : ["%n фотографија","%n фотографије","%n фотографија"],
     "Unselect all" : "Поништи цео избор",
+    "Toggle filter" : "Укључи/искључи филтер",
+    "Add photos to this album" : "Додај фотографије у овај албум",
     "Manage collaborators for this album" : "Управљање сарадницима на овом албуму",
     "Open actions menu" : "Отвори мени са акцијама",
     "Edit album details" : "Уреди детаље о албуму",
@@ -92,7 +98,6 @@ OC.L10N.register(
     "Download selected files" : "Преузми изабране фајлове",
     "Remove selection from album" : "Уклони избор са албума",
     "This album does not have any photos or videos yet!" : "Овај албум још увек нема ниједну фотографију или видео снимак!",
-    "Add photos to this album" : "Додај фотографије у овај албум",
     "Add photos to {albumName}" : "Додај фотографије у {albumName}",
     "Manage collaborators" : "Управљај сарадницима",
     "Save collaborators for this album." : "Сачувај сараднике на овом албуму",
@@ -120,23 +125,23 @@ OC.L10N.register(
     "Add photos to this place" : "Додај фотографије на ово место",
     "Cover photo for place {placeName}" : "Фотографија омота за место {placeName}",
     "There is no place yet!" : "Још увек нема места!",
-    "Cover photo for shared album {albumName}." : "Фотографија омота за дељени албум {albumName}.",
+    "Cover photo for shared album {albumName}" : "Фотографија омота за дељени албум {albumName}",
     "Back to tags overview" : "Назад на преглед ознака",
     "No photos with this tag yet" : "Још увек нема фотографија са овом ознаком",
     "No tags yet" : "Још нема ознака",
     "Photos with tags will show up here" : "Слике са ознакама ће се појавити овде",
     "Popular tags" : "Популарне ознаке",
     "All tags" : "Све ознаке",
-    "One of the source folders does not exists" : "Један од изворних фолдера не постоји",
-    "Add" : "Додај",
+    "Create new album from filters" : "Креирај нови албум из филтера",
+    "One of the source folders does not exist" : "Један од изворних фолдера не постоји",
     "Add to album" : "Додај у албум",
     "Delete selection" : "Обриши одабир",
     "No photos or videos in here" : "Овде нема фотографија или видео снимака",
     "Unassigned faces" : "Недодељена лица",
-    "_%n photos_::_%n photos_" : ["%n фотографија","%n фотографије","%n фотографија"],
     "Failed to fetch collection." : "Није успело добављање колекције.",
     "Failed to fetch collections list." : "Није успело добављање листе колекција.",
     "Failed to fetch faces list." : "Није успело добављање листе лица.",
+    "Error fetching files" : "Грешка приликом преузимања фајлова",
     "All your media" : "Сви ваши медији",
     "Album {title}" : "Албум {title}",
     "Shared Albums" : "Дељени албуми",
@@ -147,16 +152,16 @@ OC.L10N.register(
     "{title}'s face" : "лице {title}",
     "{startDate} to {endDate}" : "{startDate} до {endDate}",
     "Details" : "Детаљи",
-    "Failed to rename {oldName} to {faceName}." : "Није успела промена имена {oldName} у {faceName}.",
-    "Failed to delete {faceName}." : "Није успело брисање {faceName}.",
-    "Failed to delete {fileId}." : "Није успело брисање {fileId}.",
-    "Failed to delete {fileName}." : "Није успело брисање {fileName}.",
-    "Failed to set favorite state for {fileId}." : "Није успело постављање стања омиљено за {fileId}.",
-    "Failed to set favorite state for {fileName}." : "Није успело постављање стања омиљено за {fileName}.",
+    "Failed to rename {oldName} to {faceName}" : "Није успела промена имена {oldName} у {faceName}",
+    "Failed to delete {faceName}" : "Није успело брисање {faceName}",
+    "Failed to delete {fileId}" : "Није успело брисање {fileId}",
+    "Failed to delete {fileName}" : "Није успело брисање {fileName}",
+    "Failed to set favorite state for {fileId}" : "Није успело постављање стања омиљено за {fileId}",
+    "Failed to set favorite state for {fileName}" : "Није успело постављање стања омиљено за {fileName}",
     "Could not load photos folder" : "Не може да се учита фолдер фотографија",
-    "Default Photos upload and Albums location" : "Подразумевано место за отпремање фотографија и албума",
-    "Select the default location for your media" : "Изаберите подразумевано место за своје медије",
-    "Invalid location selected" : "Изабрана је неисправна локација",
-    "Photos directory" : "Директоријум фотографија"
+    "Back to {folder}" : "Назад у {folder}",
+    "Share this folder" : "Дели ову фасциклу",
+    "One of the source folders does not exists" : "Један од изворних фолдера не постоји",
+    "Add" : "Додај"
 },
 "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
