@@ -52,15 +52,17 @@ OC.L10N.register(
     "No picture for this day" : "Ingen bild för denna dag",
     "Picture taken on this day will show up here." : "Bild tagen den här dagen kommer att dyka upp här.",
     "More photos from this day" : "Fler bilder från denna dag",
+    "_%n photos_::_%n photos_" : ["%n bild","%n bilder"],
     "_%n unassigned photo_::_%n unassigned photos_" : ["%n ej tilldelat foto","%n ej tilldelade foton"],
     "Favorite" : "Favorit",
     "Favorite image, open the full size \"{name}\" image" : "Favoritbild, öppna bilden \"{name}\" i full storlek",
     "Open the full size \"{name}\" image" : "Öppna bilden \"{name}\" i full storlek",
     "Select image {imageName}" : "Välj bild {imageName}",
     "Open the \"{name}\" folder" : "Öppna mappen \"{name}\"",
-    "Back to {folder}" : "Tillbaka till {folder}",
     "Go back" : "Gå tillbaks",
-    "Share this folder" : "Dela denna mapp",
+    "Date range" : "Datumintervall",
+    "Select a date range" : "Välj ett datumintervall",
+    "Select places" : "Välj platser",
     "Dates" : "Datum",
     "Jump to specific date in list" : "Hoppa till specifikt datum i listan",
     "Jump to {date}" : "Gå till {date}",
@@ -86,6 +88,7 @@ OC.L10N.register(
     "Choose the folder where photos and albums are uploaded to." : "Välj mapp dit foton och album laddas upp.",
     "_%n photo_::_%n photos_" : ["%n bild","%n bilder"],
     "Unselect all" : "Avmarkera alla",
+    "Toggle filter" : "Växla filter",
     "Add photos to this album" : "Lägg till bilder i detta album",
     "Manage collaborators for this album" : "Hantera medlemmar för det här albumet",
     "Open actions menu" : "Öppna åtgärdsmenyn",
@@ -129,15 +132,16 @@ OC.L10N.register(
     "Photos with tags will show up here" : "Bilder med taggar visas här",
     "Popular tags" : "Populära taggar",
     "All tags" : "Alla taggar",
+    "Create new album from filters" : "Skapa nytt album från filter",
     "One of the source folders does not exist" : "En av källmapparna finns inte",
     "Add to album" : "Lägg till i album",
     "Delete selection" : "Ta bort urval",
     "No photos or videos in here" : "Inga bilder eller videos här",
     "Unassigned faces" : "Ej tilldelade ansikten",
-    "_%n photos_::_%n photos_" : ["%n bild","%n bilder"],
     "Failed to fetch collection." : "Det gick inte att hämta samlingen.",
     "Failed to fetch collections list." : "Det gick inte att hämta samlingslistan.",
     "Failed to fetch faces list." : "Lyckades inte hämta lista på ansikte",
+    "Error fetching files" : "Fel vid hämtning av filer",
     "All your media" : "All din media",
     "Album {title}" : "Album {title}",
     "Shared Albums" : "Delade Album",
@@ -155,6 +159,8 @@ OC.L10N.register(
     "Failed to set favorite state for {fileId}" : "Kunde inte ställa in favoritstatus för {fileId}",
     "Failed to set favorite state for {fileName}" : "Kunde inte ställa in favoritstatus för {fileName}",
     "Could not load photos folder" : "Kunde inte ladda fotomappen",
+    "Back to {folder}" : "Tillbaka till {folder}",
+    "Share this folder" : "Dela denna mapp",
     "One of the source folders does not exists" : "En av källmapparna finns inte",
     "Add" : "Lägg till"
 },
