@@ -132,9 +132,9 @@ OC.L10N.register(
     "Rate" : "Calificar",
     "Changelog" : "Bitácora de cambios",
     "Google Chrome for Android" : "Google Chrome para Android",
-    "{productName} Android app" : "{productName} aplicación Android",
     "This session" : "Esta sesión",
     "Allow filesystem access" : "Permitir acceso al sistema de archivos",
+    "Rename" : "Renombrar",
     "Revoke" : "Revocar",
     "Device" : "Dispositivo",
     "Last activity" : "Última actividad",
@@ -160,15 +160,19 @@ OC.L10N.register(
     "Submit" : "Enviar",
     "Current password" : "Contraseña actual",
     "New password" : "Nueva contraseña",
+    "Change password" : "Cambiar contraseña",
     "Picture provided by original account" : "Imagen proporcionada por la cuenta original ",
     "No email address set" : "No se ha establecido la dirección de correo electrónico",
     "Help translate" : "Ayuda a traducir",
     "Your phone number" : "Su número telefónico",
     "Your website" : "Tu sitio web",
-    "Add" : "Guardar",
+    "Add" : "Agregar",
+    "Create" : "Crear",
     "Change" : "Cambiar",
     "Delete" : "Borrar",
+    "Display name" : "Nombre a desplegar",
     "Email" : "Correo electrónico",
+    "Quota" : "Cuota",
     "Language" : "Idioma",
     "Avatar" : "Avatar",
     "Group admin for" : "Administrador del grupo para",
@@ -176,6 +180,7 @@ OC.L10N.register(
     "Last login" : "Último inicio de sesión",
     "Account actions" : "Acciones de la cuenta",
     "{size} used" : "{size} usado",
+    "Done" : "Terminado",
     "Edit" : "Editar",
     "Show last login" : "Mostrar último inicio de sesión",
     "Send email" : "Enviar correo electrónico",
@@ -221,7 +226,6 @@ OC.L10N.register(
     "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "Desarrollado por la  {communityopen}comunidad Nextcloud {linkclose}, el {githubopen}código fuente {linkclose} está licenciado bajo  {licenseopen}AGPL{linkclose}.",
     "Like our Facebook page" : "Da un Like a nuestra página de Facebook",
     "Check out our blog" : "Visita nuestro blog",
-    "Subscribe to our newsletter" : "Suscribete a nuestro boletín",
-    "You are using <strong>{usage}</strong>" : "Estás usando<strong>{usage}</strong>"
+    "Subscribe to our newsletter" : "Suscribete a nuestro boletín"
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
