@@ -467,6 +467,7 @@ OC.L10N.register(
     "Unable to update profile default setting" : "프로필 기본 설정을 업데이트 할 수 없음",
     "Profile" : "프로필",
     "Enable or disable profile by default for new accounts." : "신규 계정에 대한 프로필 기본 사용 여부를 설정하십시오.",
+    "Password confirmation is required" : "암호 확인이 필요합니다",
     "Failed to save setting" : "설정 저장 실패",
     "Unable to update server side encryption config" : "서버 측 암호화 설정을 갱신할 수 없음",
     "Server-side encryption" : "서버 측 암호화",
@@ -482,12 +483,9 @@ OC.L10N.register(
     "Be aware that encryption always increases the file size." : "암호화된 파일의 크기는 항상 커집니다.",
     "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "데이터를 주기적으로 백업하는 것을 추천하며, 암호화를 사용하고 있다면 데이터와 더불어 암호화 키도 백업하십시오.",
     "This is the final warning: Do you really want to enable encryption?" : "마지막 경고입니다. 암호화를 활성화하시겠습니까?",
-    "Failed to remove group \"{group}\"" : "그룹 \"{group}\"을(를) 삭제할 수 없음",
     "Please confirm the group removal" : "그룹 지우기를 확인해 주십시오",
-    "You are about to remove the group \"{group}\". The accounts will NOT be deleted." : "그룹 \"{group}\"을(를) 지우려고 합니다. 그룹의 계정은 삭제되지 않습니다.",
     "Submit" : "제출",
     "Rename group" : "그룹 이름 바꾸기",
-    "Remove group" : "그룹 지우기",
     "Current password" : "현재 암호",
     "New password" : "새 암호",
     "Change password" : "암호 변경",
@@ -727,45 +725,14 @@ OC.L10N.register(
     "Use a second factor besides your password to increase security for your account." : "사용자의 계정을 더욱 안전하게 보호하기 위해 암호와 함께 2단계 인증을 사용하세요.",
     "If you use third party applications to connect to Nextcloud, please make sure to create and configure an app password for each before enabling second factor authentication." : "Nextcloud에 연결하기 위해 서드파티 애플리케이션을 사용할 경우 2차 인증을 활성화하기 앞서 각 애플리케이션에 대한 앱 암호를 생성, 설정하십시오.",
     "Logged in account must be a subadmin" : "로그인한 계정은 부관리자여야 합니다.",
-    "Missing optional index \"%s\" in table \"%s\"." : "표 \"%s\"의 optional index \"%s\"이(가) 사라졌습니다",
-    "The database is missing some indexes. Due to the fact that adding indexes on big tables could take some time they were not added automatically. By running \"occ db:add-missing-indices\" those missing indexes could be added manually while the instance keeps running. Once the indexes are added queries to those tables are usually much faster." : "데이터베이스에 일부 인덱스가 없습니다. 큰 테이블에 인덱스를 추가하는 데 시간이 걸리기 때문에 자동으로 추가하지 않았습니다. 명령행에서 \"occ db:add-missing-indices\" 명령을 실행하여 인스턴스를 실행하는 동안 수동으로 인덱스를 추가할 수 있습니다. 해당 테이블에 인덱스를 추가하면 질의 속도가 다시 빨라집니다.",
     "File locking" : "파일 잠금",
     "Transactional file locking is disabled, this might lead to issues with race conditions. Enable \"filelocking.enabled\" in config.php to avoid these problems." : "트랜잭션 파일 잠금이 비활성화되어 있어 동시 접근 시 문제가 발생할 수 있습니다. config.php에서 \"filelocking.enabled\"를 활성화하여 이 문제를 방지하십시오.",
     "The PHP memory limit is below the recommended value of %s." : "PHP 메모리 제한이 추천값인 %s보다 작습니다.",
     "for WebAuthn passwordless login" : ": WebAuthn 무암호 인증을 위해 사용",
     "for WebAuthn passwordless login, and SFTP storage" : ": WebAuthn 무암호 인증 및 SFTP 저장소를 위해 사용",
-    "You are currently running PHP %s. PHP 8.0 is now deprecated in Nextcloud 27. Nextcloud 28 may require at least PHP 8.1. Please upgrade to one of the officially supported PHP versions provided by the PHP Group as soon as possible." : "현재 PHP %s이(가) 동작 중입니다. Nextcloud 27에서 PHP 8.0의 지원이 중단되었습니다. Nextcloud 28은 최소 PHP 8.1이 요구됩니다. 가능한 빨리 PHP Group에서 제공하는 공식 지원 PHP 버전으로 업그레이드 하십시오.",
-    "MariaDB version \"%s\" is used. Nextcloud 21 and higher do not support this version and require MariaDB 10.2 or higher." : "현재 MariaDB \"%s\" 버전이 사용되고 있습니다. Nextcloud 21 및 그 이상의 버전은 이를 지원하지 않습니다. MariaDB 10.2 이상을 사용하십시오.",
-    "MySQL version \"%s\" is used. Nextcloud 21 and higher do not support this version and require MySQL 8.0 or MariaDB 10.2 or higher." : "현재 MySQL \"%s\" 버전이 사용되고 있습니다. Nextcloud 21 및 그 이상의 버전은 이를 지원하지 않습니다. MySQL 8.0 혹은 MariaDB 10.2 이상을 사용하십시오.",
-    "PostgreSQL version \"%s\" is used. Nextcloud 21 and higher do not support this version and require PostgreSQL 9.6 or higher." : "현재 PostgreSQL \"%s\" 버전이 사용되고 있습니다. Nextcloud 21 및 그 이상의 버전은 이를 지원하지 않습니다. PostgreSQL 9.6 이상을 사용하십시오.",
-    "Speech-To-Text" : "음성인식",
-    "Speech-To-Text can be implemented by different apps. Here you can set which app should be used." : "음성인식 기능을 채용한 앱이 이곳에 표시됩니다. 음성인식 기능을 사용할 앱을 선택하십시오. ",
-    "None of your currently installed apps provide Speech-To-Text functionality" : "현재 설치된 앱 중 음성인식 기능을 제공하는 것이 없습니다",
-    "None of your currently installed apps provide Text processing functionality" : "현재 설치된 앱 중 문장처리 기술을 제공하는 것이 없습니다",
     "Set default expiration date for shares" : "공유에 대한 기본 만료 날짜 설정",
-    "Allow username autocompletion in share dialog and allow access to the system address book" : "공유 대화창에서 시스템 주소록에 있는 사용자 이름을 자동으로 채울 수 있도록 허용",
     "Your biography" : "내 소개문구",
     "You are using <strong>{usage}</strong>" : "<strong>{usage}</strong>를 사용하고 있습니다.",
-    "You are using <strong>{usage}</strong> of <strong>{totalSpace}</strong> (<strong>{usageRelative}%</strong>)" : "전체 <strong>{totalSpace}</strong> 중 <strong>{usage}</strong>(<strong>{usageRelative}%</strong>)를 사용하고 있습니다.",
-    "Set user manager" : "사용자 담당 관리자 지정",
-    "Username will be autogenerated" : "사용자 이름이 자동으로 생성됩니다",
-    "Username (required)" : "사용자 이름 (필수)",
-    "New user" : "새 사용자",
-    "Groups (required)" : "그룹 (필수)",
-    "Set user groups" : "사용자 그룹 설정",
-    "Set user as admin for …" : "사용자를 다음에 대한 관리자로 설정 ...",
-    "Set user quota" : "사용자 할당량 지정",
-    "Add new user" : "새 사용자 추가",
-    "_{userCount} user …_::_{userCount} users …_" : ["{userCount}명의 사용자 ..."],
-    "_{userCount} user_::_{userCount} users_" : ["{userCount}명의 사용자"],
-    "Loading users …" : "사용자 불러오는 중 ...",
-    "Username" : "사용자 이름",
-    "User backend" : "사용자 백엔드",
-    "User actions" : "사용자 동작",
-    "Add user to group" : "사용자를 그룹에 추가",
-    "Server error while trying to add WebAuthn device" : "WebAuthn 기기 추가 시도 중 서버 오류 발생",
-    "Name your device" : "장치 이름 설정",
-    "Active accounts" : "활성화된 계정",
-    "Follow us on Twitter" : "트위터에서 팔로하기"
+    "You are using <strong>{usage}</strong> of <strong>{totalSpace}</strong> (<strong>{usageRelative}%</strong>)" : "전체 <strong>{totalSpace}</strong> 중 <strong>{usage}</strong>(<strong>{usageRelative}%</strong>)를 사용하고 있습니다."
 },
 "nplurals=1; plural=0;");
