@@ -13,8 +13,6 @@ OC.L10N.register(
     "Readme" : "Leesmy",
     "Text" : "Teks",
     "📝 Collaborative document editing" : "📝 Samewerkende dokumentredigering",
-    "Use current version" : "Gebruik huidige weergawe",
-    "Use the saved version" : "Gebruik die bewaarde weergawe",
     "Reconnect" : "Herverbind",
     "Guest" : "Gas",
     "guest" : "gas",
@@ -31,18 +29,21 @@ OC.L10N.register(
     "Unordered list" : "Ongesorteerde lys",
     "Ordered list" : "Gesorteerde lys",
     "Blockquote" : "Blokaanhaling",
+    "Cancel" : "Cancel",
     "to" : "aan",
+    "Upload" : "Oplaai",
     "Edit" : "Wysig",
     "Headings" : "Koppe",
     "Heading 2" : "Kop 2",
     "Heading 3" : "Kop 3",
     "Heading 4" : "Kop 4",
     "Heading 5" : "Kop 5",
+    "Details" : "Besonderhede",
+    "Choose" : "Kies",
+    "Use current version" : "Gebruik huidige weergawe",
+    "Use the saved version" : "Gebruik die bewaarde weergawe",
     "Info" : "Inligting",
     "Success" : "Sukses",
-    "Warning" : "Waarskuwing",
-    "Details" : "Besonderhede",
-    "Show author colors" : "Toon outeurkleure",
-    "Author colors are only shown until everyone has closed the document." : "Outeurkleure word slegs getoon tot almal die dokument toegemaak het."
+    "Warning" : "Waarskuwing"
 },
 "nplurals=2; plural=(n != 1);");
