@@ -19,16 +19,19 @@ OC.L10N.register(
     "Action" : "Acción",
     "Undo" : "Deshacer",
     "Save changes" : "Guardar Cambios",
+    "Cancel" : "Cancel",
     "URL" : "URL",
     "Formatting help" : "Ayuda de formato",
     "Select language" : "Seleccionar idioma",
     "to" : "para",
     "Replace" : "Reemplazar",
+    "Upload" : "Cargar",
     "Edit" : "Editar",
     "Source code" : "Código fuente",
+    "Details" : "Detalles",
+    "Choose" : "Seleccionar",
     "Info" : "Info",
     "Success" : "Éxito",
-    "Warning" : "Advertencia",
-    "Details" : "Detalles"
+    "Warning" : "Advertencia"
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
