@@ -31,8 +31,13 @@ OC.L10N.register(
     "Assistant results" : "アシスタントの結果",
     "Show result" : "結果を表示する",
     "Delete task" : "タスクを削除",
+    "Overwrite the file and save the current changes" : "ファイルを上書きし現在の変更を保存します",
+    "Discard the current changes and load the latest version" : "現在の変更を破棄し、最新バージョンをロードします",
     "Reload" : "再読み込み",
+    "The file was overwritten. Your current changes cannot be auto-saved. Please choose how to proceed." : "ファイルが上書きされました。現在の変更は自動保存できません。続行方法を選択してください。",
+    "The document could not be loaded. Please check your internet connection." : "ドキュメントを読み込めませんでした。インターネット接続を確認してください。",
     "Reconnect" : "再接続",
+    "You've been disconnected from the server." : "サーバーから切断されました。",
     "This file is opened read-only as it is currently locked by {user}." : "このファイルは現在 {user} によってロックされているため、読み取り専用で開かれました",
     "Close outline view" : "目次の表示を閉じる",
     "Outline" : "目次",
@@ -45,6 +50,7 @@ OC.L10N.register(
     "Uploading attachment failed." : "添付ファイルのアップロードに失敗しました。",
     "Insert an attachment" : "添付ファイルを挿入する",
     "Failed to insert from Files" : "ファイルからの挿入に失敗しました",
+    "Failed to create attachment" : "添付ファイルの作成に失敗しました",
     "Preview options" : "プレビューオプション",
     "Text only" : "テキストのみ",
     "Show link preview" : "リンクのプレビューを表示",
@@ -63,7 +69,6 @@ OC.L10N.register(
     "Unsaved changes" : "未保存の変更点",
     "Save document" : "ファイルを保存する",
     "Last saved" : "最終保存",
-    "Connection failed." : "接続に失敗しました。",
     "Formatting and shortcuts" : "書式とショートカット",
     "Speed up your writing with simple shortcuts." : "シンプルなショートカットを使って文書作成をスピードアップ！",
     "Just type the Markdown syntax or use keyboard shortcuts from below." : "Markdown記法で入力するか、下に示すキーボードショートカットを使ってみましょう。",
@@ -117,10 +122,10 @@ OC.L10N.register(
     "Save changes" : "変更を保存",
     "Cancel" : "キャンセル",
     "URL" : "URL",
+    "Attachments cannot be created or uploaded because this file is shared from another cloud." : "このファイルは別のクラウドから共有されているため、添付ファイルの作成やアップロードはできません。",
     "Upload from computer" : "コンピュータからアップロード",
     "Insert from Files" : "アップロード済のファイルを挿入",
     "Formatting help" : "書式設定のヘルプ",
-    "Select file or folder to link to" : "リンク先のファイルまたはフォルダを選択",
     "Link to file or folder" : "ファイルやフォルダーへのリンク",
     "Link to website" : "ウェブサイトへのリンク",
     "Update link" : "リンクの更新",
@@ -145,6 +150,10 @@ OC.L10N.register(
     "No command found" : "コマンドが見つかりません",
     "No user found" : "ユーザーが見つかりません",
     "No suggestion found" : "提案が見つかりません",
+    "Uploading attachments is disabled because the file is shared from another cloud." : "ファイルが他のクラウドから共有されているため、添付ファイルのアップロードはできません。",
+    "Upload" : "アップロード",
+    "Insert Table" : "テーブルの挿入",
+    "Smart Picker" : "スマートピッカー",
     "Edit" : "編集",
     "Copy code block" : "コードブロックをコピー",
     "Copy code" : "コピーコード",
@@ -196,6 +205,9 @@ OC.L10N.register(
     "Ctrl" : "Ctrl",
     "Option" : "Option",
     "Formatting" : "フォーマット",
+    "Select file or folder to link to" : "リンク先のファイルまたはフォルダを選択",
+    "Choose" : "選択",
+    "Choose {file}" : "{file}を選択",
     "Add folder description" : "フォルダーの説明を追加",
     "\"{name}\" already exist!" : "\"{name}\" は既に存在します",
     "Created \"{name}\"" : "\"{name}\" を作成しました",
@@ -208,16 +220,12 @@ OC.L10N.register(
     "Document has been changed outside of the editor. The changes cannot be applied" : "ドキュメントがエディター外で変更されました。変更を適用できません",
     "Document could not be loaded. Please check your internet connection." : "ドキュメントを読み込めませんでした。インターネット接続を確認してください。",
     "Document idle for {timeout} minutes, click to continue editing" : "ドキュメントが{timeout}分間アイドル状態です。クリックして編集を続行します",
-    "Show author colors" : "記入者の色をつける",
-    "Author colors are only shown until everyone has closed the document." : "記入者の色は、全員がドキュメントを閉じるまで表示されます。",
     "Detect language" : "言語を検出する",
     "Callouts" : "コールアウト",
     "Info" : "情報",
     "Success" : "完了",
     "Warning" : "警告",
     "Danger" : "危険",
-    "Control" : "コントロール",
-    "Add notes, lists or links …" : "ノート、リスト、リンクを追加...",
     "Start writing, or try '/' to add, '@' to mention…" : "書き始めるか、「/」で追加、「@」でメンション...。"
 },
 "nplurals=1; plural=0;");
