@@ -32,12 +32,14 @@ use OCP\Share\IShare;
 use OCP\Util;
 
 class AttachmentService {
-	public function __construct(private IRootFolder $rootFolder,
+	public function __construct(
+		private IRootFolder $rootFolder,
 		private ShareManager $shareManager,
 		private IPreview $previewManager,
 		private IMimeTypeDetector $mimeTypeDetector,
 		private IURLGenerator $urlGenerator,
-		private IFilenameValidator $filenameValidator) {
+		private IFilenameValidator $filenameValidator,
+	) {
 	}
 
 	/**
@@ -101,7 +103,7 @@ class AttachmentService {
 	 * @throws NotPermittedException
 	 * @throws NoUserException
 	 */
-	public function getMediaFile(int $documentId, string $mediaFileName, string $userId): File|null {
+	public function getMediaFile(int $documentId, string $mediaFileName, string $userId): ?File {
 		$textFile = $this->getTextFile($documentId, $userId);
 		return $this->getMediaFullFile($mediaFileName, $textFile);
 	}
@@ -114,7 +116,7 @@ class AttachmentService {
 	 * @throws InvalidPathException
 	 * @throws NoUserException
 	 */
-	public function getMediaFilePublic(int $documentId, string $mediaFileName, string $shareToken): File|null {
+	public function getMediaFilePublic(int $documentId, string $mediaFileName, string $shareToken): ?File {
 		$textFile = $this->getTextFilePublic($documentId, $shareToken);
 		return $this->getMediaFullFile($mediaFileName, $textFile);
 	}
@@ -247,10 +249,10 @@ class AttachmentService {
 	/**
 	 * Save an uploaded file in the attachment folder
 	 *
-	 * @param int      $documentId
-	 * @param string   $newFileName
+	 * @param int $documentId
+	 * @param string $newFileName
 	 * @param resource $newFileResource
-	 * @param string   $userId
+	 * @param string $userId
 	 *
 	 * @return array
 	 * @throws InvalidPathException
@@ -366,12 +368,12 @@ class AttachmentService {
 		if ($extension !== '') {
 			while ($dir->nodeExists($uniqueFileName)) {
 				$counter++;
-				$uniqueFileName = preg_replace('/\.' . $extension . '$/', ' (' . $counter . ').' . $extension, $fileName);
+				$uniqueFileName = (string)preg_replace('/\.' . $extension . '$/', ' (' . $counter . ').' . $extension, $fileName);
 			}
 		} else {
 			while ($dir->nodeExists($uniqueFileName)) {
 				$counter++;
-				$uniqueFileName = preg_replace('/$/', ' (' . $counter . ')', $fileName);
+				$uniqueFileName = (string)preg_replace('/$/', ' (' . $counter . ')', $fileName);
 			}
 		}
 		return $uniqueFileName;
@@ -393,8 +395,9 @@ class AttachmentService {
 					[IShare::TYPE_LINK, IShare::TYPE_EMAIL, IShare::TYPE_ROOM],
 					true
 				)
-				&& $share->getPermissions() & Constants::PERMISSION_UPDATE);
-		} catch (ShareNotFound $e) {
+				&& $share->getPermissions() & Constants::PERMISSION_UPDATE
+				&& $share->getNode()->getPermissions() & Constants::PERMISSION_UPDATE);
+		} catch (ShareNotFound|NotFoundException $e) {
 			return false;
 		}
 	}
@@ -474,7 +477,7 @@ class AttachmentService {
 	/**
 	 * Get a user file from file ID
 	 *
-	 * @param int    $documentId
+	 * @param int $documentId
 	 * @param string $userId
 	 *
 	 * @return File
@@ -572,7 +575,7 @@ class AttachmentService {
 	 * Get attachment file names listed in the markdown file content
 	 *
 	 * @param string $content
-	 * @param int    $fileId
+	 * @param int $fileId
 	 *
 	 * @return array
 	 */
@@ -662,4 +665,24 @@ class AttachmentService {
 			}
 		}
 	}
+
+	public static function replaceAttachmentFolderId(File $source, File $target): void {
+		$sourceId = $source->getId();
+		$targetId = $target->getId();
+		$patterns = [
+			// Replace `[title](.attachments.1/file.png)` with `[title](attachments.2/file.png)`
+			// '/(\[[^]]+\]\(\s*\<?\.attachments\.)' . $sourceId . '(\/[^)]+\>?\s*\))/',
+			'/(\[(?:\\\]|[^]])+\]\(\s*\<?\.attachments\.)' . $sourceId . '(\/[^)]+\>?\s*\))/',
+			// Replace `[ref]: .attachments.1/file.png` with `[ref]: .attachments.2/file.png`
+			'/(\[(?:\\\]|[^]])+\]:\s+.attachments\.)' . $sourceId . '(\/[^\s]+)/',
+		];
+		$replacements = [
+			'${1}' . $targetId . '${2}',
+			'${1}' . $targetId . '${2}',
+		];
+		$content = preg_replace($patterns, $replacements, $target->getContent());
+		if ($content !== null) {
+			$target->putContent($content);
+		}
+	}
 }
