@@ -13,29 +13,38 @@ OC.L10N.register(
     "The given end time is invalid" : "Norādītais beigu laiks nav derīgs.",
     "The given group does not exist" : "Norādītā grupa nepastāv.",
     "File" : "Datne",
+    "File renamed" : "Datne pārdēvēta",
     "Operation #%s does not exist" : "Operation #%s does not exist",
-    "Operation %s does not exist" : "Darbība %s neeksistē",
+    "Operation %s does not exist" : "Darbība %s nepastāv",
     "Operation %s is invalid" : "Darbība %s ir nederīga",
     "Check %s does not exist" : "Pārbaude %s nepastāv",
     "Check %s is invalid" : "Pārbaude %s ir nederīga",
     "Check #%s does not exist" : "Pārbaude #%s nepastāv",
     "Check %s is invalid or does not exist" : "Pārbaude %s ir nederīga vai nepastāv",
+    "Flow" : "Plūsma",
+    "Nextcloud workflow engine" : "Nextcloud darbplūsmu dzinis",
     "Folder" : "Mape",
     "Images" : "Attēli",
-    "Predefined URLs" : "Standarta URLs",
     "Files WebDAV" : "WebDAV datnes",
     "Android client" : "Android klients",
     "iOS client" : "iOS klients",
     "Desktop client" : "Darbvirsmas klients",
-    "Cancel" : "Atcelt",
-    "Delete" : "Dzēst",
+    "Select groups" : "Izvēlieties grupas",
+    "Groups" : "Grupas",
+    "Add new flow" : "Pievienot jaunu plūsmu",
     "Save" : "Saglabāt",
+    "Cancel" : "Atcelt",
+    "Delete" : "Izdzēst",
+    "Available flows" : "Pieejamās plūsmas",
+    "No flows installed" : "Nav uzstādītu plūsmu",
+    "More flows" : "Vairāk plūsmu",
+    "Show more" : "Parādīt vairāk",
     "matches" : "atbilst",
     "does not match" : "neatbilst",
     "is" : "ir",
     "is not" : "nav",
-    "File name" : "Faila nosaukums",
-    "File MIME type" : "Datnes MIME tips",
+    "File name" : "Datnes nosaukums",
+    "File MIME type" : "Datnes MIME veids",
     "File size (upload)" : "Datnes lielums (augšupielādēt)",
     "less" : "mazāk",
     "less or equals" : "mazāks vai vienāds ar",
@@ -46,7 +55,7 @@ OC.L10N.register(
     "does not match IPv4" : "neatbilst IPv4",
     "matches IPv6" : "atbilst IPv6",
     "does not match IPv6" : "neatbilst IPv6",
-    "File system tag" : "Failu sistēmas birka",
+    "File system tag" : "Datņu sistēmas birka",
     "is tagged with" : "atzīmēts ar",
     "is not tagged with" : "nav atzīmēts ar",
     "Request URL" : "Pieprasījuma URL",
@@ -54,11 +63,7 @@ OC.L10N.register(
     "between" : "starp",
     "not between" : "nav starp",
     "Request user agent" : "Nepieciešams lietotāja aģents",
-    "User group membership" : "Lietotāju grupas piederība",
     "is member of" : "ir biedrs",
-    "is not member of" : "nav biedrs",
-    "No results" : "Nav rezultātu",
-    "%s (invisible)" : "%s (neredzams)",
-    "%s (restricted)" : "%s (ierobežots)"
+    "is not member of" : "nav dalībnieks"
 },
 "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");
