@@ -86,11 +86,6 @@ class Application extends App {
 				'fs_size',
 				['size']
 			);
-			$event->addMissingIndex(
-				'filecache',
-				'fs_id_storage_size',
-				['fileid', 'storage', 'size']
-			);
 			$event->addMissingIndex(
 				'filecache',
 				'fs_storage_path_prefix',
@@ -204,8 +199,13 @@ class Application extends App {
 
 			$event->addMissingIndex(
 				'preferences',
-				'preferences_app_key',
-				['appid', 'configkey']
+				'prefs_uid_lazy_i',
+				['userid', 'lazy']
+			);
+			$event->addMissingIndex(
+				'preferences',
+				'prefs_app_key_ind_fl_i',
+				['appid', 'configkey', 'indexed', 'flags']
 			);
 
 			$event->addMissingIndex(
@@ -232,10 +232,10 @@ class Application extends App {
 				['objectid']
 			);
 
-			$event->addMissingUniqueIndex(
-				'vcategory',
-				'unique_category_per_user',
-				['uid', 'type', 'category']
+			$event->addMissingIndex(
+				'systemtag_object_mapping',
+				'systag_objecttype',
+				['objecttype']
 			);
 		});
 
