@@ -18,6 +18,10 @@ OC.L10N.register(
     "Unknown filetype" : "Unbekannter Dateityp",
     "An error occurred. Please contact your admin." : "Es ist ein Fehler aufgetreten. Bitte kontaktiere deine Administration.",
     "Invalid image" : "Ungültiges Bild",
+    "No temporary profile picture available, try again" : "Kein temporäres Profilbild verfügbar, bitte versuche es noch einmal",
+    "No crop data provided" : "Keine Beschnittdaten zur Verfügung gestellt",
+    "No valid crop data provided" : "Keine gültigen Zuschnittdaten zur Verfügung gestellt",
+    "Crop is not square" : "Zuschnitt ist nicht quadratisch",
     "State token does not match" : "Status-Token stimmen nicht überein",
     "Invalid app password" : "Ungültiges App-Passwort",
     "Could not complete login" : "Anmeldung konnte nicht abgeschlossen werden",
@@ -49,7 +53,6 @@ OC.L10N.register(
     "No translation provider available" : "Kein Übersetzungsanbieter verfügbar",
     "Could not detect language" : "Sprache konnte nicht erkannt werden",
     "Unable to translate" : "Kann nicht übersetzt werden",
-    "No valid filters provided" : "Keine gültigen Filter angegeben",
     "[%d / %d]: %s" : "[%d / %d]: %s",
     "Repair step:" : "Reparaturschritt:",
     "Repair info:" : "Reparaturinformation:",
@@ -197,6 +200,16 @@ OC.L10N.register(
     "Matroska video" : "Matroska-Video",
     "Windows Media video" : "Windows Media-Video",
     "AVI video" : "AVI-Video",
+    "Error occurred while checking server setup" : "Fehler beim Überprüfen der Servereinrichtung",
+    "For more details see the {linkstart}documentation ↗{linkend}." : "Weitere Informationen findest du in der {linkstart}Dokumentation ↗{linkend}.",
+    "unknown text" : "Unbekannter Text",
+    "Hello world!" : "Hallo Welt!",
+    "sunny" : "sonnig",
+    "Hello {name}, the weather is {weather}" : "Hallo {name}, das Wetter ist {weather}",
+    "Hello {name}" : "Hallo {name}",
+    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Dies sind deine Suchergebnisse<script>alert(1)</script></strong>",
+    "new" : "Neu",
+    "_download %n file_::_download %n files_" : ["Lade %n Datei herunter","Lade %n Dateien herunter"],
     "The update is in progress, leaving this page might interrupt the process in some environments." : "Die Aktualisierung wird durchgeführt. Wenn du dieses Fenster verlässt, kann dies den Aktualisierungsprozess in manchen Umgebungen unterbrechen.",
     "Update to {version}" : "Aktualisierung auf {version}",
     "An error occurred." : "Es ist ein Fehler aufgetreten.",
@@ -217,7 +230,7 @@ OC.L10N.register(
     "Federated user" : "Federated Benutzer",
     "user@your-nextcloud.org" : "benutzer@deine-nextcloud.org",
     "Create share" : "Freigabe erstellen",
-    "Direct link copied" : "Direktlink kopiert",
+    "Direct link copied to clipboard" : "Direkter Link in die Zwischenablage kopiert",
     "Please copy the link manually:" : "Bitte den Link manuell kopieren:",
     "Custom date range" : "Benutzerdefinierter Zeitbereich",
     "Pick start date" : "Startdatum wählen",
@@ -226,16 +239,14 @@ OC.L10N.register(
     "Search in current app" : "In aktueller App suchen ",
     "Clear search" : "Suche löschen",
     "Search everywhere" : "Überall suchen",
-    "Searching …" : "Suche …",
+    "Searching …" : "Suche …",
     "Start typing to search" : "Beginne mit der Eingabe, um zu suchen",
-    "Minimum search length is {minSearchLength} characters" : "Die Mindestsuchlänge beträgt {minSearchLength} Zeichen",
     "No matching results" : "Keine passenden Suchergebnisse",
     "Today" : "Heute",
     "Last 7 days" : "Die letzten 7 Tage",
     "Last 30 days" : "Die letzten 30 Tage",
     "This year" : "Dieses Jahr",
     "Last year" : "Letztes Jahr",
-    "Between {startDate} and {endDate}" : "Von {startDate} bis {endDate}",
     "Unified search" : "Einheitliche Suche",
     "Search apps, files, tags, messages" : "Nach Apps, Dateien, Schlagworten und Nachrichten suchen",
     "Places" : "Orte",
@@ -243,12 +254,11 @@ OC.L10N.register(
     "Search people" : "Personen suchen",
     "People" : "Personen",
     "Filter in current view" : "Filter in aktueller Ansicht",
-    "Search connected services" : "Verbundene Dienste durchsuchen",
     "Results" : "Ergebnisse",
     "Load more results" : "Weitere Ergebnisse laden",
     "Search in" : "Suche in",
     "Log in" : "Anmelden",
-    "Logging in …" : "Melde an …",
+    "Logging in …" : "Melde an…",
     "Log in to {productName}" : "Anmelden bei {productName}",
     "Wrong login or password." : "Kontoname oder Passwort falsch",
     "This account is disabled" : "Dieses Konto ist deaktiviert",
@@ -285,21 +295,21 @@ OC.L10N.register(
     "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "Gemeinsame Dokumente, Tabellenkalkulationen und Präsentationen, die auf Collabora Online basieren.",
     "Distraction free note taking app." : "Ablenkungsfreie Notizen-App",
     "Recommended apps" : "Empfohlene Apps",
-    "Loading apps …" : "Lade Apps …",
+    "Loading apps …" : "Lade Apps …",
     "Could not fetch list of apps from the App Store." : "Liste der Apps konnte nicht vom App-Store abgerufen werden",
     "App download or installation failed" : "Herunterladen oder Installieren der App fehlgeschlagen",
     "Cannot install this app because it is not compatible" : "App kann nicht installiert werden, da sie inkompatibel ist",
     "Cannot install this app" : "App kann nicht installiert werden",
     "Skip" : "Überspringen",
-    "Installing apps …" : "Installiere Apps …",
+    "Installing apps …" : "Installiere Apps …",
     "Install recommended apps" : "Empfohlene Apps installieren",
     "Avatar of {displayName}" : "Avatar von {displayName}",
     "Settings menu" : "Einstellungen-Menü",
-    "Loading your contacts …" : "Lade deine Kontakte …",
-    "Looking for {term} …" : "Suche nach {term} …",
+    "Loading your contacts …" : "Lade deine Kontakte …",
+    "Looking for {term} …" : "Suche nach {term} …",
     "Search contacts" : "Kontakte suchen",
     "Reset search" : "Suche zurücksetzen",
-    "Search contacts …" : "Kontakte suchen …",
+    "Search contacts …" : "Kontakte suchen …",
     "Could not load your contacts" : "Deine Kontakte konnten nicht geladen werden",
     "No contacts found" : "Keine Kontakte gefunden",
     "Show all contacts" : "Alle Kontakte anzeigen",
@@ -311,18 +321,13 @@ OC.L10N.register(
     "An error occurred while searching for {type}" : "Es ist ein Fehler beim Suchen nach {type} aufgetreten",
     "Search starts once you start typing and results may be reached with the arrow keys" : "Die Suche beginnt, sobald du mit der Eingabe beginnst. Die Suchergebnisse kannst du mit den Pfeiltasten auswählen,",
     "Search for {name} only" : "Nur nach {name} suchen",
-    "Loading more results …" : "Lade weitere Ergebnisse …",
+    "Loading more results …" : "Lade weitere Ergebnisse …",
     "Forgot password?" : "Passwort vergessen?",
     "Back to login form" : "Zurück zum Anmeldeformular",
     "Back" : "Zurück",
     "Login form is disabled." : "Das Anmeldeformular ist deaktiviert.",
     "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "Das Nextcloud-Anmeldeformular ist deaktiviert. Nutze ggf. eine andere Anmeldemöglichkeit oder wende dich an deine Administration.",
     "More actions" : "Weitere Aktionen",
-    "User menu" : "Benutzermenü",
-    "Your guest name: {user}" : "Dein Gastname: {user}",
-    "You are currently not identified." : "Du bist derzeit nicht identifiziert.",
-    "Set public name" : "Öffentlichen Namen festlegen",
-    "Change public name" : "Öffentlichen Namen ändern",
     "Password is too weak" : "Passwort ist zu schwach",
     "Password is weak" : "Passwort ist schwach",
     "Password is average" : "Passwort ist durchschnittlich",
@@ -355,7 +360,7 @@ OC.L10N.register(
     "Please specify the port number along with the host name (e.g., localhost:5432)." : "Bitte die Portnummer mit der Hostadresse zusammen angeben (z. B. localhost:5432)",
     "Database host" : "Datenbank-Host",
     "localhost" : "localhost",
-    "Installing …" : "Installiere …",
+    "Installing …" : "Installiere …",
     "Install" : "Installieren",
     "Need help?" : "Hilfe nötig?",
     "See the documentation" : "Schau in die Dokumentation",
@@ -364,7 +369,7 @@ OC.L10N.register(
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Dein Browser wird nicht unterstützt. Bitte aktualisieren deinen Browser auf eine neuere oder unterstützte Version.",
     "Continue with this unsupported browser" : "Mit diesem nicht unterstützten Browser fortfahren.",
     "Supported versions" : "Unterstützte Versionen",
-    "Search {types} …" : "Suche {types} …",
+    "Search {types} …" : "Suche {types} …",
     "Choose {file}" : "{file} auswählen",
     "Choose" : "Auswählen",
     "Copy to {target}" : "Nach {target} kopieren",
@@ -384,7 +389,7 @@ OC.L10N.register(
     "(all selected)" : "(Alle ausgewählt)",
     "({count} selected)" : "({count} ausgewählt)",
     "Error loading file exists template" : "Fehler beim Laden der vorhanden Dateivorlage",
-    "Saving …" : "Speichere …",
+    "Saving …" : "Speichern …",
     "seconds ago" : "Gerade eben",
     "Connection to server lost" : "Verbindung zum Server verloren",
     "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Problem beim Laden der Seite, Seite wird in %n Sekunde nochmals geladen","Problem beim Laden der Seite, Seite wird in %n Sekunden erneut geladen"],
@@ -399,8 +404,17 @@ OC.L10N.register(
     "Type to search for existing projects" : "Nach existierenden Projekten suchen",
     "New in" : "Neu in",
     "View changelog" : "Liste der Veränderungen ansehen",
+    "No action available" : "Keine Aktion verfügbar",
+    "Error fetching contact actions" : "Fehler beim Einlesen der Kontakt-Aktionen",
     "Close \"{dialogTitle}\" dialog" : "Dialog \"{dialogTitle}\" schließen",
     "Email length is at max (255)" : "Maximale Länge der E-Mail-Adresse erreicht (255)",
+    "Non-existing tag #{tag}" : "Nicht existierender Tag #{tag}",
+    "Restricted" : "Eingeschränkt",
+    "Invisible" : "Unsichtbar",
+    "Delete" : "Löschen",
+    "Rename" : "Umbenennen",
+    "Collaborative tags" : "Kollaborative Schlagworte",
+    "No tags found" : "Keine Tags gefunden",
     "Clipboard not available, please copy manually" : "Zwischenablage nicht verfügbar, bitte manuell kopieren",
     "Personal" : "Persönlich",
     "Accounts" : "Konten",
@@ -484,48 +498,19 @@ OC.L10N.register(
     "Upgrade via web on my own risk" : "Aktualisierung über die Web-Oberfläche auf eigenes Risiko",
     "Maintenance mode" : "Wartungsmodus",
     "This %s instance is currently in maintenance mode, which may take a while." : "Diese Instanz der %s - befindet sich gerade im Wartungsmodus, was eine Weile dauern kann.",
-    "This page will refresh itself when the instance is available again." : "Diese Seite aktualisiert sich automatisch, sobald diese Instanz wieder verfügbar ist.",
+    "This page will refresh itself when the instance is available again." : "Diese Seite aktualisiert sich automatisch, sobald die Nextcloud-Instanz wieder verfügbar ist.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Kontaktiere die Systemadministration, wenn diese Meldung dauerhaft oder unerwartet erscheint.",
-    "Error occurred while checking server setup" : "Fehler beim Überprüfen der Servereinrichtung",
-    "For more details see the {linkstart}documentation ↗{linkend}." : "Weitere Informationen findest du in der {linkstart}Dokumentation ↗{linkend}.",
-    "unknown text" : "Unbekannter Text",
-    "Hello world!" : "Hallo Welt!",
-    "sunny" : "sonnig",
-    "Hello {name}, the weather is {weather}" : "Hallo {name}, das Wetter ist {weather}",
-    "Hello {name}" : "Hallo {name}",
-    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Dies sind deine Suchergebnisse<script>alert(1)</script></strong>",
-    "new" : "Neu",
-    "_download %n file_::_download %n files_" : ["Lade %n Datei herunter","Lade %n Dateien herunter"],
-    "Searching …" : "Suche …",
-    "Logging in …" : "Melde an…",
     "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Chatten, Videoanrufe, Bildschirmfreigaben, Online-Besprechungen und Webkonferenzen - in deinem Browser sowie mit mobilen Apps.",
-    "Loading apps …" : "Lade Apps …",
-    "Installing apps …" : "Installiere Apps …",
-    "Loading your contacts …" : "Lade deine Kontakte …",
-    "Looking for {term} …" : "Suche nach {term} …",
-    "Search contacts …" : "Kontakte suchen …",
-    "Loading more results …" : "Lade weitere Ergebnisse …",
     "You have not added any info yet" : "Du hast noch keine Infos hinzugefügt",
     "{user} has not added any info yet" : "{user} hat noch keine Infos hinzugefügt",
     "Error opening the user status modal, try hard refreshing the page" : "Fehler beim Modal-öffnen des Benutzerstatus, versuche die Seite zu aktualisieren",
     "Edit Profile" : "Profil bearbeiten",
     "The headline and about sections will show up here" : "Die Überschrift und der Infobereich werden hier angezeigt",
-    "Search {types} …" : "Suche {types} …",
-    "Saving …" : "Speichern …",
     "Very weak password" : "Sehr schwaches Passwort",
     "Weak password" : "Schwaches Passwort",
     "So-so password" : "Passables Passwort",
     "Good password" : "Gutes Passwort",
     "Strong password" : "Starkes Passwort",
-    "No action available" : "Keine Aktion verfügbar",
-    "Error fetching contact actions" : "Fehler beim Einlesen der Kontakt-Aktionen",
-    "Non-existing tag #{tag}" : "Nicht existierender Tag #{tag}",
-    "Restricted" : "Eingeschränkt",
-    "Invisible" : "Unsichtbar",
-    "Delete" : "Löschen",
-    "Rename" : "Umbenennen",
-    "Collaborative tags" : "Kollaborative Schlagworte",
-    "No tags found" : "Keine Tags gefunden",
     "Profile not found" : "Profil nicht gefunden",
     "The profile does not exist." : "Das Profil existiert nicht",
     "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Dein Datenverzeichnis und deine Dateien sind wahrscheinlich vom Internet aus erreichbar, weil die .htaccess-Datei nicht funktioniert.",
@@ -537,8 +522,6 @@ OC.L10N.register(
     "Toggle password visibility" : "Passwortsichtbarkeit umschalten",
     "Configure the database" : "Datenbank einrichten",
     "Only %s is available." : "Es ist nur %s verfügbar.",
-    "Database account" : "Datenbankkonto",
-    "Installing …" : "Installiere …",
-    "Direct link copied to clipboard" : "Direkter Link in die Zwischenablage kopiert"
+    "Database account" : "Datenbankkonto"
 },
 "nplurals=2; plural=(n != 1);");
