@@ -41,16 +41,16 @@ OC.L10N.register(
     "Not found" : "Ne trovita",
     "Image not found" : "Bildo ne trovita",
     "Unable to translate" : "Ne eblas traduki",
-    "Nextcloud Server" : "Nextcloud-servilo",
-    "Some of your link shares have been removed" : "Kelkaj el viaj kunhavigaj ligiloj estis forigitaj",
-    "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "Pro sekuriga problemo, ni forigu kelkajn el viaj kunhavigaj ligiloj. Bv. vidi la ligilon por plia informo.",
-    "Learn more ↗" : "Scii pli ↗",
-    "Preparing update" : "Preparo de  la ĝisdatigo",
     "[%d / %d]: %s" : "[%d / %d]: %s",
     "Repair step:" : "Ripara stadio:",
     "Repair info:" : "Ripara informo:",
     "Repair warning:" : "Ripara averto:",
     "Repair error:" : "Ripara eraro:",
+    "Nextcloud Server" : "Nextcloud-servilo",
+    "Some of your link shares have been removed" : "Kelkaj el viaj kunhavigaj ligiloj estis forigitaj",
+    "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "Pro sekuriga problemo, ni forigu kelkajn el viaj kunhavigaj ligiloj. Bv. vidi la ligilon por plia informo.",
+    "Learn more ↗" : "Scii pli ↗",
+    "Preparing update" : "Preparo de  la ĝisdatigo",
     "Turned on maintenance mode" : "Reĝimo de prizorgado ŝaltita.",
     "Turned off maintenance mode" : "Reĝimo de prizorgado malŝaltita.",
     "Maintenance mode is kept active" : "Reĝimo de prizorgado pluas",
@@ -66,6 +66,7 @@ OC.L10N.register(
     "%s (incompatible)" : "%s (nekongrua)",
     "The following apps have been disabled: %s" : "La jenaj aplikaĵoj estis malŝatitaj: %s",
     "Already up to date" : "Jam aktuala",
+    "Unknown" : "Nekonata",
     "Error occurred while checking server setup" : "Eraro dum kontrolo de servila agordo",
     "For more details see the {linkstart}documentation ↗{linkend}." : "Por pliaj detaloj, vidu la {linkstart}dokumentaron ↗{linkend}.",
     "unknown text" : "nekonata teksto",
@@ -93,37 +94,36 @@ OC.L10N.register(
     "Pick start date" : "Elekti komencan daton",
     "Pick end date" : "Elekti finan daton",
     "Search in date range" : "Serĉi en data periodo",
-    "Date" : "Dato",
+    "Searching …" : "Serĉado ...",
+    "Start typing to search" : "Ektajpu por serĉi",
+    "No matching results" : "Neniuj kongruaj rezultoj",
     "Today" : "Hodiaŭ",
     "Last 7 days" : "Lastaj 7 tagoj",
     "Last 30 days" : "Lastaj 30 tagoj",
     "This year" : "Ĉi jaro",
     "Last year" : "Lasta jaro",
+    "Date" : "Dato",
     "Search people" : "Serĉi homojn",
     "People" : "Homoj",
     "Filter in current view" : "Filtrilo en ĉi vido",
     "Search in" : "Serĉi en",
-    "Searching …" : "Serĉado ...",
-    "Start typing to search" : "Ektajpu por serĉi",
-    "No matching results" : "Neniuj kongruaj rezultoj",
-    "Between ${this.dateFilter.startFrom.toLocaleDateString()} and ${this.dateFilter.endAt.toLocaleDateString()}" : "Inter ${this.dateFilter.startFrom.toLocaleDateString()} kaj ${this.dateFilter.endAt.toLocaleDateString()}",
     "Log in" : "Ensaluti",
     "Logging in …" : "Ensaluti...",
+    "Log in to {productName}" : "Saluti al {productName}",
+    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Ni eltrovis plurajn nevalidajn provojn ensaluti el via IP-adreso. Do, oni prokrastis vian sekvantan ensaluton dum ĝis 30 sekundoj.",
+    "Account name or email" : "Kontonomo aŭ retpoŝta adreso",
     "Server side authentication failed!" : "Ĉeservila aŭtentigo malsukcesis!",
     "Please contact your administrator." : "Bonvolu kontakti vian administranton.",
     "An internal error occurred." : "Interna servileraro okazis.",
     "Please try again or contact your administrator." : "Bonvolu provi ree aŭ kontakti vian administranton.",
     "Password" : "Pasvorto",
-    "Log in to {productName}" : "Saluti al {productName}",
-    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Ni eltrovis plurajn nevalidajn provojn ensaluti el via IP-adreso. Do, oni prokrastis vian sekvantan ensaluton dum ĝis 30 sekundoj.",
-    "Account name or email" : "Kontonomo aŭ retpoŝta adreso",
     "Your account is not setup for passwordless login." : "Via konto ne estas agordita por uzi senpasvortan ensaluton.",
-    "Passwordless authentication is not supported in your browser." : "Senpasvorta aŭtentigo ne eblas per via retumilo.",
     "Your connection is not secure" : "La konekto ne sekuras",
     "Passwordless authentication is only available over a secure connection." : "Senpasvorta aŭtentigo eblas nur pere de sekura konekto.",
+    "Passwordless authentication is not supported in your browser." : "Senpasvorta aŭtentigo ne eblas per via retumilo.",
     "Reset password" : "Restarigi pasvorton",
-    "Couldn't send reset email. Please contact your administrator." : "Ne eblas sendi retpoŝton pri restarigo. Bonvolu kontakti vian administranton.",
     "Back to login" : "Antaŭen al ensaluto",
+    "Couldn't send reset email. Please contact your administrator." : "Ne eblas sendi retpoŝton pri restarigo. Bonvolu kontakti vian administranton.",
     "New password" : "Nova pasvorto",
     "Your files are encrypted. There will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" : "Viaj dosieroj estas ĉifritaj. Ne estos eble rehavi viajn datumojn post la restarigo de via pasvorto. Se vi ne tute certas pri kio fari, bonvolu pridemandi vian administranton, antaŭ ol daŭrigi.  Ĉu vi ja volas daŭrigi?",
     "I know what I'm doing" : "Mi scias, kion mi faras",
@@ -135,25 +135,43 @@ OC.L10N.register(
     "Skip" : "Preterpasi",
     "Installing apps …" : "Instalado de aplikaĵoj...",
     "Install recommended apps" : "Instali rekomendatajn aplikaĵojn",
-    "Settings menu" : "Menuo de agordo",
     "Avatar of {displayName}" : "Avataro de {displayName}",
+    "Settings menu" : "Menuo de agordo",
+    "Loading your contacts …" : "Ŝargo de viaj kontaktoj...",
+    "Looking for {term} …" : "Serĉo de {term}…",
     "Reset search" : "Restarigi serĉon",
     "Search contacts …" : "Serĉi kontaktojn…",
     "Could not load your contacts" : "Ne eblis ŝargi viajn kontaktojn",
     "No contacts found" : "Neniu kontakto troviĝis",
     "Install the Contacts app" : "Instali la Kontakto-aplikaĵon",
-    "Loading your contacts …" : "Ŝargo de viaj kontaktoj...",
-    "Looking for {term} …" : "Serĉo de {term}…",
     "Search" : "Serĉi",
     "No results for {query}" : "Neniu rezulto pri {query}",
     "Forgot password?" : "Ĉu vi forgesis vian pasvorton?",
     "Back" : "Antaŭen",
-    "Edit Profile" : "Modifi profilon",
     "More actions" : "Pliaj agoj",
+    "Security warning" : "Sekureca averto",
+    "Storage & database" : "Konservejo kaj datumbazo",
+    "Data folder" : "Datuma dosierujo",
+    "Install and activate additional PHP modules to choose other database types." : "Instalu kaj aktivigu pliajn PHP-modulojn por elekti aliajn datumbazajn specojn..",
+    "For more details check out the documentation." : "Por pli detaloj, vidu la dokumentaron.",
+    "Performance warning" : "Rendimenta averto",
+    "You chose SQLite as database." : "Vi elektis datumbazon „SQLite“.",
+    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite estu nur uzita por minimuma kaj programista servilo. Por produkta medio, ni rekomendas uzi alian tipon de datumbazo.",
+    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Se vi uzas klientojn por sinkronigi dosierojn, oni ne rekomendas datumbazon SQLite.",
+    "Database user" : "Datumbaza uzanto",
+    "Database password" : "Datumbaza pasvorto",
+    "Database name" : "Datumbaza nomo",
+    "Database tablespace" : "Datumbaza tabelospaco",
+    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Bv. entajpi la pordan numeron kune kun la gastiga nomo (ekzemple: localhost:5432).",
+    "Database host" : "Datumbaza gastigo",
+    "Installing …" : "Instalante…",
+    "Install" : "Instali",
+    "Need help?" : "Ĉu necesas helpo?",
+    "See the documentation" : "Vidi la dokumentaron",
+    "{name} version {version} and above" : "{name} versio {version} kaj supre",
     "This browser is not supported" : "La retumilo ne estas subtenata",
     "Continue with this unsupported browser" : "Daŭrigi per tiu ne subtenata retumilo",
     "Supported versions" : "Subtenataj versioj",
-    "{name} version {version} and above" : "{name} versio {version} kaj supre",
     "Choose {file}" : "Elekti {file}",
     "Choose" : "Elekti",
     "Copy to {target}" : "Kopii al {target}",
@@ -188,11 +206,6 @@ OC.L10N.register(
     "Type to search for existing projects" : "Entajpi por serĉi jam ekzistantajn projektojn",
     "New in" : "Nova en",
     "View changelog" : "Vidi ŝanĝoprotokolon",
-    "Very weak password" : "Tre malforta pasvorto",
-    "Weak password" : "Malforta pasvorto",
-    "So-so password" : "Mezbona pasvorto",
-    "Good password" : "Bona pasvorto",
-    "Strong password" : "Forta pasvorto",
     "No action available" : "Neniu ago disponebla",
     "Error fetching contact actions" : "Eraro dum serĉo de kontakt-agoj",
     "Close \"{dialogTitle}\" dialog" : "Fermi la dialogon \"{dialogTitle}\"",
@@ -208,8 +221,6 @@ OC.L10N.register(
     "Admin" : "Administranto",
     "Help" : "Helpo",
     "Access forbidden" : "Aliro estas malpermesata",
-    "Profile not found" : "Profilo ne troviĝis",
-    "The profile does not exist." : "La profilo ne ekzistas.",
     "Back to %s" : "Antaŭen al %s",
     "Page not found" : "Paĝo ne trovita",
     "The page could not be found on the server or you may not be allowed to view it." : "La paĝo ne povis esti trovita en la servilo aŭ vi eble ne rajtas vidi ĝin.",
@@ -229,32 +240,6 @@ OC.L10N.register(
     "File: %s" : "Dosiero: %s",
     "Line: %s" : "Linio: %s",
     "Trace" : "Spuro",
-    "Security warning" : "Sekureca averto",
-    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Via datumdosierujo kaj dosieroj estas probable elireblaj el la interreto, ĉar la dosiero „.htaccess“ ne funkcias.",
-    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Por pli da informoj pri kielo agordi vian retservilon, bv. vidi la <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">dokumentaron</a>.",
-    "Create an <strong>admin account</strong>" : "Krei <strong>administranto-konton</strong>",
-    "Show password" : "Montri pasvorton",
-    "Toggle password visibility" : "Ŝanĝi videblecon de pasvorto",
-    "Storage & database" : "Konservejo kaj datumbazo",
-    "Data folder" : "Datuma dosierujo",
-    "Configure the database" : "Agordi la datumbazon",
-    "Only %s is available." : "Nur %s disponeblas.",
-    "Install and activate additional PHP modules to choose other database types." : "Instalu kaj aktivigu pliajn PHP-modulojn por elekti aliajn datumbazajn specojn..",
-    "For more details check out the documentation." : "Por pli detaloj, vidu la dokumentaron.",
-    "Database account" : "Datumbaza konto",
-    "Database password" : "Datumbaza pasvorto",
-    "Database name" : "Datumbaza nomo",
-    "Database tablespace" : "Datumbaza tabelospaco",
-    "Database host" : "Datumbaza gastigo",
-    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Bv. entajpi la pordan numeron kune kun la gastiga nomo (ekzemple: localhost:5432).",
-    "Performance warning" : "Rendimenta averto",
-    "You chose SQLite as database." : "Vi elektis datumbazon „SQLite“.",
-    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite estu nur uzita por minimuma kaj programista servilo. Por produkta medio, ni rekomendas uzi alian tipon de datumbazo.",
-    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Se vi uzas klientojn por sinkronigi dosierojn, oni ne rekomendas datumbazon SQLite.",
-    "Install" : "Instali",
-    "Installing …" : "Instalante…",
-    "Need help?" : "Ĉu necesas helpo?",
-    "See the documentation" : "Vidi la dokumentaron",
     "It looks like you are trying to reinstall your Nextcloud. However the file CAN_INSTALL is missing from your config directory. Please create the file CAN_INSTALL in your config folder to continue." : "Ŝajnas, ke vi provas reinstali vian Nextcloud. Sed la dosiero CAN_INSTALL (angle por „eblo instali“) mankas en via dosierujo „config“. Bv. krei dosieron CAN_INSTALL ene de via dosierujo „config“ por daŭrigi.",
     "Could not remove CAN_INSTALL from the config folder. Please remove this file manually." : "Ne eblis forigi la dosieron „CAN_INSTALL“ el via dosierujo „config“. Bv. forigi ĝin permane.",
     "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Tiu aplikaĵo bezonas Ĝavoskripton („Javascript“) por funkcii. Bonvolu {linkstart}ŝalti Ĝavoskripton{linkend} kaj poste reŝargi la paĝon.",
@@ -309,26 +294,20 @@ OC.L10N.register(
     "This %s instance is currently in maintenance mode, which may take a while." : "La servilo %s estas nun en reĝimo de prizorgado, tio eble daŭros longatempe.",
     "This page will refresh itself when the instance is available again." : "Tiu ĉi paĝo aktualiĝos mem, kiam la servilo redisponeblos.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Kontaktu vian administranton, se tiu ĉi mesaĝo daŭras aŭ aperas neatendite.",
-    "The user limit of this instance is reached." : "La maksimuma nombro de uzantoj estis atingita en tiu ĉi servilo.",
-    "Your web server is not yet properly set up to allow file synchronization, because the WebDAV interface seems to be broken." : "Via retservilo ankoraŭ ne estas agordita por permesi sinkronigon de dosieroj, ĉar la WebDAV-interfaco ŝajne difektiĝas.",
-    "Your web server is not properly set up to resolve \"{url}\". Further information can be found in the {linkstart}documentation ↗{linkend}." : "Via retservilo ne estas bone agordita por trovi la adreson „{url}“. Pli da informo troveblas en la {linkstart}dokumentaro ↗{linkend}.",
-    "Your web server is not properly set up to resolve \"{url}\". This is most likely related to a web server configuration that was not updated to deliver this folder directly. Please compare your configuration against the shipped rewrite rules in \".htaccess\" for Apache or the provided one in the documentation for Nginx at it's {linkstart}documentation page ↗{linkend}. On Nginx those are typically the lines starting with \"location ~\" that need an update." : "Via retservilo ne estas bone agordita por trovi la adreson „{url}“. Tio plej verŝajne estas kaŭzita de servilo ne ĝisdatigita por rekte liveri tiun ĉi dosierujon. Bv. kompari vian agordon al transformreguloj en „.htaccess“ por Apache, aŭ la reguloj por Nginx en la {linkstart}dokumentaro ↗{linkend}. Ĉe Nginx, tio, kio devas ĝisdatiĝi estas kutime linioj komencantaj per „location ~“.",
-    "Your web server is not properly set up to deliver .woff2 files. This is typically an issue with the Nginx configuration. For Nextcloud 15 it needs an adjustement to also deliver .woff2 files. Compare your Nginx configuration to the recommended configuration in our {linkstart}documentation ↗{linkend}." : "Via retservilo ne estas bone agordita por sendi .woff2-dosierojn. Tio estas tipe problemo kun la agordo de Nginx. Nextcloud 15 bezonas adapton por ankaŭ sendi .woff2-dosierojn. Komparu vian Nginx-agordon kun la rekomendita agordo en nia {linkstart}dokumentaro ↗{linkend}.",
-    "The \"{header}\" HTTP header is not set to \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "La HTTP-kapo „{header}“ ne egalas al „{expected}“. Tio estas eventuala risko pri sekureco aŭ privateco. Bv. ĝustigi tiun agordon laŭe.",
-    "The \"{header}\" HTTP header is not set to \"{expected}\". Some features might not work correctly, as it is recommended to adjust this setting accordingly." : "La HTTP-kapo „{header}“ ne egalas al „{expected}“. Iuj trajtoj povus ne funkcii ĝuste. Bv. ĝustigi tiun agordon laŭe.",
-    "Currently open" : "Aktuale malfermita",
-    "Wrong username or password." : "Neĝusta uzantnomo aŭ pasvorto.",
-    "User disabled" : "Uzanto malvalidigita",
-    "Username or email" : "Uzantnomo aŭ retpoŝtadreso",
-    "Error loading message template: {error}" : "Eraro dum ŝargo de mesaĝa ŝablono: {error}",
-    "Users" : "Uzantoj",
-    "Username" : "Uzantnomo",
-    "Database user" : "Datumbaza uzanto",
-    "This action requires you to confirm your password" : "Tiu ĉi ago bezonas, ke vi konfirmas vian pasvorton",
-    "Confirm your password" : "Konfirmu vian pasvorton",
-    "Confirm" : "Konfirmi",
-    "App token" : "Aplikaĵa ĵetono",
-    "Alternative log in using app token" : "Ensaluti alimaniere per aplikaĵa ĵetono",
-    "Please use the command line updater because you have a big instance with more than 50 users." : "Bv. uzi la komandlinian ĝisdatigilon, ĉar vi havas pli da 50 uzantojn en tiu servilo."
+    "Edit Profile" : "Modifi profilon",
+    "Very weak password" : "Tre malforta pasvorto",
+    "Weak password" : "Malforta pasvorto",
+    "So-so password" : "Mezbona pasvorto",
+    "Good password" : "Bona pasvorto",
+    "Strong password" : "Forta pasvorto",
+    "Profile not found" : "Profilo ne troviĝis",
+    "The profile does not exist." : "La profilo ne ekzistas.",
+    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Via datumdosierujo kaj dosieroj estas probable elireblaj el la interreto, ĉar la dosiero „.htaccess“ ne funkcias.",
+    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Por pli da informoj pri kielo agordi vian retservilon, bv. vidi la <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">dokumentaron</a>.",
+    "Show password" : "Montri pasvorton",
+    "Toggle password visibility" : "Ŝanĝi videblecon de pasvorto",
+    "Configure the database" : "Agordi la datumbazon",
+    "Only %s is available." : "Nur %s disponeblas.",
+    "Database account" : "Datumbaza konto"
 },
 "nplurals=2; plural=(n != 1);");
