@@ -44,7 +44,6 @@ OC.L10N.register(
     "Task not found" : "Attività non trovata",
     "Internal error" : "Errore interno",
     "Not found" : "Non trovato",
-    "Node is locked" : "Il nodo è bloccato",
     "Bad request" : "Richiesta errata",
     "Requested task type does not exist" : "Il tipo di attività richiesto non esiste",
     "Necessary language model provider is not available" : "Il necessario provider di modello per la lingua non è disponibile",
@@ -81,125 +80,10 @@ OC.L10N.register(
     "%s (incompatible)" : "%s (incompatibile)",
     "The following apps have been disabled: %s" : "Le seguenti applicazioni sono state disabilitate: %s",
     "Already up to date" : "Già aggiornato",
-    "Windows Command Script" : "Script dei comandi di Windows",
-    "Electronic book document" : "Documento libro elettronico",
-    "TrueType Font Collection" : "Raccolta di font TrueType",
-    "Web Open Font Format" : "Formato Web Open Font",
-    "GPX geographic data" : "Dati geografici GPX",
-    "Gzip archive" : "Archivio Gzip",
-    "Adobe Illustrator document" : "Documento di Adobe Illustrator",
-    "Java source code" : "Codice sorgente Java",
-    "JavaScript source code" : "Codice sorgente JavaScript",
-    "JSON document" : "Documento JSON",
-    "Microsoft Access database" : "Database di Microsoft Access",
-    "Microsoft OneNote document" : "Documento di Microsoft OneNote",
-    "Microsoft Word document" : "Documento di Microsoft Word",
     "Unknown" : "Sconosciuto",
-    "PDF document" : "Documento PDF",
-    "PostScript document" : "Documento PostScript",
-    "RSS summary" : "Riepilogo RSS",
-    "Android package" : "Pacchetto Android",
-    "KML geographic data" : "Dati geografici KML",
-    "KML geographic compressed data" : "Dati geografici compressi KML",
-    "Lotus Word Pro document" : "Documento Lotus Word Pro",
-    "Excel spreadsheet" : "Foglio di calcolo Excel",
-    "Excel add-in" : "Componente aggiuntivo di Excel",
-    "Excel 2007 binary spreadsheet" : "Foglio di calcolo binario di Excel 2007",
-    "Excel spreadsheet template" : "Modello di foglio di calcolo Excel",
-    "Outlook Message" : "Messaggio di Outlook",
-    "PowerPoint presentation" : "Presentazione PowerPoint",
-    "PowerPoint add-in" : "Componente aggiuntivo di PowerPoint",
-    "PowerPoint presentation template" : "Modello di presentazione di PowerPoint",
-    "Word document" : "Documento Word",
-    "ODF formula" : "Formula ODF",
-    "ODG drawing" : "Disegno ODG",
-    "ODG drawing (Flat XML)" : "Disegno ODG (XML piatto)",
-    "ODG template" : "Modello ODG",
-    "ODP presentation" : "Presentazione ODP",
-    "ODP presentation (Flat XML)" : "Presentazione ODP (XML piatto)",
-    "ODP template" : "Modello ODP",
-    "ODS spreadsheet" : "Foglio di calcolo ODS",
-    "ODS spreadsheet (Flat XML)" : "Foglio di calcolo ODS (XML piatto)",
-    "ODS template" : "Modello ODS",
-    "ODT document" : "Documento ODT",
-    "ODT document (Flat XML)" : "Documento ODT (XML piatto)",
-    "ODT template" : "Modello ODT",
-    "PowerPoint 2007 presentation" : "Presentazione PowerPoint 2007",
-    "PowerPoint 2007 show" : "Visualizzatore di PowerPoint 2007",
-    "PowerPoint 2007 presentation template" : "Modello di presentazione di PowerPoint 2007",
-    "Excel 2007 spreadsheet" : "Foglio di calcolo Excel 2007",
-    "Excel 2007 spreadsheet template" : "Modello di foglio di calcolo di Excel 2007",
-    "Word 2007 document" : "Documento di Word 2007",
-    "Word 2007 document template" : "Modello di documento Word 2007",
-    "Microsoft Visio document" : "Documento di Microsoft Visio",
-    "WordPerfect document" : "Documento WordPerfect",
-    "7-zip archive" : "Archivio 7-zip",
-    "Blender scene" : "Scena di Blender",
-    "Bzip2 archive" : "Archivio Bzip2",
-    "Debian package" : "Pacchetto Debian",
-    "FictionBook document" : "Documento FictionBook",
-    "Unknown font" : "Font sconosciuto",
-    "Krita document" : "Documento Krita",
-    "Mobipocket e-book" : "E-book Mobipocket",
-    "Windows Installer package" : "Pacchetto di installazione di Windows",
-    "Perl script" : "Script Perl",
-    "PHP script" : "Script PHP",
-    "Tar archive" : "Archivio Tar",
-    "XML document" : "Documento XML",
-    "YAML document" : "Documento YAML",
-    "Zip archive" : "Archivio zip",
-    "Zstandard archive" : "Archivio Zstandard",
-    "AAC audio" : "Audio AAC",
-    "FLAC audio" : "Audio FLAC",
-    "MPEG-4 audio" : "Audio MPEG-4",
-    "MP3 audio" : "Audio MP3",
-    "Ogg audio" : "Audio Ogg",
-    "RIFF/WAVe standard Audio" : "Standard audio RIFF/WAVe",
-    "WebM audio" : "Audio WebM",
-    "MP3 ShoutCast playlist" : "Playlist MP3 ShoutCast",
-    "Windows BMP image" : "Immagine BMP di Windows",
-    "Better Portable Graphics image" : "Migliore immagine grafica portatile",
-    "EMF image" : "Immagine EMF",
-    "GIF image" : "Immagine GIF",
-    "HEIC image" : "Immagine HEIC",
-    "HEIF image" : "Immagine HEIF",
-    "JPEG-2000 JP2 image" : "Immagine JPEG-2000 JP2",
-    "JPEG image" : "Immagine JPEG",
     "PNG image" : "Immagine PNG",
-    "SVG image" : "Immagine SVG",
-    "Truevision Targa image" : "Immagine Truevision Targa",
-    "TIFF image" : "Immagine TIFF",
-    "WebP image" : "Immagine WebP",
-    "Digital raw image" : "Immagine digitale raw",
-    "Windows Icon" : "Icona di Windows",
-    "Email message" : "messaggio di posta elettronica",
-    "VCS/ICS calendar" : "Calendario VCS/ICS",
-    "CSS stylesheet" : "Foglio di stile CSS",
-    "CSV document" : "Documento CSV",
-    "HTML document" : "Documento HTML",
-    "Markdown document" : "Documento Markdown",
-    "Org-mode file" : "File Org-mode",
-    "Plain text document" : "Documento di testo normale",
-    "Rich Text document" : "Documento Rich Text",
-    "Electronic business card" : "Biglietto da visita elettronico",
-    "C++ source code" : "Codice sorgente C++",
-    "LDIF address book" : "Rubrica LDIF",
-    "NFO document" : "Documento NFO",
-    "PHP source" : "Sorgente PHP",
-    "Python script" : "Script Python",
-    "ReStructuredText document" : "Documento ReStructuredText",
-    "3GPP multimedia file" : "File multimediale 3GPP",
-    "MPEG video" : "Video MPEG",
-    "DV video" : "Video DV",
-    "MPEG-2 transport stream" : "Flusso di trasporto MPEG-2",
-    "MPEG-4 video" : "Video MPEG-4",
-    "Ogg video" : "Video Ogg",
-    "QuickTime video" : "Video QuickTime",
-    "WebM video" : "Video WebM",
-    "Flash video" : "Video flash",
-    "Matroska video" : "Video Matroska",
-    "Windows Media video" : "Video di Windows Media",
-    "AVI video" : "Video AVI",
+    "Error occurred while checking server setup" : "Si è verificato un errore durante il controllo della configurazione del server",
+    "For more details see the {linkstart}documentation ↗{linkend}." : "Per ulteriori dettagli, leggi la {linkstart}documentazione ↗{linkend}.",
     "unknown text" : "testo sconosciuto",
     "Hello world!" : "Ciao mondo!",
     "sunny" : "soleggiato",
@@ -228,7 +112,7 @@ OC.L10N.register(
     "Federated user" : "Utente federato",
     "user@your-nextcloud.org" : "utente@il-tuo-nextcloud.org",
     "Create share" : "Crea condivisione",
-    "Direct link copied" : "Link diretto copiato",
+    "Direct link copied to clipboard" : "Collegamento diretto copiato negli appunti",
     "Please copy the link manually:" : "Copia il collegamento manualmente:",
     "Custom date range" : "Intervallo di date personalizzato",
     "Pick start date" : "Scegli la data di inizio",
@@ -245,7 +129,6 @@ OC.L10N.register(
     "Last 30 days" : "Ultimi 30 giorni",
     "This year" : "Quest'anno",
     "Last year" : "Ultimo anno",
-    "Between {startDate} and {endDate}" : "Tra {startDate} e {endDate}",
     "Unified search" : "Ricerca unificata",
     "Search apps, files, tags, messages" : "Cerca applicazioni. file, etichette, messaggi",
     "Places" : "Luoghi",
@@ -253,7 +136,6 @@ OC.L10N.register(
     "Search people" : "Cerca le persone",
     "People" : "Persone",
     "Filter in current view" : "Filtro nella vista corrente",
-    "Search connected services" : "Cerca servizi connessi",
     "Results" : "Risultati",
     "Load more results" : "Carica più risultati",
     "Search in" : "Cerca all'interno",
@@ -328,11 +210,6 @@ OC.L10N.register(
     "Login form is disabled." : "Il modulo di accesso è disabilitato.",
     "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "Il modulo di accesso a Nextcloud è disabilitato. Usa un'altra opzione di accesso, se disponibile, o contatta l'amministratore.",
     "More actions" : "Altre azioni",
-    "User menu" : "Menu utente",
-    "Your guest name: {user}" : "Il tuo nome ospite: {user}",
-    "You are currently not identified." : "Al momento non sei stato identificato.",
-    "Set public name" : "Imposta nome pubblico",
-    "Change public name" : "Cambia nome pubblico",
     "Password is too weak" : "La password è troppo debole",
     "Password is weak" : "La password è debole",
     "Password is average" : "La password è mediocre",
@@ -426,7 +303,6 @@ OC.L10N.register(
     "Admin" : "Admin",
     "Help" : "Aiuto",
     "Access forbidden" : "Accesso negato",
-    "You are not allowed to access this page." : "Non ti è consentito accedere a questa pagina.",
     "Back to %s" : "Torna a %s",
     "Page not found" : "Pagina non trovata",
     "The page could not be found on the server or you may not be allowed to view it." : "La pagina non è stata trovata sul server o forse non ti è permesso vederla.",
@@ -505,8 +381,6 @@ OC.L10N.register(
     "This %s instance is currently in maintenance mode, which may take a while." : "Questa istanza di %s è attualmente in manutenzione, potrebbe richiedere del tempo.",
     "This page will refresh itself when the instance is available again." : "Questa pagina si aggiornerà quando l'istanza sarà nuovamente disponibile.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Contatta il tuo amministratore di sistema se questo messaggio persiste o appare inaspettatamente.",
-    "Error occurred while checking server setup" : "Si è verificato un errore durante il controllo della configurazione del server",
-    "For more details see the {linkstart}documentation ↗{linkend}." : "Per ulteriori dettagli, leggi la {linkstart}documentazione ↗{linkend}.",
     "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Chat, videochiamate, condivisione schermo, riunioni in linea e conferenze web – nel tuo browser e con le applicazioni mobili.",
     "You have not added any info yet" : "Non hai ancora aggiunto alcuna informazione",
     "{user} has not added any info yet" : "{user} non ha ancora aggiunto alcuna informazione",
@@ -529,7 +403,6 @@ OC.L10N.register(
     "Toggle password visibility" : "Commuta la visibilità delle password",
     "Configure the database" : "Configura il database",
     "Only %s is available." : "È disponibile solo %s.",
-    "Database account" : "Database account",
-    "Direct link copied to clipboard" : "Collegamento diretto copiato negli appunti"
+    "Database account" : "Database account"
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
