@@ -273,7 +273,6 @@ OC.L10N.register(
     "A valid Login must be provided" : "Et gyldigt login skal angives",
     "Login contains whitespace at the beginning or at the end" : "Login indeholder mellemrum i begyndelsen eller slutningen",
     "Login must not consist of dots only" : "Login må ikke kun bestå af prikker",
-    "Login is too long" : "Login er for lang",
     "Login is invalid because files already exist for this user" : "Login er ugyldigt, fordi filer allerede eksisterer for denne bruger",
     "Account disabled" : "Konto deaktiveret",
     "Login canceled by app" : "Login annulleret af app",
@@ -443,20 +442,8 @@ OC.L10N.register(
     "Generate headline" : "Generer overskrift",
     "Summarizes text by reducing its length without losing key information." : "Opsummerer tekst ved at reducere dens længde uden at miste nøgleinformation.",
     "Extracts topics from a text and outputs them separated by commas." : "Uddrager emner fra en tekst og skriver dem adskilt af kommaer.",
-    "Education Edition" : "Uddanelses Version",
-    "File name is a reserved word" : "Filnavnet er et reserveret ord",
-    "File name contains at least one invalid character" : "Filnavnet indeholder mindst et ugyldigt tegn",
-    "File name is too long" : "Filnavnet er for langt",
-    "Users" : "Brugere",
-    "%1$s shared »%2$s« with you and wants to add:" : "%1$s delte »%2$s« med dig og vil gerne tilføje:",
-    "%1$s shared »%2$s« with you and wants to add" : "%1$s delte »%2$s« med dig og vil gerne tilføje",
-    "»%s« added a note to a file shared with you" : "»%s« tilføjede en note til en fil delt med dig",
-    "Open »%s«" : "Åbn »%s«",
-    "%1$s shared »%2$s« with you" : "%1$s delte »%2$s« med dig",
-    "%1$s shared »%2$s« with you." : "%1$s delte »%2$s« med dig",
-    "Click the button below to open it." : "Klik på knappen nedenunder for at åbne.",
     "File is currently busy, please try again later" : "Filen er i øjeblikket optaget - forsøg igen senere",
     "Cannot download file" : "Kan ikke downloade filen",
-    "Ensure there is a file called \".ocdata\" in the root of the data directory." : "Du bedes sikre at filen \".ocdata\" befinder sig i roden af din datamappe."
+    "Login is too long" : "Login er for lang"
 },
 "nplurals=2; plural=(n != 1);");
