@@ -93,6 +93,8 @@ OC.L10N.register(
     "Destination does not exist" : "Destination does not exist",
     "Destination is not creatable" : "Destination is not creatable",
     "Dot files are not allowed" : "Dot files are not allowed",
+    "%1$s (renamed)" : "%1$s (renamed)",
+    "renamed file" : "renamed file",
     "\"%1$s\" is a forbidden file or folder name." : "\"%1$s\" is a forbidden file or folder name.",
     "\"%1$s\" is a forbidden prefix for file or folder names." : "\"%1$s\" is a forbidden prefix for file or folder names.",
     "\"%1$s\" is not allowed inside a file or folder name." : "\"%1$s\" is not allowed inside a file or folder name.",
@@ -201,6 +203,7 @@ OC.L10N.register(
     "Path is already shared with this group" : "Path is already shared with this group",
     "Link sharing is not allowed" : "Link sharing is not allowed",
     "Public upload is not allowed" : "Public upload is not allowed",
+    "You cannot share a folder that contains other shares" : "You cannot share a folder that contains other shares",
     "Sharing is disabled" : "Sharing is disabled",
     "Sharing is disabled for you" : "Sharing is disabled for you",
     "Cannot share with the share owner" : "Cannot share with the share owner",
@@ -272,6 +275,7 @@ OC.L10N.register(
     "A valid Login must be provided" : "A valid Login must be provided",
     "Login contains whitespace at the beginning or at the end" : "Login contains whitespace at the beginning or at the end",
     "Login must not consist of dots only" : "Login must not consist of dots only",
+    "Username is too long" : "Username is too long",
     "Login is invalid because files already exist for this user" : "Login is invalid because files already exist for this user",
     "Account disabled" : "Account disabled",
     "Login canceled by app" : "Login cancelled by app",
@@ -362,6 +366,11 @@ OC.L10N.register(
     "How many images to generate" : "How many images to generate",
     "Output images" : "Output images",
     "The generated images" : "The generated images",
+    "Generate speech" : "Generate speech",
+    "Generate speech from a transcript" : "Generate speech from a transcript",
+    "Write transcript that you want the assistant to generate speech from" : "Write transcript that you want the assistant to generate speech from",
+    "Output speech" : "Output speech",
+    "The generated speech" : "The generated speech",
     "Free text to text prompt" : "Free text to text prompt",
     "Runs an arbitrary prompt through a language model that returns a reply" : "Runs an arbitrary prompt through a language model that returns a reply",
     "Describe a task that you want the assistant to do or ask a question" : "Describe a task that you want the assistant to do or ask a question",
@@ -441,20 +450,8 @@ OC.L10N.register(
     "Generate headline" : "Generate headline",
     "Summarizes text by reducing its length without losing key information." : "Summarizes text by reducing its length without losing key information.",
     "Extracts topics from a text and outputs them separated by commas." : "Extracts topics from a text and outputs them separated by commas.",
-    "Education Edition" : "Education Edition",
-    "File name is a reserved word" : "File name is a reserved word",
-    "File name contains at least one invalid character" : "File name contains at least one invalid character",
-    "File name is too long" : "File name is too long",
-    "Users" : "Users",
-    "%1$s shared »%2$s« with you and wants to add:" : "%1$s shared »%2$s« with you and wants to add:",
-    "%1$s shared »%2$s« with you and wants to add" : "%1$s shared »%2$s« with you and wants to add",
-    "»%s« added a note to a file shared with you" : "»%s« added a note to a file shared with you",
-    "Open »%s«" : "Open »%s«",
-    "%1$s shared »%2$s« with you" : "%1$s shared »%2$s« with you",
-    "%1$s shared »%2$s« with you." : "%1$s shared »%2$s« with you.",
-    "Click the button below to open it." : "Click the button below to open it.",
     "File is currently busy, please try again later" : "File is currently busy, please try again later",
     "Cannot download file" : "Cannot download file",
-    "Ensure there is a file called \".ocdata\" in the root of the data directory." : "Ensure there is a file called \".ocdata\" in the root of the data directory."
+    "Login is too long" : "Login is too long"
 },
 "nplurals=2; plural=(n != 1);");
