@@ -5,7 +5,7 @@ OC.L10N.register(
     "See %s" : "Skatīt %s",
     "Application %1$s is not present or has a non-compatible version with this server. Please check the apps directory." : "Lietotne %1$s nav pieejama vai tai ir ar šo serveri nesaderīga versija. Lūgums pārbaudīt lietotņu mapi.",
     "Sample configuration detected" : "Atrasta konfigurācijas paraugs",
-    "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Konstatēts, ka paraug konfigurācija ir nokopēta. Tas var izjaukt jūsu instalāciju un nav atbalstīts. Lūdzu, izlasiet dokumentāciju, pirms veicat izmaiņas config.php",
+    "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Tika noteikts, ka tika kopēta paraugkonfigurācija. Tas var salauzt uzstādīto un netiek atbalstīts. Lūgums pirms izmaiņu veikšanas config.php izlasīt dokumentāciju",
     "%s email verification" : "%s e-pasta pārbaude",
     "Email verification" : "E-pasta pārbaude",
     "Click the following button to confirm your email." : "Jāklikšķina zemā esošā poga, lai apstiprinātu savu e-pasta adresi.",
@@ -20,27 +20,30 @@ OC.L10N.register(
     "%sbit or higher PHP required." : "Nepieciešams %sbit vai jaunāks PHP.",
     "The command line tool %s could not be found" : "Komandrindas rīku %s nevarēja atrast",
     "The library %s is not available." : "Bibliotēka %s nav pieejama.",
-    "Server version %s or higher is required." : "Ir vajadzīga servera versija %s vai jaunāka.",
-    "Server version %s or lower is required." : "Ir vajadzīga servera versija %s vai vecāka.",
+    "The following platforms are supported: %s" : "Tiek atbalstītas šīs platformas: %s",
+    "Server version %s or higher is required." : "Ir nepieciešama servera versija %s vai jaunāka.",
+    "Server version %s or lower is required." : "Ir nepieciešama servera versija %s vai vecāka.",
     "Authentication" : "Autentifikācija",
     "Unknown filetype" : "Nezināms datnes veids",
     "Invalid image" : "Nederīgs attēls",
-    "Avatar image is not square" : "Avatar attēls nav kvadrāts",
+    "Avatar image is not square" : "Profila attēls nav kvadrāts",
     "Files" : "Datnes",
     "View profile" : "Skatīt profilu",
     "today" : "šodien",
     "yesterday" : "vakar",
-    "_%n day ago_::_%n days ago_" : ["%n dienas atpakaļ","%n dienas atpakaļ","%n dienām"],
+    "_%n day ago_::_%n days ago_" : ["pirms %n dienām","pirms %n dienas","pirms %n dienām"],
     "last month" : "pagājušajā mēnesī",
-    "_%n month ago_::_%n months ago_" : ["%n mēneši atpakaļ","%n mēneši atpakaļ","%n mēnešiem"],
+    "_%n month ago_::_%n months ago_" : ["pirms %n mēnešiem","pirms %n mēneša","pirms %n mēnešiem"],
     "last year" : "gājušajā gadā",
-    "_%n year ago_::_%n years ago_" : ["%n gadiem","%n gadiem","%n gadiem"],
-    "_%n hour ago_::_%n hours ago_" : ["%n stundas atpakaļ","%n stundas atpakaļ","%n stundām"],
-    "_%n minute ago_::_%n minutes ago_" : ["%n minūtes atpakaļ","%n minūtes atpakaļ","%n minūtēm"],
-    "seconds ago" : "sekundēm",
+    "_%n year ago_::_%n years ago_" : ["pirms %n gadiem","pirms %n gada","pirms %n gadiem"],
+    "_%n hour ago_::_%n hours ago_" : ["pirms %n stundām","pirms %n stundas","pirms %n stundām"],
+    "_%n minute ago_::_%n minutes ago_" : ["pirms %n minūtēm","pirms %n minūtes","pirms %n minūtēm"],
+    "seconds ago" : "pirms vairākām sekundēm",
+    "Empty file" : "Tukša datne",
     "File already exists" : "Datne jau pastāv",
     "Filename contains at least one invalid character" : "Datnes nosaukums satur vismaz vienu nederīgu rakstzīmi",
     "Empty filename is not allowed" : "Tukšs datnes nosaukums nav atļauts",
+    "App \"%s\" cannot be installed because it is not compatible with this version of the server." : "Lietotni \"%s\" nevar uzstādīt, jo tā nav saderīga ar šo servera versiju.",
     "__language_name__" : "Latviešu",
     "This is an automatically sent email, please do not reply." : "Šis ir automātiski nosūtīts e-pasta ziņojums, lūgums neatbildēt.",
     "Help & privacy" : "Palīdzība un privātums",
@@ -63,8 +66,9 @@ OC.L10N.register(
     "Additional settings" : "Papildu iestatījumi",
     "Oracle connection could not be established" : "Nevar izveidot savienojumu ar Oracle",
     "Set an admin password." : "Iestatīt pārvaldītāja paroli.",
+    "Open %s" : "Atvērt %s",
     "Unknown share type" : "Nezināms kopīgošanas veids",
-    "You are not allowed to share %s" : "Tev nav ļauts dalīties ar %s",
+    "You are not allowed to share %s" : "Tev nav ļauts kopīgot %s",
     "Could not find category \"%s\"" : "Nevarēja atrast kategoriju “%s”",
     "Sunday" : "Svētdiena",
     "Monday" : "Pirmdiena",
@@ -112,12 +116,12 @@ OC.L10N.register(
     "Nov." : "Nov.",
     "Dec." : "Dec.",
     "A valid password must be provided" : "Jānorāda derīga parole",
-    "Login canceled by app" : "Pieteikšanos atcelā lietotne",
+    "Login canceled by app" : "Lietotne atcēla pieteikšanos",
     "a safe home for all your data" : "droša vieta visiem Taviem datiem",
     "Application is not enabled" : "Lietotne nav iespējota",
-    "Authentication error" : "Autentifikācijas kļūda",
+    "Authentication error" : "Autentificēšanās kļūda",
     "Token expired. Please reload page." : "Pilnvarai ir beidzies derīgums. Lūgums pārlādēt lapu.",
-    "PHP module %s not installed." : "PHP modulis %s nav instalēts.",
+    "PHP module %s not installed." : "Nav uzstādīts PHP modulis %s.",
     "Please ask your server administrator to install the module." : "Lūgums vaicāt savam servera pārvaldītāja, lai uzstāda moduli.",
     "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Tas ir iespējams, kešatmiņa / paātrinātājs, piemēram, Zend OPcache vai eAccelerator.",
     "PHP modules have been installed, but they are still listed as missing?" : "PHP modulis ir uzstādīts, taču tas joprojām ir uzskatāms kā trūkstošs, pazudis?",
@@ -125,15 +129,11 @@ OC.L10N.register(
     "Storage unauthorized. %s" : "Krātuve neautorizēta. %s",
     "Storage incomplete configuration. %s" : "Storage incomplete configuration. %s",
     "Storage connection error. %s" : "Datu savienojuma kļūda. %s",
-    "Storage is temporarily not available" : "Glabātuve īslaicīgi nav pieejama",
+    "Storage is temporarily not available" : "Krātuve īslaicīgi nav pieejama",
     "Storage connection timeout. %s" : "Datu savienojuma taimauts. %s",
     "Text" : "Teksts",
     "Summary" : "Kopsavilkums",
     "Translate" : "Tulkot",
-    "File name is a reserved word" : "Datnes nosaukums ir aizņemts vārds",
-    "File name is too long" : "Datnes nosaukums ir pārāk garš",
-    "Users" : "Lietotāji",
-    "Open »%s«" : "Atvērt »%s«",
     "File is currently busy, please try again later" : "Datne pašlaik ir aizņemta. Lūgums vēlāk mēģināt vēlreiz"
 },
 "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");
