@@ -275,7 +275,7 @@ OC.L10N.register(
     "A valid Login must be provided" : "En giltig inloggning måste anges",
     "Login contains whitespace at the beginning or at the end" : "Inloggningen innehåller blanksteg i början eller slutet",
     "Login must not consist of dots only" : "Inloggningen får inte innehålla enbart punkter",
-    "Login is too long" : "Inloggningen är för lång",
+    "Username is too long" : "Användarnamnet är för långt",
     "Login is invalid because files already exist for this user" : "Inloggningen är ogiltigt eftersom det redan finns filer för den här användaren",
     "Account disabled" : "Konto inaktiverat",
     "Login canceled by app" : "Inloggningen avbruten av appen",
@@ -450,20 +450,8 @@ OC.L10N.register(
     "Generate headline" : "Skapa rubrik",
     "Summarizes text by reducing its length without losing key information." : "Sammanfattar text genom att minska dess längd utan att förlora viktig information.",
     "Extracts topics from a text and outputs them separated by commas." : "Extraherar ämnen från en text och matar ut dem separerade med kommatecken.",
-    "Education Edition" : "Utbildningspaket",
-    "File name is a reserved word" : "Filnamnet är ett reserverat ord",
-    "File name contains at least one invalid character" : "Filnamnet innehåller minst ett ogiltigt tecken",
-    "File name is too long" : "Filnamnet är för långt",
-    "Users" : "Användare",
-    "%1$s shared »%2$s« with you and wants to add:" : "%1$s delade \"%2$s\" med dig och vill lägga till:",
-    "%1$s shared »%2$s« with you and wants to add" : "%1$s delade \"%2$s\" med dig och vill lägga till",
-    "»%s« added a note to a file shared with you" : "\"%s\" lade till en kommentar till en fil som delats med dig",
-    "Open »%s«" : "Öppna \"%s\"",
-    "%1$s shared »%2$s« with you" : "%1$s delade \"%2$s\" med dig",
-    "%1$s shared »%2$s« with you." : "%1$s delade \"%2$s\" med dig.",
-    "Click the button below to open it." : "Klicka på knappen nedan för att öppna det.",
     "File is currently busy, please try again later" : "Filen är för tillfället upptagen, försök igen senare",
     "Cannot download file" : "Kan inte ladda ner fil",
-    "Ensure there is a file called \".ocdata\" in the root of the data directory." : "Säkerställ att du har filen \".ocdata\" i huvudkatalogen för din data."
+    "Login is too long" : "Inloggningen är för lång"
 },
 "nplurals=2; plural=(n != 1);");
