@@ -93,6 +93,8 @@ OC.L10N.register(
     "Destination does not exist" : "目的地不存在",
     "Destination is not creatable" : "無法建立目的地",
     "Dot files are not allowed" : "不允許小數點開頭的檔案",
+    "%1$s (renamed)" : "%1$s（已重新命名）",
+    "renamed file" : "已重新命名檔案",
     "\"%1$s\" is a forbidden file or folder name." : "「%1$s」是禁止的檔案或資料夾名稱。",
     "\"%1$s\" is a forbidden prefix for file or folder names." : "「%1$s」是禁止的檔案或資料夾名稱前綴。",
     "\"%1$s\" is not allowed inside a file or folder name." : "「%1$s」不允許出現在檔案或資料夾名稱中。",
@@ -201,6 +203,7 @@ OC.L10N.register(
     "Path is already shared with this group" : "路徑已與此群組分享",
     "Link sharing is not allowed" : "不允許連結分享",
     "Public upload is not allowed" : "不允許公開上傳",
+    "You cannot share a folder that contains other shares" : "您無法分享包含其他分享的資料夾",
     "Sharing is disabled" : "已停用分享",
     "Sharing is disabled for you" : "您已停用分享",
     "Cannot share with the share owner" : "無法與分享擁有者分享",
@@ -272,6 +275,7 @@ OC.L10N.register(
     "A valid Login must be provided" : "必須提供有效帳號",
     "Login contains whitespace at the beginning or at the end" : "帳號的開頭或結尾有空白",
     "Login must not consist of dots only" : "帳號不能只包含小數點",
+    "Username is too long" : "使用者名稱太長了",
     "Login is invalid because files already exist for this user" : "帳號無效，因為使用者的檔案已經存在",
     "Account disabled" : "帳號已停用",
     "Login canceled by app" : "應用程式取消了登入",
@@ -328,7 +332,6 @@ OC.L10N.register(
     "The audio to transcribe" : "要轉錄的音訊",
     "Transcription" : "轉錄",
     "The transcribed text" : "已轉錄的文字",
-    "ContextAgent" : "ContextAgent",
     "Chat with an agent" : "與 agent 聊天",
     "Chat message" : "聊天訊息",
     "A chat message to send to the agent." : "要傳送給 agent 的聊天訊息。",
@@ -363,6 +366,11 @@ OC.L10N.register(
     "How many images to generate" : "要產生多少影像",
     "Output images" : "輸出影像",
     "The generated images" : "產生的影像",
+    "Generate speech" : "產生語音",
+    "Generate speech from a transcript" : "從轉錄稿產生語音",
+    "Write transcript that you want the assistant to generate speech from" : "寫下您想要小幫手產生語音的來源轉錄稿",
+    "Output speech" : "輸出語音",
+    "The generated speech" : "產生的語音",
     "Free text to text prompt" : "文字提示的自由文字",
     "Runs an arbitrary prompt through a language model that returns a reply" : "透過回傳回覆的語言模型執行任意提示",
     "Describe a task that you want the assistant to do or ask a question" : "描述您希望助理執行的任務或提出問題",
@@ -442,21 +450,8 @@ OC.L10N.register(
     "Generate headline" : "生成標題",
     "Summarizes text by reducing its length without losing key information." : "寫成摘要，減少文字長度而不丟失關鍵資訊。",
     "Extracts topics from a text and outputs them separated by commas." : "從文字中取出涵蓋的主題並輸出，然後用逗號分隔。",
-    "Education Edition" : "教育版",
-    "File name is a reserved word" : "檔案名稱是保留字",
-    "File name contains at least one invalid character" : "檔案名稱含有不允許的字元",
-    "File name is too long" : "檔案名稱太長",
-    "Users" : "使用者",
-    "%1$s shared »%2$s« with you and wants to add:" : "%1$s 與您分享了「%2$s 」，且想要新增：",
-    "%1$s shared »%2$s« with you and wants to add" : "%1$s 與您分享了「%2$s」，且想要新增",
-    "»%s« added a note to a file shared with you" : "「%s」在與您分享的檔案中加入了備註",
-    "Open »%s«" : "開啟「%s」",
-    "%1$s shared »%2$s« with you" : "%1$s 與您分享了「%2$s」",
-    "%1$s shared »%2$s« with you." : "%1$s 與您分享了「%2$s」。",
-    "Click the button below to open it." : "點擊下方的按鈕將其打開。",
     "File is currently busy, please try again later" : "檔案目前忙碌中，請稍候再試",
     "Cannot download file" : "無法下載檔案",
-    "Ensure there is a file called \".ocdata\" in the root of the data directory." : "請確保資料目錄最上層有一個「.ocdata」檔案。",
-    "Path contains files shared with you" : "路徑包含與您分享的檔案"
+    "Login is too long" : "帳號太長了"
 },
 "nplurals=1; plural=0;");
