@@ -11,20 +11,16 @@ namespace OCP\Files\Config\Event;
 
 use OCP\EventDispatcher\Event;
 use OCP\Files\Config\ICachedMountInfo;
+use OCP\Files\Mount\IMountPoint;
 
 /**
  * Event emitted when a user mount was added.
  *
- * @since 31.0.6
+ * @since 30.0.12
  */
 class UserMountAddedEvent extends Event {
-	/**
-	 * Creates a new @see UserMountAddedEvent
-	 *
-	 * @since 31.0.6
-	 */
 	public function __construct(
-		public readonly ICachedMountInfo $mountPoint,
+		public readonly IMountPoint|ICachedMountInfo $mountPoint,
 	) {
 		parent::__construct();
 	}
